package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Glib.IdleSource

Idle callbacks - functions called when the main loop is idle

Sourcetype id

Idle source ID

Sourceval add : ?prio:int -> (unit -> bool) -> id

add callback adds a function to be called whenever there are no higher priority events pending in the main loop. The callback should return true to continue being called, or false to be removed.

  • parameter prio

    Optional priority (default: G_PRIORITY_DEFAULT_IDLE)

Sourceval remove : id -> unit

remove id removes the idle callback with the given ID