package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Glib.TimeoutSource

Timeout callbacks - functions called after a specified time

Sourcetype id

Timeout source ID

Sourceval add : ?prio:int -> ms:int -> callback:(unit -> bool) -> unit -> id

add ~ms ~callback adds a timeout function that will be called every ms milliseconds. The callback should return true to continue being called, or false to be removed.

  • parameter prio

    Optional priority (default: G_PRIORITY_DEFAULT)

  • parameter ms

    Interval in milliseconds

  • parameter callback

    Function to call, returns true to continue

Sourceval remove : id -> unit

remove id removes the timeout with the given ID