package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Glib_bytesSource

GLib.Bytes - Immutable reference-counted byte buffer

GBytes wraps an immutable block of memory with reference counting. Used for texture data, file contents, serialized data, etc.

Sourcetype t

Opaque GBytes type - backed by GBytes* with g_bytes_unref finalizer

Sourceval create : string -> t

Create a GBytes from an OCaml string (copies the data)

Sourceval to_string : t -> string

Copy the GBytes data into a new OCaml string

Sourceval size : t -> int

Get the size of the byte buffer