package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Gvariant_typeSource

GVariantType - Type description for GVariant

GVariantType describes the type of a GVariant value. It is used for type checking and construction of complex types.

This is an immutable type that uses g_variant_type_copy/free.

Types

Sourcetype t

Opaque GVariantType - backed by GVariantType* with free finalizer

Constructors

Sourceval of_string : string -> t

Create a GVariantType from a type string (e.g., "i", "s", "as", "asv")

Accessors

Sourceval to_string : t -> string

Get the type string representation

Predicates

Sourceval is_basic : t -> bool

Check if the type is a basic type (not a container)

Sourceval is_container : t -> bool

Check if the type is a container type

Sourceval is_array : t -> bool

Check if the type is an array type

Sourceval is_dict_entry : t -> bool

Check if the type is a dictionary entry type

Sourceval is_tuple : t -> bool

Check if the type is a tuple type

Sourceval is_variant : t -> bool

Check if the type is the variant type "v"

Type Constants

Sourceval unit : t

The unit type "()"

Sourceval boolean : t

The boolean type "b"

Sourceval int32 : t

The int32 type "i"

Sourceval int64 : t

The int64 type "x"

Sourceval double : t

The double type "d"

Sourceval string : t

The string type "s"

Sourceval object_path : t

The object path type "o"

Sourceval signature : t

The signature type "g"

Sourceval variant : t

The variant type "v"

Sourceval byte : t

The byte type "y"

Sourceval int16 : t

The int16 type "n"

Sourceval uint16 : t

The uint16 type "q"

Sourceval uint32 : t

The uint32 type "u"

Sourceval uint64 : t

The uint64 type "t"

Sourceval handle : t

The handle type "h"