package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Int16Source

Signed 16-bit integer (gint16).

Backed by private int — no heap allocation. Range: -32768, 32767.

Sourcetype t = private int
Sourceval of_int : int -> t

of_int n converts n to an Int16.t.

Sourceval to_int : t -> int

to_int v returns the underlying integer value.

Sourceval min_int : t

The minimum value: -32768.

Sourceval max_int : t

The maximum value: 32767.

Sourceval minus_one : t

The value -1.

Sourceval min_value : int

The minimum value representable as an int, equal to to_int min_int.

Sourceval max_value : int

The maximum value representable as an int, equal to to_int max_int.