package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Int32Source

Signed 32-bit integer (gint32).

Backed by private int — no heap allocation. Range: -2147483648, 2147483647.

This module intentionally shadows Stdlib.Int32. Use Stdlib.Int32 when you need OCaml's boxed int32 type.

Sourcetype t = private int
Sourceval of_int : int -> t

of_int n converts n to an Int32.t.

Sourceval to_int : t -> int

to_int v returns the underlying integer value.

Sourceval min_int : t

The minimum value: -2147483648.

Sourceval max_int : t

The maximum value: 2147483647.

Sourceval minus_one : t

The value -1.

Sourceval min_value : int

The minimum value representable as an int, equal to to_int min_int.

Sourceval max_value : int

The maximum value representable as an int, equal to to_int max_int.