package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ocgtk_commonSource

Common utility modules for ocgtk GTK4 bindings.

This module re-exports hand-written common modules shared across all ocgtk binding libraries (Gtk, Gio, Gdk, etc.). Each module is also available as a flat top-level module (e.g. Gobject) in the ocgtk.common library.

Sourcemodule GError = GError

Error type for GTK/GLib functions. See GError.

Sourcemodule Gobject = Gobject

GObject type system, properties, and signals. See Gobject.

Sourcemodule Gvariant = Gvariant

GVariant structured data serialization. See Gvariant.

Sourcemodule Gvariant_type = Gvariant_type

GVariant type descriptions. See Gvariant_type.