package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module UInt16Source

Unsigned 16-bit integer (guint16).

Backed by private int — no heap allocation. Range: 0, 65535.

Sourcetype t = private int
Sourceval of_int : int -> t

of_int n converts n to a UInt16.t.

Sourceval to_int : t -> int

to_int v returns the underlying integer value.

Sourceval min_int : t

The minimum value: 0.

Sourceval max_int : t

The maximum value: 65535.

Sourceval zero : t

Alias for min_int: 0.

Sourceval min_value : int

The minimum value representable as an int, equal to to_int min_int.

Sourceval max_value : int

The maximum value representable as an int, equal to to_int max_int.