package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.App_launch_context

type t = [ `app_launch_context | `object_ ] Gobject.obj
val set_timestamp : t -> UInt32.t -> unit

Sets the timestamp of @context.

The timestamp should ideally be taken from the event that triggered the launch.

Window managers can use this information to avoid moving the focus to the newly launched application when the user is busy typing in another window. This is also known as 'focus stealing prevention'.

val set_icon_name : t -> string option -> unit

Sets the icon for applications that are launched with this context.

The @icon_name will be interpreted in the same way as the Icon field in desktop files. See also method@Gdk.AppLaunchContext.set_icon.

If both @icon and @icon_name are set, the @icon_name takes priority. If neither @icon or @icon_name is set, the icon is taken from either the file that is passed to launched application or from the `GAppInfo` for the launched application itself.

val set_icon : t -> Ocgtk_gio.Gio.Wrappers.Icon.t option -> unit

Sets the icon for applications that are launched with this context.

Window Managers can use this information when displaying startup notification.

See also method@Gdk.AppLaunchContext.set_icon_name.

val set_desktop : t -> int -> unit

Sets the workspace on which applications will be launched.

This only works when running under a window manager that supports multiple workspaces, as described in the Extended Window Manager Hints(http://www.freedesktop.org/Standards/wm-spec). Specifically this sets the `_NET_WM_DESKTOP` property described in that spec.

This only works when using the X11 backend.

When the workspace is not specified or @desktop is set to -1, it is up to the window manager to pick one, typically it will be the current workspace.

val get_display : t -> [ `display | `object_ ] Gobject.obj

Get property: display