package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Cairo_context

type t = [ `cairo_context | `draw_context | `object_ ] Gobject.obj
val cairo_create : t -> Ocgtk_cairo.Cairo.Wrappers.Context.t option

Retrieves a Cairo context to be used to draw on the `GdkSurface` of @context.

A call to method@Gdk.DrawContext.begin_frame with this @context must have been done or this function will return %NULL.

The returned context is guaranteed to be valid until method@Gdk.DrawContext.end_frame is called.