package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Content_formats_builder

type t = [ `content_formats_builder ] Gobject.obj

A `GdkContentFormatsBuilder` is an auxiliary struct used to create new `GdkContentFormats`, and should not be kept around.

val new_ : unit -> t

Create a new ContentFormatsBuilder

val to_formats : t -> [ `content_formats ] Gobject.obj

Creates a new `GdkContentFormats` from the given @builder.

The given `GdkContentFormatsBuilder` is reset once this function returns; you cannot call this function multiple times on the same @builder instance.

This function is intended primarily for bindings. C code should use method@Gdk.ContentFormatsBuilder.free_to_formats.

val ref : t -> t

Acquires a reference on the given @builder.

This function is intended primarily for bindings. `GdkContentFormatsBuilder` objects should not be kept around.

val add_mime_type : t -> string -> unit

Appends @mime_type to @builder if it has not already been added.

val add_gtype : t -> Gobject.Type.t -> unit

Appends @type to @builder if it has not already been added.

val add_formats : t -> [ `content_formats ] Gobject.obj -> unit

Appends all formats from @formats to @builder, skipping those that already exist.

val get_type : unit -> Gobject.Type.t