package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Content_serializer

type t = [ `content_serializer | `object_ ] Gobject.obj
val return_success : t -> unit

Indicate that the serialization has been successfully completed.

val return_error : t -> GError.t -> unit

Indicate that the serialization has ended with an error.

This function consumes @error.

val get_value : t -> Gobject.Value.t

Gets the `GValue` to read the object to serialize from.

val get_priority : t -> int

Gets the I/O priority for the current operation.

This is the priority that was passed to func@content_serialize_async.

val get_output_stream : t -> Ocgtk_gio.Gio.Wrappers.Output_stream.t

Gets the output stream for the current operation.

This is the stream that was passed to func@content_serialize_async.

val get_mime_type : t -> string

Gets the mime type to serialize to.

val get_gtype : t -> Gobject.Type.t

Gets the `GType` to of the object to serialize.

val get_cancellable : t -> Ocgtk_gio.Gio.Wrappers.Cancellable.t option

Gets the cancellable for the current operation.

This is the `GCancellable` that was passed to func@content_serialize_async.