package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Device_pad

type t = [ `device_pad ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val get_n_groups : t -> int

Returns the number of groups this pad device has.

Pads have at least one group. A pad group is a subcollection of buttons/strip/rings that is affected collectively by a same current mode.

val get_n_features : t -> Gdk_enums.devicepadfeature -> int

Returns the number of features a tablet pad has.

val get_group_n_modes : t -> int -> int

Returns the number of modes that @group may have.

val get_feature_group : t -> Gdk_enums.devicepadfeature -> int -> int

Returns the group the given @feature and @idx belong to.

f the feature or index do not exist in @pad, -1 is returned.