package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Device_tool

type t = [ `device_tool | `object_ ] Gobject.obj
val get_tool_type : t -> Gdk_enums.devicetooltype

Gets the `GdkDeviceToolType` of the tool.

val get_serial : t -> UInt64.t

Gets the serial number of this tool.

This value can be used to identify a physical tool (eg. a tablet pen) across program executions.

val get_hardware_id : t -> UInt64.t

Gets the hardware ID of this tool, or 0 if it's not known.

When non-zero, the identifier is unique for the given tool model, meaning that two identical tools will share the same @hardware_id, but will have different serial numbers (see method@Gdk.DeviceTool.get_serial).

This is a more concrete (and device specific) method to identify a `GdkDeviceTool` than method@Gdk.DeviceTool.get_tool_type, as a tablet may support multiple devices with the same `GdkDeviceToolType`, but different hardware identifiers.

val get_axes : t -> Gdk_enums.axisflags

Gets the axes of the tool.