package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Grab_broken_event

type t = [ `grab_broken_event | `event ] Gobject.obj
val get_implicit : t -> bool

Checks whether the grab broken event is for an implicit grab.

val get_grab_surface : t -> [ `surface | `object_ ] Gobject.obj

Extracts the grab surface from a grab broken event.