package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Pad_event

type t = [ `pad_event | `event ] Gobject.obj
val get_group_mode : t -> int * int

Extracts group and mode information from a pad event.

val get_button : t -> int

Extracts information about the pressed button from a pad event.

val get_axis_value : t -> int * float

Extracts the information from a pad strip or ring event.