package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Rectangle

type t = [ `rectangle ] Gobject.obj

A `GdkRectangle` data type for representing rectangles.

`GdkRectangle` is identical to `cairo_rectangle_t`. Together with Cairo’s `cairo_region_t` data type, these are the central types for representing sets of pixels.

The intersection of two rectangles can be computed with method@Gdk.Rectangle.intersect; to find the union of two rectangles use method@Gdk.Rectangle.union.

The `cairo_region_t` type provided by Cairo is usually used for managing non-rectangular clipping of graphical operations.

The Graphene library has a number of other data types for regions and volumes in 2D and 3D.

val union : t -> t -> t

Calculates the union of two rectangles.

The union of rectangles @src1 and @src2 is the smallest rectangle which includes both @src1 and @src2 within it. It is allowed for @dest to be the same as either @src1 or @src2.

Note that this function does not ignore 'empty' rectangles (ie. with zero width or height).

val intersect : t -> t -> bool * t

Calculates the intersection of two rectangles.

It is allowed for @dest to be the same as either @src1 or @src2. If the rectangles do not intersect, @dest’s width and height is set to 0 and its x and y values are undefined. If you are only interested in whether the rectangles intersect, but not in the intersecting area itself, pass %NULL for @dest.

val equal : t -> t -> bool

Checks if the two given rectangles are equal.

val contains_point : t -> int -> int -> bool

Returns %TRUE if @rect contains the point described by @x and @y.

val get_type : unit -> Gobject.Type.t