package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Time_coord

type t = [ `time_coord ] Gobject.obj

A `GdkTimeCoord` stores a single event in a motion history.

To check whether an axis is present, check whether the corresponding flag from the flags@Gdk.AxisFlags enumeration is set in the @flags To access individual axis values, use the values of the values of the enum@Gdk.AxisUse enumerations as indices.