package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Toplevel_layout

type t = [ `toplevel_layout ] Gobject.obj

The `GdkToplevelLayout` struct contains information that is necessary to present a sovereign window on screen.

The `GdkToplevelLayout` struct is necessary for using method@Gdk.Toplevel.present.

Toplevel surfaces are sovereign windows that can be presented to the user in various states (maximized, on all workspaces, etc).

val new_ : unit -> t

Create a new ToplevelLayout

val set_resizable : t -> bool -> unit

Sets whether the layout should allow the user to resize the surface after it has been presented.

val set_maximized : t -> bool -> unit

Sets whether the layout should cause the surface to be maximized when presented.

val set_fullscreen : t -> bool -> [ `monitor | `object_ ] Gobject.obj option -> unit

Sets whether the layout should cause the surface to be fullscreen when presented.

val ref : t -> t

Increases the reference count of @layout.

val get_resizable : t -> bool

Returns whether the layout should allow the user to resize the surface.

val get_maximized : t -> bool * bool

If the layout specifies whether to the toplevel should go maximized, the value pointed to by @maximized is set to %TRUE if it should go fullscreen, or %FALSE, if it should go unmaximized.

val get_fullscreen_monitor : t -> [ `monitor | `object_ ] Gobject.obj option

Returns the monitor that the layout is fullscreening the surface on.

val get_fullscreen : t -> bool * bool

If the layout specifies whether to the toplevel should go fullscreen, the value pointed to by @fullscreen is set to %TRUE if it should go fullscreen, or %FALSE, if it should go unfullscreen.

val equal : t -> t -> bool

Check whether @layout and @other has identical layout properties.

val get_type : unit -> Gobject.Type.t