package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Touchpad_event

type t = [ `touchpad_event | `event ] Gobject.obj
val get_pinch_scale : t -> float

Extracts the scale from a touchpad pinch event.

val get_pinch_angle_delta : t -> float

Extracts the angle delta from a touchpad pinch event.

val get_n_fingers : t -> int

Extracts the number of fingers from a touchpad event.

val get_gesture_phase : t -> Gdk_enums.touchpadgesturephase

Extracts the touchpad gesture phase from a touchpad event.

val get_deltas : t -> float * float

Extracts delta information from a touchpad event.