package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Pixbuf_simple_anim

type t = [ `pixbuf_simple_anim | `pixbuf_animation | `object_ ] Gobject.obj
val new_ : int -> int -> float -> t

Create a new PixbufSimpleAnim

val set_loop : t -> bool -> unit

Sets whether @animation should loop indefinitely when it reaches the end.

val get_loop : t -> bool

Gets whether @animation should loop indefinitely when it reaches the end.

val add_frame : t -> [ `pixbuf | `object_ ] Gobject.obj -> unit

Adds a new frame to @animation. The @pixbuf must have the dimensions specified when the animation was constructed.