package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Buffered_output_stream

type t = [ `buffered_output_stream | `filter_output_stream | `output_stream | `object_ ] Gobject.obj
val new_ : [ `output_stream | `object_ ] Gobject.obj -> t

Create a new BufferedOutputStream

val new_sized : [ `output_stream | `object_ ] Gobject.obj -> Gsize.t -> t

Create a new BufferedOutputStream

val set_buffer_size : t -> Gsize.t -> unit

Sets the size of the internal buffer to @size.

val set_auto_grow : t -> bool -> unit

Sets whether or not the @stream's buffer should automatically grow. If @auto_grow is true, then each write will just make the buffer larger, and you must manually flush the buffer to actually write out the data to the underlying stream.

val get_buffer_size : t -> Gsize.t

Gets the size of the buffer in the @stream.

val get_auto_grow : t -> bool

Checks if the buffer automatically grows as data is added.