package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Converter

type t = [ `converter ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val reset : t -> unit

Resets all internal state in the converter, making it behave as if it was just created. If the converter has any internal state that would produce output then that output is lost.