package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Credentials

type t = [ `credentials | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new Credentials

val to_string : t -> string

Creates a human-readable textual representation of @credentials that can be used in logging and debug messages. The format of the returned string may change in future GLib release.

val set_unix_user : t -> int -> (bool, GError.t) result

Tries to set the UNIX user identifier on @credentials. This method is only available on UNIX platforms.

This operation can fail if #GCredentials is not supported on the OS or if the native credentials type does not contain information about the UNIX user. It can also fail if the OS does not allow the use of "spoofed" credentials.

val is_same_user : t -> t -> (bool, GError.t) result

Checks if @credentials and @other_credentials is the same user.

This operation can fail if #GCredentials is not supported on the the OS.

val get_unix_user : t -> (int, GError.t) result

Tries to get the UNIX user identifier from @credentials. This method is only available on UNIX platforms.

This operation can fail if #GCredentials is not supported on the OS or if the native credentials type does not contain information about the UNIX user.

val get_unix_pid : t -> (int, GError.t) result

Tries to get the UNIX process identifier from @credentials. This method is only available on UNIX platforms.

This operation can fail if #GCredentials is not supported on the OS or if the native credentials type does not contain information about the UNIX process ID.