package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.D_bus_interface_info

type t = [ `d_bus_interface_info ] Gobject.obj

Information about a D-Bus interface.

val ref : t -> t

If @info is statically allocated does nothing. Otherwise increases the reference count.

val lookup_signal : t -> string -> [ `d_bus_signal_info ] Gobject.obj option

Looks up information about a signal.

The cost of this function is O(n) in number of signals unless g_dbus_interface_info_cache_build() has been used on @info.

val lookup_property : t -> string -> [ `d_bus_property_info ] Gobject.obj option

Looks up information about a property.

The cost of this function is O(n) in number of properties unless g_dbus_interface_info_cache_build() has been used on @info.

val lookup_method : t -> string -> [ `d_bus_method_info ] Gobject.obj option

Looks up information about a method.

The cost of this function is O(n) in number of methods unless g_dbus_interface_info_cache_build() has been used on @info.

val cache_release : t -> unit

Decrements the usage count for the cache for @info built by g_dbus_interface_info_cache_build() (if any) and frees the resources used by the cache if the usage count drops to zero.

val cache_build : t -> unit

Builds a lookup-cache to speed up g_dbus_interface_info_lookup_method(), g_dbus_interface_info_lookup_signal() and g_dbus_interface_info_lookup_property().

If this has already been called with @info, the existing cache is used and its use count is increased.

Note that @info cannot be modified until g_dbus_interface_info_cache_release() is called.

val get_type : unit -> Gobject.Type.t