package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.D_bus_interface_skeleton

type t = [ `d_bus_interface_skeleton | `object_ ] Gobject.obj
val unexport_from_connection : t -> [ `d_bus_connection | `object_ ] Gobject.obj -> unit

Stops exporting @interface_ on @connection.

To stop exporting on all connections the interface is exported on, use g_dbus_interface_skeleton_unexport().

val unexport : t -> unit

Stops exporting @interface_ on all connections it is exported on.

To unexport @interface_ from only a single connection, use g_dbus_interface_skeleton_unexport_from_connection()

val set_flags : t -> Gio_enums.dbusinterfaceskeletonflags -> unit

Sets flags describing what the behavior of @skeleton should be.

val has_connection : t -> [ `d_bus_connection | `object_ ] Gobject.obj -> bool

Checks if @interface_ is exported on @connection.

val get_vtable : t -> [ `d_bus_interface_v_table ] Gobject.obj

Gets the interface vtable for the D-Bus interface implemented by @interface_. The returned function pointers should expect @interface_ itself to be passed as @user_data.

val get_properties : t -> Gvariant.t

Gets all D-Bus properties for @interface_.

val get_object_path : t -> string option

Gets the object path that @interface_ is exported on, if any.

val get_info : t -> [ `d_bus_interface_info ] Gobject.obj

Gets D-Bus introspection information for the D-Bus interface implemented by @interface_.

Gets the #GDBusInterfaceSkeletonFlags that describes what the behavior of @interface_

val get_connections : t -> [ `d_bus_connection | `object_ ] Gobject.obj list

Gets a list of the connections that @interface_ is exported on.

val get_connection : t -> [ `d_bus_connection | `object_ ] Gobject.obj option

Gets the first connection that @interface_ is exported on, if any.

val flush : t -> unit

If @interface_ has outstanding changes, request for these changes to be emitted immediately.

For example, an exported D-Bus interface may queue up property changes and emit the `org.freedesktop.DBus.Properties.PropertiesChanged` signal later (e.g. in an idle handler). This technique is useful for collapsing multiple property changes into one.

val export : t -> [ `d_bus_connection | `object_ ] Gobject.obj -> string -> (bool, GError.t) result

Exports @interface_ at @object_path on @connection.

This can be called multiple times to export the same @interface_ onto multiple connections however the @object_path provided must be the same for all connections.

Use g_dbus_interface_skeleton_unexport() to unexport the object.

Get property: g-flags

val set_g_flags : t -> Gio_enums.dbusinterfaceskeletonflags -> unit

Set property: g-flags

val on_g_authorize_method : ?after:bool -> t -> callback: (invocation:[ `d_bus_method_invocation | `object_ ] Gobject.obj -> bool) -> Gobject.Signal.handler_id