package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.D_bus_object_skeleton

type t = [ `d_bus_object_skeleton | `object_ ] Gobject.obj
val new_ : string -> t

Create a new DBusObjectSkeleton

val set_object_path : t -> string -> unit

Sets the object path for @object.

val remove_interface_by_name : t -> string -> unit

Removes the #GDBusInterface with @interface_name from @object.

If no D-Bus interface of the given interface exists, this function does nothing.

val remove_interface : t -> [ `d_bus_interface_skeleton | `object_ ] Gobject.obj -> unit

Removes @interface_ from @object.

val flush : t -> unit

This method simply calls g_dbus_interface_skeleton_flush() on all interfaces belonging to @object. See that method for when flushing is useful.

val add_interface : t -> [ `d_bus_interface_skeleton | `object_ ] Gobject.obj -> unit

Adds @interface_ to @object.

If @object already contains a #GDBusInterfaceSkeleton with the same interface name, it is removed before @interface_ is added.

Note that @object takes its own reference on @interface_ and holds it until removed.

val get_g_object_path : t -> string

Get property: g-object-path

val set_g_object_path : t -> string -> unit

Set property: g-object-path

val on_authorize_method : ?after:bool -> t -> callback: (interface:[ `d_bus_interface_skeleton | `object_ ] Gobject.obj -> invocation:[ `d_bus_method_invocation | `object_ ] Gobject.obj -> bool) -> Gobject.Signal.handler_id