package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Debug_controller_d_bus

type t = [ `debug_controller_d_bus | `object_ ] Gobject.obj
val new_ : [ `d_bus_connection | `object_ ] Gobject.obj -> [ `cancellable | `object_ ] Gobject.obj option -> (t, GError.t) result

Create a new DebugControllerDBus

val stop : t -> unit

Stop the debug controller, unregistering its object from the bus.

Any pending method calls to the object will complete successfully, but new ones will return an error. This method will block until all pending #GDebugControllerDBus::authorize signals have been handled. This is expected to not take long, as it will just be waiting for threads to join. If any #GDebugControllerDBus::authorize signal handlers are still executing in other threads, this will block until after they have returned.

This method will be called automatically when the final reference to the #GDebugControllerDBus is dropped. You may want to call it explicitly to know when the controller has been fully removed from the bus, or to break reference count cycles.

Calling this method from within a #GDebugControllerDBus::authorize signal handler will cause a deadlock and must not be done.

val get_connection : t -> [ `d_bus_connection | `object_ ] Gobject.obj

Get property: connection

val on_authorize : ?after:bool -> t -> callback: (invocation:[ `d_bus_method_invocation | `object_ ] Gobject.obj -> bool) -> Gobject.Signal.handler_id