package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Dtls_client_connection

type t = [ `dtls_client_connection ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val set_validation_flags : t -> Gio_enums.tlscertificateflags -> unit

Sets @conn's validation flags, to override the default set of checks performed when validating a server certificate. By default, %G_TLS_CERTIFICATE_VALIDATE_ALL is used.

This function does not work as originally designed and is impossible to use correctly. See #GDtlsClientConnection:validation-flags for more information.

val set_server_identity : t -> [ `socket_connectable ] Gobject.obj -> unit

Sets @conn's expected server identity, which is used both to tell servers on virtual hosts which certificate to present, and also to let @conn know what name to look for in the certificate when performing %G_TLS_CERTIFICATE_BAD_IDENTITY validation, if enabled.

val get_validation_flags : t -> Gio_enums.tlscertificateflags

Gets @conn's validation flags

This function does not work as originally designed and is impossible to use correctly. See #GDtlsClientConnection:validation-flags for more information.

val get_server_identity : t -> [ `socket_connectable ] Gobject.obj

Gets @conn's expected server identity