package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.File_attribute_matcher

type t = [ `file_attribute_matcher ] Gobject.obj

Determines if a string matches a file attribute.

val new_ : string -> t

Create a new FileAttributeMatcher

val to_string : t -> string

Prints what the matcher is matching against. The format will be equal to the format passed to g_file_attribute_matcher_new(). The output however, might not be identical, as the matcher may decide to use a different order or omit needless parts.

val subtract : t -> t option -> t option

Subtracts all attributes of @subtract from @matcher and returns a matcher that supports those attributes.

Note that currently it is not possible to remove a single attribute when the @matcher matches the whole namespace - or remove a namespace or attribute when the matcher matches everything. This is a limitation of the current implementation, but may be fixed in the future.

val ref : t -> t

References a file attribute matcher.

val matches_only : t -> string -> bool

Checks if an attribute matcher only matches a given attribute. Always returns %FALSE if "*" was used when creating the matcher.

val matches : t -> string -> bool

Checks if an attribute will be matched by an attribute matcher. If the matcher was created with the "*" matching string, this function will always return %TRUE.

val enumerate_next : t -> string option

Gets the next matched attribute from a #GFileAttributeMatcher.

val enumerate_namespace : t -> string -> bool

Checks if the matcher will match all of the keys in a given namespace. This will always return %TRUE if a wildcard character is in use (e.g. if matcher was created with "standard::*" and @ns is "standard", or if matcher was created using "*" and namespace is anything.)

TODO: this is awkwardly worded.

val get_type : unit -> Gobject.Type.t