package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.File_monitor

type t = [ `file_monitor | `object_ ] Gobject.obj
val set_rate_limit : t -> int -> unit

Sets the rate limit to which the @monitor will report consecutive change events to the same file.

val is_cancelled : t -> bool

Returns whether the monitor is canceled.

val emit_event : t -> [ `file ] Gobject.obj -> [ `file ] Gobject.obj -> Gio_enums.filemonitorevent -> unit

Emits the #GFileMonitor::changed signal if a change has taken place. Should be called from file monitor implementations only.

Implementations are responsible to call this method from the thread-default main contextg-main-context-push-thread-default of the thread that the monitor was created in.

val cancel : t -> bool

Cancels a file monitor.

val get_cancelled : t -> bool

Get property: cancelled

val on_changed : ?after:bool -> t -> callback: (file:[ `file ] Gobject.obj -> other_file:[ `file ] Gobject.obj option -> event_type:Gio_enums.filemonitorevent -> unit) -> Gobject.Signal.handler_id