package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Filename_completer

type t = [ `filename_completer | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new FilenameCompleter

val set_dirs_only : t -> bool -> unit

If @dirs_only is %TRUE, @completer will only complete directory names, and not file names.

val get_completions : t -> string -> string array

Gets an array of completion strings for a given initial text.

val get_completion_suffix : t -> string -> string option

Obtains a completion for @initial_text from @completer.

val on_got_completion_data : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id