package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Io_extension

type t = [ `io_extension ] Gobject.obj

#GIOExtension is an opaque data structure and can only be accessed using the following functions.

val get_type : t -> Gobject.Type.t

Gets the type associated with @extension.

val get_priority : t -> int

Gets the priority with which @extension was registered.

val get_name : t -> string

Gets the name under which @extension was registered.

Note that the same type may be registered as extension for multiple extension points, under different names.