package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Io_stream

type t = [ `io_stream | `object_ ] Gobject.obj
val set_pending : t -> (bool, GError.t) result

Sets @stream to have actions pending. If the pending flag is already set or @stream is closed, it will return %FALSE and set @error.

val is_closed : t -> bool

Checks if a stream is closed.

val has_pending : t -> bool

Checks if a stream has pending actions.

val get_output_stream : t -> [ `output_stream | `object_ ] Gobject.obj

Gets the output stream for this object. This is used for writing.

val get_input_stream : t -> [ `input_stream | `object_ ] Gobject.obj

Gets the input stream for this object. This is used for reading.

val close_finish : t -> [ `async_result ] Gobject.obj -> (bool, GError.t) result

Closes a stream.

val close : t -> [ `cancellable | `object_ ] Gobject.obj option -> (bool, GError.t) result

Closes the stream, releasing resources related to it. This will also close the individual input and output streams, if they are not already closed.

Once the stream is closed, all other operations will return %G_IO_ERROR_CLOSED. Closing a stream multiple times will not return an error.

Closing a stream will automatically flush any outstanding buffers in the stream.

Streams will be automatically closed when the last reference is dropped, but you might want to call this function to make sure resources are released as early as possible.

Some streams might keep the backing store of the stream (e.g. a file descriptor) open after the stream is closed. See the documentation for the individual stream for details.

On failure the first error that happened will be reported, but the close operation will finish as much as possible. A stream that failed to close will still return %G_IO_ERROR_CLOSED for all operations. Still, it is important to check and report the error to the user, otherwise there might be a loss of data as all data might not be written.

If @cancellable is not NULL, then the operation can be cancelled by triggering the cancellable object from another thread. If the operation was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. Cancelling a close will still leave the stream closed, but some streams can use a faster close that doesn't block to e.g. check errors.

The default implementation of this method just calls close on the individual input/output streams.

val clear_pending : t -> unit

Clears the pending flag on @stream.

val get_closed : t -> bool

Get property: closed