package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Menu_attribute_iter

type t = [ `menu_attribute_iter | `object_ ] Gobject.obj
val next : t -> bool

Attempts to advance the iterator to the next (possibly first) attribute.

%TRUE is returned on success, or %FALSE if there are no more attributes.

You must call this function when you first acquire the iterator to advance it to the first attribute (and determine if the first attribute exists at all).

val get_value : t -> Gvariant.t

Gets the value of the attribute at the current iterator position.

The iterator is not advanced.

val get_name : t -> string

Gets the name of the attribute at the current iterator position, as a string.

The iterator is not advanced.