package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Menu_link_iter

type t = [ `menu_link_iter | `object_ ] Gobject.obj
val next : t -> bool

Attempts to advance the iterator to the next (possibly first) link.

%TRUE is returned on success, or %FALSE if there are no more links.

You must call this function when you first acquire the iterator to advance it to the first link (and determine if the first link exists at all).

val get_value : t -> [ `menu_model | `object_ ] Gobject.obj

Gets the linked #GMenuModel at the current iterator position.

The iterator is not advanced.

val get_name : t -> string

Gets the name of the link at the current iterator position.

The iterator is not advanced.