package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Network_service

type t = [ `network_service | `object_ ] Gobject.obj
val new_ : string -> string -> string -> t

Create a new NetworkService

val set_scheme : t -> string -> unit

Set's the URI scheme used to resolve proxies. By default, the service name is used as scheme.

val get_service : t -> string

Gets @srv's service name (eg, "ldap").

val get_scheme : t -> string

Gets the URI scheme used to resolve proxies. By default, the service name is used as scheme.

val get_protocol : t -> string

Gets @srv's protocol name (eg, "tcp").

val get_domain : t -> string

Gets the domain that @srv serves. This might be either UTF-8 or ASCII-encoded, depending on what @srv was created with.