package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Output_message

type t = [ `output_message ] Gobject.obj

Structure used for scatter/gather data output when sending multiple messages or packets in one go. You generally pass in an array of #GOutputVectors and the operation will use all the buffers as if they were one buffer.

If @address is %NULL then the message is sent to the default receiver (as previously set by g_socket_connect()).