package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Remote_action_group

type t = [ `remote_action_group ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val change_action_state_full : t -> string -> Gvariant.t -> Gvariant.t -> unit

Changes the state of a remote action.

This is the same as g_action_group_change_action_state() except that it allows for provision of "platform data" to be sent along with the state change request. This typically contains details such as the user interaction timestamp or startup notification information.

@platform_data must be non-%NULL and must have the type %G_VARIANT_TYPE_VARDICT. If it is floating, it will be consumed.

val activate_action_full : t -> string -> Gvariant.t option -> Gvariant.t -> unit

Activates the remote action.

This is the same as g_action_group_activate_action() except that it allows for provision of "platform data" to be sent along with the activation request. This typically contains details such as the user interaction timestamp or startup notification information.

@platform_data must be non-%NULL and must have the type %G_VARIANT_TYPE_VARDICT. If it is floating, it will be consumed.