package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Seekable

type t = [ `seekable ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val truncate : t -> int64 -> [ `cancellable | `object_ ] Gobject.obj option -> (bool, GError.t) result

Sets the length of the stream to @offset. If the stream was previously larger than @offset, the extra data is discarded. If the stream was previously shorter than @offset, it is extended with NUL ('\0') bytes.

If @cancellable is not %NULL, then the operation can be cancelled by triggering the cancellable object from another thread. If the operation was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. If an operation was partially finished when the operation was cancelled the partial result will be returned, without an error.

val tell : t -> int64

Tells the current position within the stream.

val can_truncate : t -> bool

Tests if the length of the stream can be adjusted with g_seekable_truncate().

val can_seek : t -> bool

Tests if the stream supports the #GSeekableIface.