package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Settings_schema_source

type t = [ `settings_schema_source ] Gobject.obj

This is an opaque structure type. You may not access it directly.

val new_from_directory : string -> t option -> bool -> (t, GError.t) result

Create a new SettingsSchemaSource

val ref : t -> t

Increase the reference count of @source, returning a new reference.

val lookup : t -> string -> bool -> [ `settings_schema ] Gobject.obj option

Looks up a schema with the identifier @schema_id in @source.

This function is not required for normal uses of #GSettings but it may be useful to authors of plugin management systems or to those who want to introspect the content of schemas.

If the schema isn't found directly in @source and @recursive is %TRUE then the parent sources will also be checked.

If the schema isn't found, %NULL is returned.

val get_type : unit -> Gobject.Type.t