package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Simple_action_group

type t = [ `simple_action_group | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new SimpleActionGroup

val remove : t -> string -> unit

Removes the named action from the action group.

If no action of this name is in the group then nothing happens.

val lookup : t -> string -> [ `action ] Gobject.obj

Looks up the action with the name @action_name in the group.

If no such action exists, returns %NULL.

val insert : t -> [ `action ] Gobject.obj -> unit

Adds an action to the action group.

If the action group already contains an action with the same name as @action then the old action is dropped from the group.

The action group takes its own reference on @action.