package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Socket_address_enumerator

type t = [ `socket_address_enumerator | `object_ ] Gobject.obj
val next_finish : t -> [ `async_result ] Gobject.obj -> ([ `socket_address | `object_ ] Gobject.obj option, GError.t) result

Retrieves the result of a completed call to g_socket_address_enumerator_next_async(). See g_socket_address_enumerator_next() for more information about error handling.

val next : t -> [ `cancellable | `object_ ] Gobject.obj option -> ([ `socket_address | `object_ ] Gobject.obj option, GError.t) result

Retrieves the next #GSocketAddress from @enumerator. Note that this may block for some amount of time. (Eg, a #GNetworkAddress may need to do a DNS lookup before it can return an address.) Use g_socket_address_enumerator_next_async() if you need to avoid blocking.

If @enumerator is expected to yield addresses, but for some reason is unable to (eg, because of a DNS error), then the first call to g_socket_address_enumerator_next() will return an appropriate error in *@error. However, if the first call to g_socket_address_enumerator_next() succeeds, then any further internal errors (other than @cancellable being triggered) will be ignored.