package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Socket_connectable

type t = [ `socket_connectable ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val to_string : t -> string

Format a #GSocketConnectable as a string. This is a human-readable format for use in debugging output, and is not a stable serialization format. It is not suitable for use in user interfaces as it exposes too much information for a user.

If the #GSocketConnectable implementation does not support string formatting, the implementation’s type name will be returned as a fallback.

val proxy_enumerate : t -> [ `socket_address_enumerator | `object_ ] Gobject.obj

Creates a #GSocketAddressEnumerator for @connectable that will return a #GProxyAddress for each of its addresses that you must connect to via a proxy.

If @connectable does not implement g_socket_connectable_proxy_enumerate(), this will fall back to calling g_socket_connectable_enumerate().

val enumerate : t -> [ `socket_address_enumerator | `object_ ] Gobject.obj

Creates a #GSocketAddressEnumerator for @connectable.