package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Socket_control_message

type t = [ `socket_control_message | `object_ ] Gobject.obj
val get_size : t -> Gsize.t

Returns the space required for the control message, not including headers or alignment.

val get_msg_type : t -> int

Returns the protocol specific type of the control message. For instance, for UNIX fd passing this would be SCM_RIGHTS.

val get_level : t -> int

Returns the "level" (i.e. the originating protocol) of the control message. This is often SOL_SOCKET.