package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Static_resource

type t = [ `static_resource ] Gobject.obj

#GStaticResource is an opaque data structure and can only be accessed using the following functions.

val init : t -> unit

Initializes a GResource from static data using a GStaticResource.

This is normally used by code generated by glib-compile-resourcesglib-compile-resources and is not typically used by other code.

val get_resource : t -> [ `resource ] Gobject.obj

Gets the GResource that was registered by a call to g_static_resource_init().

This is normally used by code generated by glib-compile-resourcesglib-compile-resources and is not typically used by other code.

val fini : t -> unit

Finalized a GResource initialized by g_static_resource_init().

This is normally used by code generated by glib-compile-resourcesglib-compile-resources and is not typically used by other code.