package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Themed_icon

type t = [ `themed_icon | `object_ ] Gobject.obj
val new_ : string -> t

Create a new ThemedIcon

val new_from_names : string array -> int -> t

Create a new ThemedIcon

val new_with_default_fallbacks : string -> t

Create a new ThemedIcon

val prepend_name : t -> string -> unit

Prepend a name to the list of icons from within @icon.

Note that doing so invalidates the hash computed by prior calls to g_icon_hash().

val get_names : t -> string array

Gets the names of icons from within @icon.

val append_name : t -> string -> unit

Append a name to the list of icons from within @icon.

Note that doing so invalidates the hash computed by prior calls to g_icon_hash().

val get_use_default_fallbacks : t -> bool

Get property: use-default-fallbacks