package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Tls_password

type t = [ `tls_password | `object_ ] Gobject.obj
val new_ : Gio_enums.tlspasswordflags -> string -> t

Create a new TlsPassword

val set_warning : t -> string -> unit

Set a user readable translated warning. Usually this warning is a representation of the password flags returned from g_tls_password_get_flags().

val set_flags : t -> Gio_enums.tlspasswordflags -> unit

Set flags about the password.

val set_description : t -> string -> unit

Set a description string about what the password will be used for.

val get_warning : t -> string

Get a user readable translated warning. Usually this warning is a representation of the password flags returned from g_tls_password_get_flags().

val get_flags : t -> Gio_enums.tlspasswordflags

Get flags about the password.

val get_description : t -> string

Get a description string about what the password will be used for.