package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Unix_mount_monitor

type t = [ `unix_mount_monitor | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new UnixMountMonitor

val set_rate_limit : t -> int -> unit

This function does nothing.

Before 2.44, this was a partially-effective way of controlling the rate at which events would be reported under some uncommon circumstances. Since @mount_monitor is a singleton, it also meant that calling this function would have side effects for other users of the monitor.

val on_mountpoints_changed : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_mounts_changed : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id