package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Unix_mount_point

type t = [ `unix_mount_point ] Gobject.obj

Defines a Unix mount point (e.g. <filename>/dev</filename>). This corresponds roughly to a fstab entry.

val is_user_mountable : t -> bool

Checks if a unix mount point is mountable by the user.

val is_readonly : t -> bool

Checks if a unix mount point is read only.

val is_loopback : t -> bool

Checks if a unix mount point is a loopback device.

val guess_symbolic_icon : t -> [ `icon ] Gobject.obj

Guesses the symbolic icon of a Unix mount point.

val guess_name : t -> string

Guesses the name of a Unix mount point. The result is a translated string.

val guess_icon : t -> [ `icon ] Gobject.obj

Guesses the icon of a Unix mount point.

val guess_can_eject : t -> bool

Guesses whether a Unix mount point can be ejected.

val get_options : t -> string option

Gets the options for the mount point.

val get_mount_path : t -> string

Gets the mount path for a unix mount point.

val get_fs_type : t -> string

Gets the file system type for the mount point.

val get_device_path : t -> string

Gets the device path for a unix mount point.

val compare : t -> t -> int

Compares two unix mount points.

val get_type : unit -> Gobject.Type.t