package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Unix_output_stream

type t = [ `unix_output_stream | `output_stream | `object_ ] Gobject.obj
val new_ : int -> bool -> t

Create a new UnixOutputStream

val set_close_fd : t -> bool -> unit

Sets whether the file descriptor of @stream shall be closed when the stream is closed.

val get_fd : t -> int

Return the UNIX file descriptor that the stream writes to.

val get_close_fd : t -> bool

Returns whether the file descriptor of @stream will be closed when the stream is closed.