package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Vfs

type t = [ `vfs | `object_ ] Gobject.obj
val unregister_uri_scheme : t -> string -> bool

Unregisters the URI handler for @scheme previously registered with g_vfs_register_uri_scheme().

val parse_name : t -> string -> [ `file ] Gobject.obj

This operation never fails, but the returned object might not support any I/O operations if the @parse_name cannot be parsed by the #GVfs module.

val is_active : t -> bool

Checks if the VFS is active.

val get_supported_uri_schemes : t -> string array

Gets a list of URI schemes supported by @vfs.

val get_file_for_uri : t -> string -> [ `file ] Gobject.obj

Gets a #GFile for @uri.

This operation never fails, but the returned object might not support any I/O operation if the URI is malformed or if the URI scheme is not supported.

val get_file_for_path : t -> string -> [ `file ] Gobject.obj

Gets a #GFile for @path.