package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Volume_monitor

type t = [ `volume_monitor | `object_ ] Gobject.obj
val get_volumes : t -> [ `volume ] Gobject.obj list

Gets a list of the volumes on the system.

The returned list should be freed with g_list_free(), after its elements have been unreffed with g_object_unref().

val get_volume_for_uuid : t -> string -> [ `volume ] Gobject.obj option

Finds a #GVolume object by its UUID (see g_volume_get_uuid())

val get_mounts : t -> [ `mount ] Gobject.obj list

Gets a list of the mounts on the system.

The returned list should be freed with g_list_free(), after its elements have been unreffed with g_object_unref().

val get_mount_for_uuid : t -> string -> [ `mount ] Gobject.obj option

Finds a #GMount object by its UUID (see g_mount_get_uuid())

val get_connected_drives : t -> [ `drive ] Gobject.obj list

Gets a list of drives connected to the system.

The returned list should be freed with g_list_free(), after its elements have been unreffed with g_object_unref().

val on_drive_changed : ?after:bool -> t -> callback:(drive:[ `drive ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_drive_connected : ?after:bool -> t -> callback:(drive:[ `drive ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_drive_disconnected : ?after:bool -> t -> callback:(drive:[ `drive ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_drive_eject_button : ?after:bool -> t -> callback:(drive:[ `drive ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_drive_stop_button : ?after:bool -> t -> callback:(drive:[ `drive ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_mount_added : ?after:bool -> t -> callback:(mount:[ `mount ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_mount_changed : ?after:bool -> t -> callback:(mount:[ `mount ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_mount_pre_unmount : ?after:bool -> t -> callback:(mount:[ `mount ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_mount_removed : ?after:bool -> t -> callback:(mount:[ `mount ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_volume_added : ?after:bool -> t -> callback:(volume:[ `volume ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_volume_changed : ?after:bool -> t -> callback:(volume:[ `volume ] Gobject.obj -> unit) -> Gobject.Signal.handler_id
val on_volume_removed : ?after:bool -> t -> callback:(volume:[ `volume ] Gobject.obj -> unit) -> Gobject.Signal.handler_id