package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Zlib_compressor

type t = [ `zlib_compressor | `object_ ] Gobject.obj
val new_ : Gio_enums.zlibcompressorformat -> int -> t

Create a new ZlibCompressor

val set_file_info : t -> [ `file_info | `object_ ] Gobject.obj option -> unit

Sets @file_info in @compressor. If non-%NULL, and @compressor's #GZlibCompressor:format property is %G_ZLIB_COMPRESSOR_FORMAT_GZIP, it will be used to set the file name and modification time in the GZIP header of the compressed data.

Note: it is an error to call this function while a compression is in progress; it may only be called immediately after creation of @compressor, or after resetting it with g_converter_reset().

val get_file_info : t -> [ `file_info | `object_ ] Gobject.obj option

Returns the #GZlibCompressor:file-info property.

val get_format : t -> Gio_enums.zlibcompressorformat

Get property: format

val get_level : t -> int

Get property: level