package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ocgtk_gio.Gio_enums

type bustype = [
  1. | `STARTER
    (*

    Not a message bus.

    *)
  2. | `NONE
    (*

    The system-wide message bus.

    *)
  3. | `SYSTEM
    (*

    The login session message bus.

    *)
  4. | `SESSION
]
val bustype_of_int : int -> bustype
val bustype_to_int : bustype -> int
type converterresult = [
  1. | `ERROR
    (*

    Some data was consumed or produced

    *)
  2. | `CONVERTED
    (*

    The conversion is finished

    *)
  3. | `FINISHED
    (*

    Flushing is finished

    *)
  4. | `FLUSHED
]
val converterresult_of_int : int -> converterresult
val converterresult_to_int : converterresult -> int
type credentialstype = [
  1. | `INVALID
    (*

    The native credentials type is a `struct ucred`.

    *)
  2. | `LINUX_UCRED
    (*

    The native credentials type is a `struct cmsgcred`.

    *)
  3. | `FREEBSD_CMSGCRED
    (*

    The native credentials type is a `struct sockpeercred`. Added in 2.30.

    *)
  4. | `OPENBSD_SOCKPEERCRED
    (*

    The native credentials type is a `ucred_t`. Added in 2.40.

    *)
  5. | `SOLARIS_UCRED
    (*

    The native credentials type is a `struct unpcbid`. Added in 2.42.

    *)
  6. | `NETBSD_UNPCBID
    (*

    The native credentials type is a `struct xucred`. Added in 2.66.

    *)
  7. | `APPLE_XUCRED
    (*

    The native credentials type is a PID `DWORD`. Added in 2.72.

    *)
  8. | `WIN32_PID
]
val credentialstype_of_int : int -> credentialstype
val credentialstype_to_int : credentialstype -> int
type dbuserror = [
  1. | `FAILED
    (*

    There was not enough memory to complete an operation.

    *)
  2. | `NO_MEMORY
    (*

    The bus doesn't know how to launch a service to supply the bus name you wanted.

    *)
  3. | `SERVICE_UNKNOWN
    (*

    The bus name you referenced doesn't exist (i.e. no application owns it).

    *)
  4. | `NAME_HAS_NO_OWNER
    (*

    No reply to a message expecting one, usually means a timeout occurred.

    *)
  5. | `NO_REPLY
    (*

    Something went wrong reading or writing to a socket, for example.

    *)
  6. | `IO_ERROR
    (*

    A D-Bus bus address was malformed.

    *)
  7. | `BAD_ADDRESS
    (*

    Requested operation isn't supported (like ENOSYS on UNIX).

    *)
  8. | `NOT_SUPPORTED
    (*

    Some limited resource is exhausted.

    *)
  9. | `LIMITS_EXCEEDED
    (*

    Security restrictions don't allow doing what you're trying to do.

    *)
  10. | `ACCESS_DENIED
    (*

    Authentication didn't work.

    *)
  11. | `AUTH_FAILED
    (*

    Unable to connect to server (probably caused by ECONNREFUSED on a socket).

    *)
  12. | `NO_SERVER
    (*

    Certain timeout errors, possibly ETIMEDOUT on a socket. Note that %G_DBUS_ERROR_NO_REPLY is used for message reply timeouts. Warning: this is confusingly-named given that %G_DBUS_ERROR_TIMED_OUT also exists. We can't fix it for compatibility reasons so just be careful.

    *)
  13. | `TIMEOUT
    (*

    No network access (probably ENETUNREACH on a socket).

    *)
  14. | `NO_NETWORK
    (*

    Can't bind a socket since its address is in use (i.e. EADDRINUSE).

    *)
  15. | `ADDRESS_IN_USE
    (*

    The connection is disconnected and you're trying to use it.

    *)
  16. | `DISCONNECTED
    (*

    Invalid arguments passed to a method call.

    *)
  17. | `INVALID_ARGS
    (*

    Missing file.

    *)
  18. | `FILE_NOT_FOUND
    (*

    Existing file and the operation you're using does not silently overwrite.

    *)
  19. | `FILE_EXISTS
    (*

    Method name you invoked isn't known by the object you invoked it on.

    *)
  20. | `UNKNOWN_METHOD
    (*

    Certain timeout errors, e.g. while starting a service. Warning: this is confusingly-named given that %G_DBUS_ERROR_TIMEOUT also exists. We can't fix it for compatibility reasons so just be careful.

    *)
  21. | `TIMED_OUT
    (*

    Tried to remove or modify a match rule that didn't exist.

    *)
  22. | `MATCH_RULE_NOT_FOUND
    (*

    The match rule isn't syntactically valid.

    *)
  23. | `MATCH_RULE_INVALID
    (*

    While starting a new process, the exec() call failed.

    *)
  24. | `SPAWN_EXEC_FAILED
    (*

    While starting a new process, the fork() call failed.

    *)
  25. | `SPAWN_FORK_FAILED
    (*

    While starting a new process, the child exited with a status code.

    *)
  26. | `SPAWN_CHILD_EXITED
    (*

    While starting a new process, the child exited on a signal.

    *)
  27. | `SPAWN_CHILD_SIGNALED
    (*

    While starting a new process, something went wrong.

    *)
  28. | `SPAWN_FAILED
    (*

    We failed to setup the environment correctly.

    *)
  29. | `SPAWN_SETUP_FAILED
    (*

    We failed to setup the config parser correctly.

    *)
  30. | `SPAWN_CONFIG_INVALID
    (*

    Bus name was not valid.

    *)
  31. | `SPAWN_SERVICE_INVALID
    (*

    Service file not found in system-services directory.

    *)
  32. | `SPAWN_SERVICE_NOT_FOUND
    (*

    Permissions are incorrect on the setuid helper.

    *)
  33. | `SPAWN_PERMISSIONS_INVALID
    (*

    Service file invalid (Name, User or Exec missing).

    *)
  34. | `SPAWN_FILE_INVALID
    (*

    Tried to get a UNIX process ID and it wasn't available.

    *)
  35. | `SPAWN_NO_MEMORY
    (*

    Tried to get a UNIX process ID and it wasn't available.

    *)
  36. | `UNIX_PROCESS_ID_UNKNOWN
    (*

    A type signature is not valid.

    *)
  37. | `INVALID_SIGNATURE
    (*

    A file contains invalid syntax or is otherwise broken.

    *)
  38. | `INVALID_FILE_CONTENT
    (*

    Asked for SELinux security context and it wasn't available.

    *)
  39. | `SELINUX_SECURITY_CONTEXT_UNKNOWN
    (*

    Asked for ADT audit data and it wasn't available.

    *)
  40. | `ADT_AUDIT_DATA_UNKNOWN
    (*

    There's already an object with the requested object path.

    *)
  41. | `OBJECT_PATH_IN_USE
    (*

    Object you invoked a method on isn't known. Since 2.42

    *)
  42. | `UNKNOWN_OBJECT
    (*

    Interface you invoked a method on isn't known by the object. Since 2.42

    *)
  43. | `UNKNOWN_INTERFACE
    (*

    Property you tried to access isn't known by the object. Since 2.42

    *)
  44. | `UNKNOWN_PROPERTY
    (*

    Property you tried to set is read-only. Since 2.42

    *)
  45. | `PROPERTY_READ_ONLY
]
val dbuserror_of_int : int -> dbuserror
val dbuserror_to_int : dbuserror -> int
type dbusmessagebyteorder = [
  1. | `BIG_ENDIAN
    (*

    The byte order is little endian.

    *)
  2. | `LITTLE_ENDIAN
]
val dbusmessagebyteorder_of_int : int -> dbusmessagebyteorder
val dbusmessagebyteorder_to_int : dbusmessagebyteorder -> int
type dbusmessageheaderfield = [
  1. | `INVALID
    (*

    The object path.

    *)
  2. | `PATH
    (*

    The interface name.

    *)
  3. | `INTERFACE
    (*

    The method or signal name.

    *)
  4. | `MEMBER
    (*

    The name of the error that occurred.

    *)
  5. | `ERROR_NAME
    (*

    The serial number the message is a reply to.

    *)
  6. | `REPLY_SERIAL
    (*

    The name the message is intended for.

    *)
  7. | `DESTINATION
    (*

    Unique name of the sender of the message (filled in by the bus).

    *)
  8. | `SENDER
    (*

    The signature of the message body.

    *)
  9. | `SIGNATURE
    (*

    The number of UNIX file descriptors that accompany the message.

    *)
  10. | `NUM_UNIX_FDS
]
val dbusmessageheaderfield_of_int : int -> dbusmessageheaderfield
val dbusmessageheaderfield_to_int : dbusmessageheaderfield -> int
type dbusmessagetype = [
  1. | `INVALID
    (*

    Method call.

    *)
  2. | `METHOD_CALL
    (*

    Method reply.

    *)
  3. | `METHOD_RETURN
    (*

    Error reply.

    *)
  4. | `ERROR
    (*

    Signal emission.

    *)
  5. | `SIGNAL
]
val dbusmessagetype_of_int : int -> dbusmessagetype
val dbusmessagetype_to_int : dbusmessagetype -> int
type datastreambyteorder = [
  1. | `BIG_ENDIAN
    (*

    Selects Little Endian byte order.

    *)
  2. | `LITTLE_ENDIAN
    (*

    Selects endianness based on host machine's architecture.

    *)
  3. | `HOST_ENDIAN
]
val datastreambyteorder_of_int : int -> datastreambyteorder
val datastreambyteorder_to_int : datastreambyteorder -> int
type datastreamnewlinetype = [
  1. | `LF
    (*

    Selects "CR" line endings.

    *)
  2. | `CR
    (*

    Selects "CR, LF" line ending, common on Microsoft Windows.

    *)
  3. | `CR_LF
    (*

    Automatically try to handle any line ending type.

    *)
  4. | `ANY
]
val datastreamnewlinetype_of_int : int -> datastreamnewlinetype
val datastreamnewlinetype_to_int : datastreamnewlinetype -> int
type drivestartstoptype = [
  1. | `UNKNOWN
    (*

    The stop method will physically shut down the drive and e.g. power down the port the drive is attached to.

    *)
  2. | `SHUTDOWN
    (*

    The start/stop methods are used for connecting/disconnect to the drive over the network.

    *)
  3. | `NETWORK
    (*

    The start/stop methods will assemble/disassemble a virtual drive from several physical drives.

    *)
  4. | `MULTIDISK
    (*

    The start/stop methods will unlock/lock the disk (for example using the ATA <quote>SECURITY UNLOCK DEVICE</quote> command)

    *)
  5. | `PASSWORD
]
val drivestartstoptype_of_int : int -> drivestartstoptype
val drivestartstoptype_to_int : drivestartstoptype -> int
type emblemorigin = [
  1. | `UNKNOWN
    (*

    Emblem adds device-specific information

    *)
  2. | `DEVICE
    (*

    Emblem depicts live metadata, such as "readonly"

    *)
  3. | `LIVEMETADATA
    (*

    Emblem comes from a user-defined tag, e.g. set by nautilus (in the future)

    *)
  4. | `TAG
]
val emblemorigin_of_int : int -> emblemorigin
val emblemorigin_to_int : emblemorigin -> int
type fileattributestatus = [
  1. | `UNSET
    (*

    Attribute value is set.

    *)
  2. | `SET
    (*

    Indicates an error in setting the value.

    *)
  3. | `ERROR_SETTING
]
val fileattributestatus_of_int : int -> fileattributestatus
val fileattributestatus_to_int : fileattributestatus -> int
type fileattributetype = [
  1. | `INVALID
    (*

    a null terminated UTF8 string.

    *)
  2. | `STRING
    (*

    a zero terminated string of non-zero bytes.

    *)
  3. | `BYTE_STRING
    (*

    a boolean value.

    *)
  4. | `BOOLEAN
    (*

    an unsigned 4-byte/32-bit integer.

    *)
  5. | `UINT32
    (*

    a signed 4-byte/32-bit integer.

    *)
  6. | `INT32
    (*

    an unsigned 8-byte/64-bit integer.

    *)
  7. | `UINT64
    (*

    a signed 8-byte/64-bit integer.

    *)
  8. | `INT64
    (*

    a #GObject.

    *)
  9. | `OBJECT
    (*

    a %NULL terminated char **. Since 2.22

    *)
  10. | `STRINGV
]
val fileattributetype_of_int : int -> fileattributetype
val fileattributetype_to_int : fileattributetype -> int
type filemonitorevent = [
  1. | `CHANGED
    (*

    a hint that this was probably the last change in a set of changes.

    *)
  2. | `CHANGES_DONE_HINT
    (*

    a file was deleted.

    *)
  3. | `DELETED
    (*

    a file was created.

    *)
  4. | `CREATED
    (*

    a file attribute was changed.

    *)
  5. | `ATTRIBUTE_CHANGED
    (*

    the file location will soon be unmounted.

    *)
  6. | `PRE_UNMOUNT
    (*

    the file location was unmounted.

    *)
  7. | `UNMOUNTED
    (*

    the file was moved -- only sent if the (deprecated) %G_FILE_MONITOR_SEND_MOVED flag is set

    *)
  8. | `MOVED
    (*

    the file was renamed within the current directory -- only sent if the %G_FILE_MONITOR_WATCH_MOVES flag is set. Since: 2.46.

    *)
  9. | `RENAMED
    (*

    the file was moved into the monitored directory from another location -- only sent if the %G_FILE_MONITOR_WATCH_MOVES flag is set. Since: 2.46.

    *)
  10. | `MOVED_IN
    (*

    the file was moved out of the monitored directory to another location -- only sent if the %G_FILE_MONITOR_WATCH_MOVES flag is set. Since: 2.46

    *)
  11. | `MOVED_OUT
]
val filemonitorevent_of_int : int -> filemonitorevent
val filemonitorevent_to_int : filemonitorevent -> int
type filetype = [
  1. | `UNKNOWN
    (*

    File handle represents a regular file.

    *)
  2. | `REGULAR
    (*

    File handle represents a directory.

    *)
  3. | `DIRECTORY
    (*

    File handle represents a symbolic link (Unix systems).

    *)
  4. | `SPECIAL
    (*

    File is a shortcut (Windows systems).

    *)
  5. | `SHORTCUT
    (*

    File is a mountable location.

    *)
  6. | `MOUNTABLE
]
val filetype_of_int : int -> filetype
val filetype_to_int : filetype -> int
type filesystempreviewtype = [
  1. | `IF_ALWAYS
    (*

    Preview files if user has requested preview of "local" files.

    *)
  2. | `IF_LOCAL
    (*

    Never preview files.

    *)
  3. | `NEVER
]
val filesystempreviewtype_of_int : int -> filesystempreviewtype
val filesystempreviewtype_to_int : filesystempreviewtype -> int
type ioerrorenum = [
  1. | `FAILED
    (*

    File not found.

    *)
  2. | `NOT_FOUND
    (*

    File already exists.

    *)
  3. | `EXISTS
    (*

    File is a directory.

    *)
  4. | `IS_DIRECTORY
    (*

    File is not a directory.

    *)
  5. | `NOT_DIRECTORY
    (*

    File is a directory that isn't empty.

    *)
  6. | `NOT_EMPTY
    (*

    File is not a regular file.

    *)
  7. | `NOT_REGULAR_FILE
    (*

    File is not a symbolic link.

    *)
  8. | `NOT_MOUNTABLE_FILE
    (*

    Filename is too many characters.

    *)
  9. | `FILENAME_TOO_LONG
    (*

    Filename is invalid or contains invalid characters.

    *)
  10. | `INVALID_FILENAME
    (*

    File contains too many symbolic links.

    *)
  11. | `NO_SPACE
    (*

    Invalid argument.

    *)
  12. | `INVALID_ARGUMENT
    (*

    Permission denied.

    *)
  13. | `PERMISSION_DENIED
    (*

    Operation (or one of its parameters) not supported

    *)
  14. | `NOT_SUPPORTED
    (*

    File isn't mounted.

    *)
  15. | `NOT_MOUNTED
    (*

    File is already mounted.

    *)
  16. | `ALREADY_MOUNTED
    (*

    File was closed.

    *)
  17. | `CLOSED
    (*

    Operation was cancelled. See #GCancellable.

    *)
  18. | `CANCELLED
    (*

    Operations are still pending.

    *)
  19. | `PENDING
    (*

    File is read only.

    *)
  20. | `READ_ONLY
    (*

    Backup couldn't be created.

    *)
  21. | `CANT_CREATE_BACKUP
    (*

    File's Entity Tag was incorrect.

    *)
  22. | `WRONG_ETAG
    (*

    Operation timed out.

    *)
  23. | `TIMED_OUT
    (*

    Operation would be recursive.

    *)
  24. | `WOULD_RECURSE
    (*

    File is busy.

    *)
  25. | `BUSY
    (*

    Operation would block.

    *)
  26. | `WOULD_BLOCK
    (*

    Host couldn't be found (remote operations).

    *)
  27. | `HOST_NOT_FOUND
    (*

    Operation would merge files.

    *)
  28. | `WOULD_MERGE
    (*

    Operation failed and a helper program has already interacted with the user. Do not display any error dialog.

    *)
  29. | `FAILED_HANDLED
    (*

    The current process has too many files open and can't open any more. Duplicate descriptors do count toward this limit. Since 2.20

    *)
  30. | `TOO_MANY_OPEN_FILES
    (*

    The object has not been initialized. Since 2.22

    *)
  31. | `NOT_INITIALIZED
    (*

    The requested address is already in use. Since 2.22

    *)
  32. | `ADDRESS_IN_USE
    (*

    Need more input to finish operation. Since 2.24

    *)
  33. | `PARTIAL_INPUT
    (*

    The input data was invalid. Since 2.24

    *)
  34. | `INVALID_DATA
    (*

    A remote object generated an error that doesn't correspond to a locally registered #GError error domain. Use g_dbus_error_get_remote_error() to extract the D-Bus error name and g_dbus_error_strip_remote_error() to fix up the message so it matches what was received on the wire. Since 2.26.

    *)
  35. | `DBUS_ERROR
    (*

    Host unreachable. Since 2.26

    *)
  36. | `HOST_UNREACHABLE
    (*

    Network unreachable. Since 2.26

    *)
  37. | `NETWORK_UNREACHABLE
    (*

    Connection refused. Since 2.26

    *)
  38. | `CONNECTION_REFUSED
    (*

    Connection to proxy server failed. Since 2.26

    *)
  39. | `PROXY_FAILED
    (*

    Proxy authentication failed. Since 2.26

    *)
  40. | `PROXY_AUTH_FAILED
    (*

    Proxy server needs authentication. Since 2.26

    *)
  41. | `PROXY_NEED_AUTH
    (*

    Proxy connection is not allowed by ruleset. Since 2.26

    *)
  42. | `PROXY_NOT_ALLOWED
    (*

    Broken pipe. Since 2.36

    *)
  43. | `BROKEN_PIPE
    (*

    Connection closed by peer. Note that this is the same code as %G_IO_ERROR_BROKEN_PIPE; before 2.44 some "connection closed" errors returned %G_IO_ERROR_BROKEN_PIPE, but others returned %G_IO_ERROR_FAILED. Now they should all return the same value, which has this more logical name. Since 2.44.

    *)
  44. | `CONNECTION_CLOSED
    (*

    Transport endpoint is not connected. Since 2.44

    *)
  45. | `NOT_CONNECTED
    (*

    Message too large. Since 2.48.

    *)
  46. | `MESSAGE_TOO_LARGE
    (*

    No such device found. Since 2.74

    *)
  47. | `NO_SUCH_DEVICE
    (*

    Destination address unset. Since 2.80

    *)
  48. | `DESTINATION_UNSET
]
val ioerrorenum_of_int : int -> ioerrorenum
val ioerrorenum_to_int : ioerrorenum -> int
type iomodulescopeflags = [
  1. | `NONE
    (*

    When using this scope to load or scan modules, automatically block a modules which has the same base basename as previously loaded module.

    *)
  2. | `BLOCK_DUPLICATES
]
val iomodulescopeflags_of_int : int -> iomodulescopeflags
val iomodulescopeflags_to_int : iomodulescopeflags -> int
type memorymonitorwarninglevel = [
  1. | `LOW
    (*

    Same as @G_MEMORY_MONITOR_WARNING_LEVEL_LOW but the device has even less free memory, so processes should try harder to free up unneeded resources. If your process does not need to stay running, it is a good time for it to quit.

    *)
  2. | `MEDIUM
    (*

    The system will soon start terminating processes to reclaim memory, including background processes.

    *)
  3. | `CRITICAL
]
val memorymonitorwarninglevel_of_int : int -> memorymonitorwarninglevel
val memorymonitorwarninglevel_to_int : memorymonitorwarninglevel -> int
type mountoperationresult = [
  1. | `HANDLED
    (*

    The user requested the mount operation to be aborted

    *)
  2. | `ABORTED
    (*

    The request was unhandled (i.e. not implemented)

    *)
  3. | `UNHANDLED
]
val mountoperationresult_of_int : int -> mountoperationresult
val mountoperationresult_to_int : mountoperationresult -> int
type networkconnectivity = [
  1. | `LOCAL
    (*

    The host is connected to a network, but does not appear to be able to reach the full Internet, perhaps due to upstream network problems.

    *)
  2. | `LIMITED
    (*

    The host is behind a captive portal and cannot reach the full Internet.

    *)
  3. | `PORTAL
    (*

    The host is connected to a network, and appears to be able to reach the full Internet.

    *)
  4. | `FULL
]
val networkconnectivity_of_int : int -> networkconnectivity
val networkconnectivity_to_int : networkconnectivity -> int
type notificationpriority = [
  1. | `NORMAL
    (*

    for notifications that do not require immediate attention - typically used for contextual background information, such as contact birthdays or local weather

    *)
  2. | `LOW
    (*

    for events that require more attention, usually because responses are time-sensitive (for example chat and SMS messages or alarms)

    *)
  3. | `HIGH
    (*

    for urgent notifications, or notifications that require a response in a short space of time (for example phone calls or emergency warnings)

    *)
  4. | `URGENT
]
val notificationpriority_of_int : int -> notificationpriority
val notificationpriority_to_int : notificationpriority -> int
type passwordsave = [
  1. | `NEVER
    (*

    save a password for the session.

    *)
  2. | `FOR_SESSION
    (*

    save a password permanently.

    *)
  3. | `PERMANENTLY
]
val passwordsave_of_int : int -> passwordsave
val passwordsave_to_int : passwordsave -> int
type pollablereturn = [
  1. | `FAILED
    (*

    The operation was successfully finished.

    *)
  2. | `OK
    (*

    The operation would block.

    *)
  3. | `WOULD_BLOCK
]
val pollablereturn_of_int : int -> pollablereturn
val pollablereturn_to_int : pollablereturn -> int
type resolvererror = [
  1. | `NOT_FOUND
    (*

    the requested information could not be looked up due to a network error or similar problem

    *)
  2. | `TEMPORARY_FAILURE
    (*

    unknown error

    *)
  3. | `INTERNAL
]
val resolvererror_of_int : int -> resolvererror
val resolvererror_to_int : resolvererror -> int
type resolverrecordtype = [
  1. | `SRV
    (*

    look up DNS MX records for a domain

    *)
  2. | `MX
    (*

    look up DNS TXT records for a name

    *)
  3. | `TXT
    (*

    look up DNS SOA records for a zone

    *)
  4. | `SOA
    (*

    look up DNS NS records for a domain

    *)
  5. | `NS
]
val resolverrecordtype_of_int : int -> resolverrecordtype
val resolverrecordtype_to_int : resolverrecordtype -> int
type resourceerror = [
  1. | `NOT_FOUND
    (*

    unknown error

    *)
  2. | `INTERNAL
]
val resourceerror_of_int : int -> resourceerror
val resourceerror_to_int : resourceerror -> int
type socketclientevent = [
  1. | `RESOLVING
    (*

    The client has completed a DNS lookup.

    *)
  2. | `RESOLVED
    (*

    The client is connecting to a remote host (either a proxy or the destination server).

    *)
  3. | `CONNECTING
    (*

    The client has connected to a remote host.

    *)
  4. | `CONNECTED
    (*

    The client is negotiating with a proxy to connect to the destination server.

    *)
  5. | `PROXY_NEGOTIATING
    (*

    The client has negotiated with the proxy server.

    *)
  6. | `PROXY_NEGOTIATED
    (*

    The client is performing a TLS handshake.

    *)
  7. | `TLS_HANDSHAKING
    (*

    The client has performed a TLS handshake.

    *)
  8. | `TLS_HANDSHAKED
    (*

    The client is done with a particular #GSocketConnectable.

    *)
  9. | `COMPLETE
]
val socketclientevent_of_int : int -> socketclientevent
val socketclientevent_to_int : socketclientevent -> int
type socketfamily = [
  1. | `INVALID
    (*

    the UNIX domain family

    *)
  2. | `UNIX
    (*

    the IPv4 family

    *)
  3. | `IPV4
    (*

    the IPv6 family

    *)
  4. | `IPV6
]
val socketfamily_of_int : int -> socketfamily
val socketfamily_to_int : socketfamily -> int
type socketlistenerevent = [
  1. | `BINDING
    (*

    The listener has bound a socket.

    *)
  2. | `BOUND
    (*

    The listener is about to start listening on this socket.

    *)
  3. | `LISTENING
    (*

    The listener is now listening on this socket.

    *)
  4. | `LISTENED
]
val socketlistenerevent_of_int : int -> socketlistenerevent
val socketlistenerevent_to_int : socketlistenerevent -> int
type socketprotocol = [
  1. | `UNKNOWN
    (*

    The default protocol for the family/type

    *)
  2. | `DEFAULT
    (*

    TCP over IP

    *)
  3. | `TCP
    (*

    UDP over IP

    *)
  4. | `UDP
    (*

    SCTP over IP

    *)
  5. | `SCTP
]
val socketprotocol_of_int : int -> socketprotocol
val socketprotocol_to_int : socketprotocol -> int
type sockettype = [
  1. | `INVALID
    (*

    Reliable connection-based byte streams (e.g. TCP).

    *)
  2. | `STREAM
    (*

    Connectionless, unreliable datagram passing. (e.g. UDP)

    *)
  3. | `DATAGRAM
    (*

    Reliable connection-based passing of datagrams of fixed maximum length (e.g. SCTP).

    *)
  4. | `SEQPACKET
]
val sockettype_of_int : int -> sockettype
val sockettype_to_int : sockettype -> int
type tlsauthenticationmode = [
  1. | `NONE
    (*

    client authentication is requested

    *)
  2. | `REQUESTED
    (*

    client authentication is required

    *)
  3. | `REQUIRED
]
val tlsauthenticationmode_of_int : int -> tlsauthenticationmode
val tlsauthenticationmode_to_int : tlsauthenticationmode -> int
type tlscertificaterequestflags = [
  1. | `NONE
]
val tlscertificaterequestflags_of_int : int -> tlscertificaterequestflags
val tlscertificaterequestflags_to_int : tlscertificaterequestflags -> int
type tlschannelbindingerror = [
  1. | `NOT_IMPLEMENTED
    (*

    The handshake is not yet complete on the connection which is a strong requirement for any existing binding type.

    *)
  2. | `INVALID_STATE
    (*

    Handshake is complete but binding data is not available. That normally indicates the TLS implementation failed to provide the binding data. For example, some implementations do not provide a peer certificate for resumed connections.

    *)
  3. | `NOT_AVAILABLE
    (*

    Binding type is not supported on the current connection. This error could be triggered when requesting `tls-server-end-point` binding data for a certificate which has no hash function or uses multiple hash functions.

    *)
  4. | `NOT_SUPPORTED
    (*

    Any other backend error preventing binding data retrieval.

    *)
  5. | `GENERAL_ERROR
]
val tlschannelbindingerror_of_int : int -> tlschannelbindingerror
val tlschannelbindingerror_to_int : tlschannelbindingerror -> int
type tlschannelbindingtype = [
  1. | `UNIQUE
    (*

    `tls-server-end-point`(https://tools.ietf.org/html/rfc5929#section-4) binding type

    *)
  2. | `SERVER_END_POINT
    (*

    `tls-exporter`(https://www.rfc-editor.org/rfc/rfc9266.html) binding type. Since: 2.74

    *)
  3. | `EXPORTER
]
val tlschannelbindingtype_of_int : int -> tlschannelbindingtype
val tlschannelbindingtype_to_int : tlschannelbindingtype -> int
type tlsdatabaselookupflags = [
  1. | `NONE
    (*

    Restrict lookup to certificates that have a private key.

    *)
  2. | `KEYPAIR
]
val tlsdatabaselookupflags_of_int : int -> tlsdatabaselookupflags
val tlsdatabaselookupflags_to_int : tlsdatabaselookupflags -> int
type tlserror = [
  1. | `UNAVAILABLE
    (*

    Miscellaneous TLS error

    *)
  2. | `MISC
    (*

    The certificate presented could not be parsed or failed validation.

    *)
  3. | `BAD_CERTIFICATE
    (*

    The TLS handshake failed because the peer does not seem to be a TLS server.

    *)
  4. | `NOT_TLS
    (*

    The TLS handshake failed because the peer's certificate was not acceptable.

    *)
  5. | `HANDSHAKE
    (*

    The TLS handshake failed because the server requested a client-side certificate, but none was provided. See g_tls_connection_set_certificate().

    *)
  6. | `CERTIFICATE_REQUIRED
    (*

    The TLS connection was closed without proper notice, which may indicate an attack. See g_tls_connection_set_require_close_notify().

    *)
  7. | `EOF
    (*

    The TLS handshake failed because the client sent the fallback SCSV, indicating a protocol downgrade attack. Since: 2.60

    *)
  8. | `INAPPROPRIATE_FALLBACK
    (*

    The certificate failed to load because a password was incorrect. Since: 2.72

    *)
  9. | `BAD_CERTIFICATE_PASSWORD
]
val tlserror_of_int : int -> tlserror
val tlserror_to_int : tlserror -> int
type tlsinteractionresult = [
  1. | `UNHANDLED
    (*

    The interaction completed, and resulting data is available.

    *)
  2. | `HANDLED
    (*

    The interaction has failed, or was cancelled. and the operation should be aborted.

    *)
  3. | `FAILED
]
val tlsinteractionresult_of_int : int -> tlsinteractionresult
val tlsinteractionresult_to_int : tlsinteractionresult -> int
type tlsprotocolversion = [
  1. | `UNKNOWN
    (*

    SSL 3.0, which is insecure and should not be used

    *)
  2. | `SSL_3_0
    (*

    TLS 1.0, which is insecure and should not be used

    *)
  3. | `TLS_1_0
    (*

    TLS 1.1, which is insecure and should not be used

    *)
  4. | `TLS_1_1
    (*

    TLS 1.2, defined by RFC 5246(https://datatracker.ietf.org/doc/html/rfc5246)

    *)
  5. | `TLS_1_2
    (*

    TLS 1.3, defined by RFC 8446(https://datatracker.ietf.org/doc/html/rfc8446)

    *)
  6. | `TLS_1_3
    (*

    DTLS 1.0, which is insecure and should not be used

    *)
  7. | `DTLS_1_0
    (*

    DTLS 1.2, defined by RFC 6347(https://datatracker.ietf.org/doc/html/rfc6347)

    *)
  8. | `DTLS_1_2
]
val tlsprotocolversion_of_int : int -> tlsprotocolversion
val tlsprotocolversion_to_int : tlsprotocolversion -> int
type tlsrehandshakemode = [
  1. | `NEVER
    (*

    Allow safe rehandshaking only

    *)
  2. | `SAFELY
    (*

    Allow unsafe rehandshaking

    *)
  3. | `UNSAFELY
]
val tlsrehandshakemode_of_int : int -> tlsrehandshakemode
val tlsrehandshakemode_to_int : tlsrehandshakemode -> int
type unixsocketaddresstype = [
  1. | `INVALID
    (*

    anonymous

    *)
  2. | `ANONYMOUS
    (*

    a filesystem path

    *)
  3. | `PATH
    (*

    an abstract name

    *)
  4. | `ABSTRACT
    (*

    an abstract name, 0-padded to the full length of a unix socket name

    *)
  5. | `ABSTRACT_PADDED
]
val unixsocketaddresstype_of_int : int -> unixsocketaddresstype
val unixsocketaddresstype_to_int : unixsocketaddresstype -> int
type zlibcompressorformat = [
  1. | `ZLIB
    (*

    gzip file format

    *)
  2. | `GZIP
    (*

    deflate compression with no header

    *)
  3. | `RAW
]
val zlibcompressorformat_of_int : int -> zlibcompressorformat
val zlibcompressorformat_to_int : zlibcompressorformat -> int
type appinfocreateflags_flag = [
  1. | `NONE
    (*

    Application opens in a terminal window.

    *)
  2. | `NEEDS_TERMINAL
    (*

    Application supports URI arguments.

    *)
  3. | `SUPPORTS_URIS
    (*

    Application supports startup notification. Since 2.26

    *)
  4. | `SUPPORTS_STARTUP_NOTIFICATION
]
type appinfocreateflags = appinfocreateflags_flag list
val appinfocreateflags_of_int : int -> appinfocreateflags
val appinfocreateflags_to_int : appinfocreateflags -> int
type applicationflags_flag = [
  1. | `FLAGS_NONE
    (*

    Default flags. Since: 2.74

    *)
  2. | `DEFAULT_FLAGS
    (*

    Run as a service. In this mode, registration fails if the service is already running, and the application will initially wait up to 10 seconds for an initial activation message to arrive.

    *)
  3. | `IS_SERVICE
    (*

    Don't try to become the primary instance.

    *)
  4. | `IS_LAUNCHER
    (*

    This application handles opening files (in the primary instance). Note that this flag only affects the default implementation of local_command_line(), and has no effect if %G_APPLICATION_HANDLES_COMMAND_LINE is given. See g_application_run() for details.

    *)
  5. | `HANDLES_OPEN
    (*

    This application handles command line arguments (in the primary instance). Note that this flag only affect the default implementation of local_command_line(). See g_application_run() for details.

    *)
  6. | `HANDLES_COMMAND_LINE
    (*

    Send the environment of the launching process to the primary instance. Set this flag if your application is expected to behave differently depending on certain environment variables. For instance, an editor might be expected to use the `GIT_COMMITTER_NAME` environment variable when editing a git commit message. The environment is available to the #GApplication::command-line signal handler, via g_application_command_line_getenv().

    *)
  7. | `SEND_ENVIRONMENT
    (*

    Make no attempts to do any of the typical single-instance application negotiation, even if the application ID is given. The application neither attempts to become the owner of the application ID nor does it check if an existing owner already exists. Everything occurs in the local process. Since: 2.30.

    *)
  8. | `NON_UNIQUE
    (*

    Allow users to override the application ID from the command line with `--gapplication-app-id`. Since: 2.48

    *)
  9. | `CAN_OVERRIDE_APP_ID
    (*

    Allow another instance to take over the bus name. Since: 2.60

    *)
  10. | `ALLOW_REPLACEMENT
    (*

    Take over from another instance. This flag is usually set by passing `--gapplication-replace` on the commandline. Since: 2.60

    *)
  11. | `REPLACE
]
type applicationflags = applicationflags_flag list
val applicationflags_of_int : int -> applicationflags
val applicationflags_to_int : applicationflags -> int
type askpasswordflags_flag = [
  1. | `NEED_PASSWORD
    (*

    operation requires a username.

    *)
  2. | `NEED_USERNAME
    (*

    operation requires a domain.

    *)
  3. | `NEED_DOMAIN
    (*

    operation supports saving settings.

    *)
  4. | `SAVING_SUPPORTED
    (*

    operation supports anonymous users.

    *)
  5. | `ANONYMOUS_SUPPORTED
    (*

    operation takes TCRYPT parameters (Since: 2.58)

    *)
  6. | `TCRYPT
]
type askpasswordflags = askpasswordflags_flag list
val askpasswordflags_of_int : int -> askpasswordflags
val askpasswordflags_to_int : askpasswordflags -> int
type busnameownerflags_flag = [
  1. | `NONE
    (*

    Allow another message bus connection to claim the name.

    *)
  2. | `ALLOW_REPLACEMENT
    (*

    If another message bus connection owns the name and have specified %G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT, then take the name from the other connection.

    *)
  3. | `REPLACE
    (*

    If another message bus connection owns the name, immediately return an error from g_bus_own_name() rather than entering the waiting queue for that name. (Since 2.54)

    *)
  4. | `DO_NOT_QUEUE
]
type busnameownerflags = busnameownerflags_flag list
val busnameownerflags_of_int : int -> busnameownerflags
val busnameownerflags_to_int : busnameownerflags -> int
type busnamewatcherflags_flag = [
  1. | `NONE
    (*

    If no-one owns the name when beginning to watch the name, ask the bus to launch an owner for the name.

    *)
  2. | `AUTO_START
]
type busnamewatcherflags = busnamewatcherflags_flag list
val busnamewatcherflags_of_int : int -> busnamewatcherflags
val busnamewatcherflags_to_int : busnamewatcherflags -> int
type converterflags_flag = [
  1. | `NONE
    (*

    At end of input data

    *)
  2. | `INPUT_AT_END
    (*

    Flush data

    *)
  3. | `FLUSH
]
type converterflags = converterflags_flag list
val converterflags_of_int : int -> converterflags
val converterflags_to_int : converterflags -> int
type dbuscallflags_flag = [
  1. | `NONE
    (*

    The bus must not launch an owner for the destination name in response to this method invocation.

    *)
  2. | `NO_AUTO_START
    (*

    the caller is prepared to wait for interactive authorization. Since 2.46.

    *)
  3. | `ALLOW_INTERACTIVE_AUTHORIZATION
]
type dbuscallflags = dbuscallflags_flag list
val dbuscallflags_of_int : int -> dbuscallflags
val dbuscallflags_to_int : dbuscallflags -> int
type dbuscapabilityflags_flag = [
  1. | `NONE
    (*

    The connection supports exchanging UNIX file descriptors with the remote peer.

    *)
  2. | `UNIX_FD_PASSING
]
type dbuscapabilityflags = dbuscapabilityflags_flag list
val dbuscapabilityflags_of_int : int -> dbuscapabilityflags
val dbuscapabilityflags_to_int : dbuscapabilityflags -> int
type dbusconnectionflags_flag = [
  1. | `NONE
    (*

    Perform authentication against server.

    *)
  2. | `AUTHENTICATION_CLIENT
    (*

    Perform authentication against client.

    *)
  3. | `AUTHENTICATION_SERVER
    (*

    When authenticating as a server, allow the anonymous authentication method.

    *)
  4. | `AUTHENTICATION_ALLOW_ANONYMOUS
    (*

    Pass this flag if connecting to a peer that is a message bus. This means that the Hello() method will be invoked as part of the connection setup.

    *)
  5. | `MESSAGE_BUS_CONNECTION
    (*

    If set, processing of D-Bus messages is delayed until g_dbus_connection_start_message_processing() is called.

    *)
  6. | `DELAY_MESSAGE_PROCESSING
    (*

    When authenticating as a server, require the UID of the peer to be the same as the UID of the server. (Since: 2.68)

    *)
  7. | `AUTHENTICATION_REQUIRE_SAME_USER
    (*

    When authenticating, try to use protocols that work across a Linux user namespace boundary, even if this reduces interoperability with older D-Bus implementations. This currently affects client-side `EXTERNAL` authentication, for which this flag makes connections to a server in another user namespace succeed, but causes a deadlock when connecting to a GDBus server older than 2.73.3. Since: 2.74

    *)
  8. | `CROSS_NAMESPACE
]
type dbusconnectionflags = dbusconnectionflags_flag list
val dbusconnectionflags_of_int : int -> dbusconnectionflags
val dbusconnectionflags_to_int : dbusconnectionflags -> int
type dbusinterfaceskeletonflags_flag = [
  1. | `NONE
    (*

    Each method invocation is handled in a thread dedicated to the invocation. This means that the method implementation can use blocking IO without blocking any other part of the process. It also means that the method implementation must use locking to access data structures used by other threads.

    *)
  2. | `HANDLE_METHOD_INVOCATIONS_IN_THREAD
]
type dbusinterfaceskeletonflags = dbusinterfaceskeletonflags_flag list
val dbusinterfaceskeletonflags_of_int : int -> dbusinterfaceskeletonflags
val dbusinterfaceskeletonflags_to_int : dbusinterfaceskeletonflags -> int
type dbusmessageflags_flag = [
  1. | `NONE
    (*

    A reply is not expected.

    *)
  2. | `NO_REPLY_EXPECTED
    (*

    The bus must not launch an owner for the destination name in response to this message.

    *)
  3. | `NO_AUTO_START
    (*

    If set on a method call, this flag means that the caller is prepared to wait for interactive authorization. Since 2.46.

    *)
  4. | `ALLOW_INTERACTIVE_AUTHORIZATION
]
type dbusmessageflags = dbusmessageflags_flag list
val dbusmessageflags_of_int : int -> dbusmessageflags
val dbusmessageflags_to_int : dbusmessageflags -> int
type dbusobjectmanagerclientflags_flag = [
  1. | `NONE
    (*

    If not set and the manager is for a well-known name, then request the bus to launch an owner for the name if no-one owns the name. This flag can only be used in managers for well-known names.

    *)
  2. | `DO_NOT_AUTO_START
]
type dbusobjectmanagerclientflags = dbusobjectmanagerclientflags_flag list
val dbusobjectmanagerclientflags_of_int : int -> dbusobjectmanagerclientflags
val dbusobjectmanagerclientflags_to_int : dbusobjectmanagerclientflags -> int
type dbuspropertyinfoflags_flag = [
  1. | `NONE
    (*

    Property is readable.

    *)
  2. | `READABLE
    (*

    Property is writable.

    *)
  3. | `WRITABLE
]
type dbuspropertyinfoflags = dbuspropertyinfoflags_flag list
val dbuspropertyinfoflags_of_int : int -> dbuspropertyinfoflags
val dbuspropertyinfoflags_to_int : dbuspropertyinfoflags -> int
type dbusproxyflags_flag = [
  1. | `NONE
    (*

    Don't load properties.

    *)
  2. | `DO_NOT_LOAD_PROPERTIES
    (*

    Don't connect to signals on the remote object.

    *)
  3. | `DO_NOT_CONNECT_SIGNALS
    (*

    If the proxy is for a well-known name, do not ask the bus to launch an owner during proxy initialization or a method call. This flag is only meaningful in proxies for well-known names.

    *)
  4. | `DO_NOT_AUTO_START
    (*

    If set, the property value for any __invalidated property__ will be (asynchronously) retrieved upon receiving the `PropertiesChanged`(http://dbus.freedesktop.org/doc/dbus-specification.html#standard-interfaces-properties) D-Bus signal and the property will not cause emission of the #GDBusProxy::g-properties-changed signal. When the value is received the #GDBusProxy::g-properties-changed signal is emitted for the property along with the retrieved value. Since 2.32.

    *)
  5. | `GET_INVALIDATED_PROPERTIES
    (*

    If the proxy is for a well-known name, do not ask the bus to launch an owner during proxy initialization, but allow it to be autostarted by a method call. This flag is only meaningful in proxies for well-known names, and only if %G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START is not also specified.

    *)
  6. | `DO_NOT_AUTO_START_AT_CONSTRUCTION
    (*

    Don't actually send the AddMatch D-Bus call for this signal subscription. This gives you more control over which match rules you add (but you must add them manually). (Since: 2.72)

    *)
  7. | `NO_MATCH_RULE
]
type dbusproxyflags = dbusproxyflags_flag list
val dbusproxyflags_of_int : int -> dbusproxyflags
val dbusproxyflags_to_int : dbusproxyflags -> int
type dbussendmessageflags_flag = [
  1. | `NONE
    (*

    Do not automatically assign a serial number from the #GDBusConnection object when sending a message.

    *)
  2. | `PRESERVE_SERIAL
]
type dbussendmessageflags = dbussendmessageflags_flag list
val dbussendmessageflags_of_int : int -> dbussendmessageflags
val dbussendmessageflags_to_int : dbussendmessageflags -> int
type dbusserverflags_flag = [
  1. | `NONE
    (*

    All #GDBusServer::new-connection signals will run in separated dedicated threads (see signal for details).

    *)
  2. | `RUN_IN_THREAD
    (*

    Allow the anonymous authentication method.

    *)
  3. | `AUTHENTICATION_ALLOW_ANONYMOUS
    (*

    Require the UID of the peer to be the same as the UID of the server when authenticating. (Since: 2.68)

    *)
  4. | `AUTHENTICATION_REQUIRE_SAME_USER
]
type dbusserverflags = dbusserverflags_flag list
val dbusserverflags_of_int : int -> dbusserverflags
val dbusserverflags_to_int : dbusserverflags -> int
type dbussignalflags_flag = [
  1. | `NONE
    (*

    Don't actually send the AddMatch D-Bus call for this signal subscription. This gives you more control over which match rules you add (but you must add them manually).

    *)
  2. | `NO_MATCH_RULE
    (*

    Match first arguments that contain a bus or interface name with the given namespace.

    *)
  3. | `MATCH_ARG0_NAMESPACE
    (*

    Match first arguments that contain an object path that is either equivalent to the given path, or one of the paths is a subpath of the other.

    *)
  4. | `MATCH_ARG0_PATH
]
type dbussignalflags = dbussignalflags_flag list
val dbussignalflags_of_int : int -> dbussignalflags
val dbussignalflags_to_int : dbussignalflags -> int
type dbussubtreeflags_flag = [
  1. | `NONE
    (*

    Method calls to objects not in the enumerated range will still be dispatched. This is useful if you want to dynamically spawn objects in the subtree.

    *)
  2. | `DISPATCH_TO_UNENUMERATED_NODES
]
type dbussubtreeflags = dbussubtreeflags_flag list
val dbussubtreeflags_of_int : int -> dbussubtreeflags
val dbussubtreeflags_to_int : dbussubtreeflags -> int
type drivestartflags_flag = [
  1. | `NONE
]
type drivestartflags = drivestartflags_flag list
val drivestartflags_of_int : int -> drivestartflags
val drivestartflags_to_int : drivestartflags -> int
type fileattributeinfoflags_flag = [
  1. | `NONE
    (*

    copy the attribute values when the file is copied.

    *)
  2. | `COPY_WITH_FILE
    (*

    copy the attribute values when the file is moved.

    *)
  3. | `COPY_WHEN_MOVED
]
type fileattributeinfoflags = fileattributeinfoflags_flag list
val fileattributeinfoflags_of_int : int -> fileattributeinfoflags
val fileattributeinfoflags_to_int : fileattributeinfoflags -> int
type filecopyflags_flag = [
  1. | `NONE
    (*

    Overwrite any existing files

    *)
  2. | `OVERWRITE
    (*

    Make a backup of any existing files.

    *)
  3. | `BACKUP
    (*

    Don't follow symlinks.

    *)
  4. | `ALL_METADATA
    (*

    Don't use copy and delete fallback if native move not supported.

    *)
  5. | `NO_FALLBACK_FOR_MOVE
    (*

    Leaves target file with default perms, instead of setting the source file perms.

    *)
  6. | `TARGET_DEFAULT_PERMS
    (*

    Use default modification timestamps instead of copying them from the source file. Since 2.80

    *)
  7. | `TARGET_DEFAULT_MODIFIED_TIME
]
type filecopyflags = filecopyflags_flag list
val filecopyflags_of_int : int -> filecopyflags
val filecopyflags_to_int : filecopyflags -> int
type filecreateflags_flag = [
  1. | `NONE
    (*

    Create a file that can only be accessed by the current user.

    *)
  2. | `PRIVATE
    (*

    Replace the destination as if it didn't exist before. Don't try to keep any old permissions, replace instead of following links. This is generally useful if you're doing a "copy over" rather than a "save new version of" replace operation. You can think of it as "unlink destination" before writing to it, although the implementation may not be exactly like that. This flag can only be used with g_file_replace() and its variants, including g_file_replace_contents(). Since 2.20

    *)
  3. | `REPLACE_DESTINATION
]
type filecreateflags = filecreateflags_flag list
val filecreateflags_of_int : int -> filecreateflags
val filecreateflags_to_int : filecreateflags -> int
type filemeasureflags_flag = [
  1. | `NONE
    (*

    Report any error encountered while traversing the directory tree. Normally errors are only reported for the toplevel file.

    *)
  2. | `REPORT_ANY_ERROR
    (*

    Tally usage based on apparent file sizes. Normally, the block-size is used, if available, as this is a more accurate representation of disk space used. Compare with `du --apparent-size`. Since GLib 2.78. and similarly to `du` since GNU Coreutils 9.2, this will ignore the sizes of file types other than regular files and links, as the sizes of other file types are not specified in a standard way.

    *)
  3. | `APPARENT_SIZE
    (*

    Do not cross mount point boundaries. Compare with `du -x`.

    *)
  4. | `NO_XDEV
]
type filemeasureflags = filemeasureflags_flag list
val filemeasureflags_of_int : int -> filemeasureflags
val filemeasureflags_to_int : filemeasureflags -> int
type filemonitorflags_flag = [
  1. | `NONE
    (*

    Watch for mount events.

    *)
  2. | `WATCH_MOUNTS
    (*

    Pair DELETED and CREATED events caused by file renames (moves) and send a single G_FILE_MONITOR_EVENT_MOVED event instead (NB: not supported on all backends; the default behaviour -without specifying this flag- is to send single DELETED and CREATED events). Deprecated since 2.46: use %G_FILE_MONITOR_WATCH_MOVES instead.

    *)
  3. | `SEND_MOVED
    (*

    Watch for changes to the file made via another hard link. Since 2.36.

    *)
  4. | `WATCH_MOVES
]
type filemonitorflags = filemonitorflags_flag list
val filemonitorflags_of_int : int -> filemonitorflags
val filemonitorflags_to_int : filemonitorflags -> int
type filequeryinfoflags_flag = [
  1. | `NONE
    (*

    Don't follow symlinks.

    *)
]
type filequeryinfoflags = filequeryinfoflags_flag list
val filequeryinfoflags_of_int : int -> filequeryinfoflags
val filequeryinfoflags_to_int : filequeryinfoflags -> int
type iostreamspliceflags_flag = [
  1. | `NONE
    (*

    Close the first stream after the splice.

    *)
  2. | `CLOSE_STREAM1
    (*

    Close the second stream after the splice.

    *)
  3. | `CLOSE_STREAM2
    (*

    Wait for both splice operations to finish before calling the callback.

    *)
  4. | `WAIT_FOR_BOTH
]
type iostreamspliceflags = iostreamspliceflags_flag list
val iostreamspliceflags_of_int : int -> iostreamspliceflags
val iostreamspliceflags_to_int : iostreamspliceflags -> int
type mountmountflags_flag = [
  1. | `NONE
]
type mountmountflags = mountmountflags_flag list
val mountmountflags_of_int : int -> mountmountflags
val mountmountflags_to_int : mountmountflags -> int
type mountunmountflags_flag = [
  1. | `NONE
    (*

    Unmount even if there are outstanding file operations on the mount.

    *)
  2. | `FORCE
]
type mountunmountflags = mountunmountflags_flag list
val mountunmountflags_of_int : int -> mountunmountflags
val mountunmountflags_to_int : mountunmountflags -> int
type outputstreamspliceflags_flag = [
  1. | `NONE
    (*

    Close the source stream after the splice.

    *)
  2. | `CLOSE_SOURCE
    (*

    Close the target stream after the splice.

    *)
  3. | `CLOSE_TARGET
]
type outputstreamspliceflags = outputstreamspliceflags_flag list
val outputstreamspliceflags_of_int : int -> outputstreamspliceflags
val outputstreamspliceflags_to_int : outputstreamspliceflags -> int
type resolvernamelookupflags_flag = [
  1. | `DEFAULT
    (*

    only resolve ipv4 addresses

    *)
  2. | `IPV4_ONLY
    (*

    only resolve ipv6 addresses

    *)
  3. | `IPV6_ONLY
]
type resolvernamelookupflags = resolvernamelookupflags_flag list
val resolvernamelookupflags_of_int : int -> resolvernamelookupflags
val resolvernamelookupflags_to_int : resolvernamelookupflags -> int
type resourceflags_flag = [
  1. | `NONE
    (*

    The file is compressed.

    *)
  2. | `COMPRESSED
]
type resourceflags = resourceflags_flag list
val resourceflags_of_int : int -> resourceflags
val resourceflags_to_int : resourceflags -> int
type resourcelookupflags_flag = [
  1. | `NONE
]
type resourcelookupflags = resourcelookupflags_flag list
val resourcelookupflags_of_int : int -> resourcelookupflags
val resourcelookupflags_to_int : resourcelookupflags -> int
type settingsbindflags_flag = [
  1. | `DEFAULT
    (*

    Update the #GObject property when the setting changes. It is an error to use this flag if the property is not writable.

    *)
  2. | `GET
    (*

    Update the setting when the #GObject property changes. It is an error to use this flag if the property is not readable.

    *)
  3. | `SET
    (*

    Do not try to bind a "sensitivity" property to the writability of the setting

    *)
  4. | `NO_SENSITIVITY
    (*

    When set in addition to %G_SETTINGS_BIND_GET, set the #GObject property value initially from the setting, but do not listen for changes of the setting

    *)
  5. | `GET_NO_CHANGES
    (*

    When passed to g_settings_bind(), uses a pair of mapping functions that invert the boolean value when mapping between the setting and the property. The setting and property must both be booleans. You cannot pass this flag to g_settings_bind_with_mapping().

    *)
  6. | `INVERT_BOOLEAN
]
type settingsbindflags = settingsbindflags_flag list
val settingsbindflags_of_int : int -> settingsbindflags
val settingsbindflags_to_int : settingsbindflags -> int
type socketmsgflags_flag = [
  1. | `NONE
    (*

    Request to send/receive out of band data.

    *)
  2. | `OOB
    (*

    Read data from the socket without removing it from the queue.

    *)
  3. | `PEEK
    (*

    Don't use a gateway to send out the packet, only send to hosts on directly connected networks.

    *)
  4. | `DONTROUTE
]
type socketmsgflags = socketmsgflags_flag list
val socketmsgflags_of_int : int -> socketmsgflags
val socketmsgflags_to_int : socketmsgflags -> int
type subprocessflags_flag = [
  1. | `NONE
    (*

    create a pipe for the stdin of the spawned process that can be accessed with g_subprocess_get_stdin_pipe().

    *)
  2. | `STDIN_PIPE
    (*

    stdin is inherited from the calling process.

    *)
  3. | `STDIN_INHERIT
    (*

    create a pipe for the stdout of the spawned process that can be accessed with g_subprocess_get_stdout_pipe().

    *)
  4. | `STDOUT_PIPE
    (*

    silence the stdout of the spawned process (ie: redirect to `/dev/null`).

    *)
  5. | `STDOUT_SILENCE
    (*

    create a pipe for the stderr of the spawned process that can be accessed with g_subprocess_get_stderr_pipe().

    *)
  6. | `STDERR_PIPE
    (*

    silence the stderr of the spawned process (ie: redirect to `/dev/null`).

    *)
  7. | `STDERR_SILENCE
    (*

    merge the stderr of the spawned process with whatever the stdout happens to be. This is a good way of directing both streams to a common log file, for example.

    *)
  8. | `STDERR_MERGE
    (*

    spawned processes will inherit the file descriptors of their parent, unless those descriptors have been explicitly marked as close-on-exec. This flag has no effect over the "standard" file descriptors (stdin, stdout, stderr).

    *)
  9. | `INHERIT_FDS
    (*

    if path searching is needed when spawning the subprocess, use the `PATH` in the launcher environment. (Since: 2.72)

    *)
  10. | `SEARCH_PATH_FROM_ENVP
]
type subprocessflags = subprocessflags_flag list
val subprocessflags_of_int : int -> subprocessflags
val subprocessflags_to_int : subprocessflags -> int
type testdbusflags_flag = [
  1. | `NONE
]
type testdbusflags = testdbusflags_flag list
val testdbusflags_of_int : int -> testdbusflags
val testdbusflags_to_int : testdbusflags -> int
type tlscertificateflags_flag = [
  1. | `NO_FLAGS
    (*

    The signing certificate authority is not known.

    *)
  2. | `UNKNOWN_CA
    (*

    The certificate does not match the expected identity of the site that it was retrieved from.

    *)
  3. | `BAD_IDENTITY
    (*

    The certificate's activation time is still in the future

    *)
  4. | `NOT_ACTIVATED
    (*

    The certificate has expired

    *)
  5. | `EXPIRED
    (*

    The certificate has been revoked according to the #GTlsConnection's certificate revocation list.

    *)
  6. | `REVOKED
    (*

    The certificate's algorithm is considered insecure.

    *)
  7. | `INSECURE
    (*

    Some other error occurred validating the certificate

    *)
  8. | `GENERIC_ERROR
    (*

    the combination of all of the above flags

    *)
  9. | `VALIDATE_ALL
]
type tlscertificateflags = tlscertificateflags_flag list
val tlscertificateflags_of_int : int -> tlscertificateflags
val tlscertificateflags_to_int : tlscertificateflags -> int
type tlsdatabaseverifyflags_flag = [
  1. | `NONE
]
type tlsdatabaseverifyflags = tlsdatabaseverifyflags_flag list
val tlsdatabaseverifyflags_of_int : int -> tlsdatabaseverifyflags
val tlsdatabaseverifyflags_to_int : tlsdatabaseverifyflags -> int
type tlspasswordflags_flag = [
  1. | `NONE
    (*

    The password was wrong, and the user should retry.

    *)
  2. | `RETRY
    (*

    Hint to the user that the password has been wrong many times, and the user may not have many chances left.

    *)
  3. | `MANY_TRIES
    (*

    Hint to the user that this is the last try to get this password right.

    *)
  4. | `FINAL_TRY
    (*

    For PKCS #11, the user PIN is required. Since: 2.70.

    *)
  5. | `PKCS11_USER
    (*

    For PKCS #11, the security officer PIN is required. Since: 2.70.

    *)
  6. | `PKCS11_SECURITY_OFFICER
    (*

    For PKCS #11, the context-specific PIN is required. Since: 2.70.

    *)
  7. | `PKCS11_CONTEXT_SPECIFIC
]
type tlspasswordflags = tlspasswordflags_flag list
val tlspasswordflags_of_int : int -> tlspasswordflags
val tlspasswordflags_to_int : tlspasswordflags -> int