package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Quad

type t = [ `quad ] Gobject.obj

A 4 vertex quadrilateral, as represented by four #graphene_point_t.

The contents of a #graphene_quad_t are private and should never be accessed directly.

val alloc : unit -> t

Create a new Quad

val init_from_rect : t -> [ `rect ] Gobject.obj -> t

Initializes a #graphene_quad_t using the four corners of the given #graphene_rect_t.

val init_from_points : t -> [ `point ] Gobject.obj array -> t

Initializes a #graphene_quad_t using an array of points.

val init : t -> [ `point ] Gobject.obj -> [ `point ] Gobject.obj -> [ `point ] Gobject.obj -> [ `point ] Gobject.obj -> t

Initializes a #graphene_quad_t with the given points.

val get_point : t -> int -> [ `point ] Gobject.obj

Retrieves the point of a #graphene_quad_t at the given index.

val contains : t -> [ `point ] Gobject.obj -> bool

Checks if the given #graphene_quad_t contains the given #graphene_point_t.

val bounds : t -> [ `rect ] Gobject.obj

Computes the bounding rectangle of @q and places it into @r.

val get_type : unit -> Gobject.Type.t