package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Cairo_node

type t = [ `cairo_node | `render_node ] Gobject.obj

Create a new CairoNode

Retrieves the Cairo surface used by the render node.

val get_draw_context : t -> Ocgtk_cairo.Cairo.Wrappers.Context.t

Creates a Cairo context for drawing using the surface associated to the render node.

If no surface exists yet, a surface will be created optimized for rendering to @renderer.