package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Conic_gradient_node

type t = [ `conic_gradient_node | `render_node ] Gobject.obj

Create a new ConicGradientNode

val get_rotation : t -> float

Retrieves the rotation for the gradient in degrees.

val get_n_color_stops : t -> Gsize.t

Retrieves the number of color stops in the gradient.

val get_color_stops : t -> [ `color_stop ] Gobject.obj array * Gsize.t

Retrieves the color stops in the gradient.

Retrieves the center pointer for the gradient.

val get_angle : t -> float

Retrieves the angle for the gradient in radians, normalized in 0, 2 * PI.

The angle is starting at the top and going clockwise, as expressed in the css specification:

angle = 90 - gsk_conic_gradient_node_get_rotation()