package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Debug_node

type t = [ `debug_node | `render_node ] Gobject.obj
val new_ : [ `render_node ] Gobject.obj -> string -> t

Create a new DebugNode

val get_message : t -> string

Gets the debug message that was set on this node

val get_child : t -> [ `render_node ] Gobject.obj

Gets the child node that is getting drawn by the given @node.