package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Fill_node

type t = [ `fill_node | `render_node ] Gobject.obj
val new_ : [ `render_node ] Gobject.obj -> [ `path ] Gobject.obj -> Gsk_enums.fillrule -> t

Create a new FillNode

val get_path : t -> [ `path ] Gobject.obj

Retrieves the path used to describe the area filled with the contents of the @node.

val get_fill_rule : t -> Gsk_enums.fillrule

Retrieves the fill rule used to determine how the path is filled.

val get_child : t -> [ `render_node ] Gobject.obj

Gets the child node that is getting drawn by the given @node.