package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Path_measure

type t = [ `path_measure ] Gobject.obj
val new_ : [ `path ] Gobject.obj -> t

Create a new PathMeasure

val new_with_tolerance : [ `path ] Gobject.obj -> float -> t

Create a new PathMeasure

val ref : t -> t

Increases the reference count of a `GskPathMeasure` by one.

val get_tolerance : t -> float

Returns the tolerance that the measure was created with.

val get_point : t -> float -> bool * [ `path_point ] Gobject.obj

Sets @result to the point at the given distance into the path.

An empty path has no points, so `FALSE` is returned in that case.

val get_path : t -> [ `path ] Gobject.obj

Returns the path that the measure was created for.

val get_length : t -> float

Gets the length of the path being measured.

The length is cached, so this function does not do any work.