package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Rounded_clip_node

type t = [ `rounded_clip_node | `render_node ] Gobject.obj
val new_ : [ `render_node ] Gobject.obj -> [ `rounded_rect ] Gobject.obj -> t

Create a new RoundedClipNode

val get_clip : t -> [ `rounded_rect ] Gobject.obj

Retrieves the rounded rectangle used to clip the contents of the @node.

val get_child : t -> [ `render_node ] Gobject.obj

Gets the child node that is getting clipped by the given @node.