package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Stroke_node

type t = [ `stroke_node | `render_node ] Gobject.obj
val new_ : [ `render_node ] Gobject.obj -> [ `path ] Gobject.obj -> [ `stroke ] Gobject.obj -> t

Create a new StrokeNode

val get_stroke : t -> [ `stroke ] Gobject.obj

Retrieves the stroke attributes used in this @node.

val get_path : t -> [ `path ] Gobject.obj

Retrieves the path that will be stroked with the contents of the @node.

val get_child : t -> [ `render_node ] Gobject.obj

Gets the child node that is getting drawn by the given @node.