package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ocgtk_gsk.Gsk_enums

type blendmode = [
  1. | `DEFAULT
    (*

    The source color is multiplied by the destination and replaces the destination

    *)
  2. | `MULTIPLY
    (*

    Multiplies the complements of the destination and source color values, then complements the result.

    *)
  3. | `SCREEN
    (*

    Multiplies or screens the colors, depending on the destination color value. This is the inverse of hard-list

    *)
  4. | `OVERLAY
    (*

    Selects the darker of the destination and source colors

    *)
  5. | `DARKEN
    (*

    Selects the lighter of the destination and source colors

    *)
  6. | `LIGHTEN
    (*

    Brightens the destination color to reflect the source color

    *)
  7. | `COLOR_DODGE
    (*

    Darkens the destination color to reflect the source color

    *)
  8. | `COLOR_BURN
    (*

    Multiplies or screens the colors, depending on the source color value

    *)
  9. | `HARD_LIGHT
    (*

    Darkens or lightens the colors, depending on the source color value

    *)
  10. | `SOFT_LIGHT
    (*

    Subtracts the darker of the two constituent colors from the lighter color

    *)
  11. | `DIFFERENCE
    (*

    Produces an effect similar to that of the difference mode but lower in contrast

    *)
  12. | `EXCLUSION
    (*

    Creates a color with the hue and saturation of the source color and the luminosity of the destination color

    *)
  13. | `COLOR
    (*

    Creates a color with the hue of the source color and the saturation and luminosity of the destination color

    *)
  14. | `HUE
    (*

    Creates a color with the saturation of the source color and the hue and luminosity of the destination color

    *)
  15. | `SATURATION
    (*

    Creates a color with the luminosity of the source color and the hue and saturation of the destination color

    *)
  16. | `LUMINOSITY
]
val blendmode_of_int : int -> blendmode
val blendmode_to_int : blendmode -> int
type corner = [
  1. | `TOP_LEFT
    (*

    The top right corner

    *)
  2. | `TOP_RIGHT
    (*

    The bottom right corner

    *)
  3. | `BOTTOM_RIGHT
    (*

    The bottom left corner

    *)
  4. | `BOTTOM_LEFT
]
val corner_of_int : int -> corner
val corner_to_int : corner -> int
type fillrule = [
  1. | `WINDING
    (*

    Counts the total number of intersections, without regard to the orientation of the contour. If the total number of intersections is odd, the point will be filled.

    *)
  2. | `EVEN_ODD
]
val fillrule_of_int : int -> fillrule
val fillrule_to_int : fillrule -> int
type gluniformtype = [
  1. | `NONE
    (*

    A float uniform

    *)
  2. | `FLOAT
    (*

    A GLSL int / gint32 uniform

    *)
  3. | `INT
    (*

    A GLSL uint / guint32 uniform

    *)
  4. | `UINT
    (*

    A GLSL bool / gboolean uniform

    *)
  5. | `BOOL
    (*

    A GLSL vec2 / graphene_vec2_t uniform

    *)
  6. | `VEC2
    (*

    A GLSL vec3 / graphene_vec3_t uniform

    *)
  7. | `VEC3
    (*

    A GLSL vec4 / graphene_vec4_t uniform

    *)
  8. | `VEC4
]
val gluniformtype_of_int : int -> gluniformtype
val gluniformtype_to_int : gluniformtype -> int
type linecap = [
  1. | `BUTT
    (*

    Use a round ending, the center of the circle is the start or end point

    *)
  2. | `ROUND
    (*

    use squared ending, the center of the square is the start or end point

    *)
  3. | `SQUARE
]
val linecap_of_int : int -> linecap
val linecap_to_int : linecap -> int
type linejoin = [
  1. | `MITER
    (*

    Use a round join, the center of the circle is the join point

    *)
  2. | `ROUND
    (*

    use a cut-off join, the join is cut off at half the line width from the joint point

    *)
  3. | `BEVEL
]
val linejoin_of_int : int -> linejoin
val linejoin_to_int : linejoin -> int
type maskmode = [
  1. | `ALPHA
    (*

    Use the inverted alpha channel of the mask

    *)
  2. | `INVERTED_ALPHA
    (*

    Use the luminance of the mask, multiplied by mask alpha

    *)
  3. | `LUMINANCE
    (*

    Use the inverted luminance of the mask, multiplied by mask alpha

    *)
  4. | `INVERTED_LUMINANCE
]
val maskmode_of_int : int -> maskmode
val maskmode_to_int : maskmode -> int
type pathdirection = [
  1. | `FROM_START
    (*

    The tangent against path direction of the incoming side of the path

    *)
  2. | `TO_START
    (*

    The tangent in path direction of the outgoing side of the path

    *)
  3. | `TO_END
    (*

    The tangent against path direction of the outgoing side of the path

    *)
  4. | `FROM_END
]
val pathdirection_of_int : int -> pathdirection
val pathdirection_to_int : pathdirection -> int
type pathoperation = [
  1. | `MOVE
    (*

    A close operation ending the current contour with a line back to the starting point. Two points describe the start and end of the line.

    *)
  2. | `CLOSE
    (*

    A line-to operation, with 2 points describing the start and end point of a straight line.

    *)
  3. | `LINE
    (*

    A curve-to operation describing a quadratic Bézier curve with 3 points describing the start point, the control point and the end point of the curve.

    *)
  4. | `QUAD
    (*

    A curve-to operation describing a cubic Bézier curve with 4 points describing the start point, the two control points and the end point of the curve.

    *)
  5. | `CUBIC
    (*

    A rational quadratic Bézier curve with 3 points describing the start point, control point and end point of the curve. A weight for the curve will be passed, too.

    *)
  6. | `CONIC
]
val pathoperation_of_int : int -> pathoperation
val pathoperation_to_int : pathoperation -> int
type rendernodetype = [
  1. | `NOT_A_RENDER_NODE
    (*

    A node containing a stack of children

    *)
  2. | `CONTAINER_NODE
    (*

    A node drawing a `cairo_surface_t`

    *)
  3. | `CAIRO_NODE
    (*

    A node drawing a single color rectangle

    *)
  4. | `COLOR_NODE
    (*

    A node drawing a linear gradient

    *)
  5. | `LINEAR_GRADIENT_NODE
    (*

    A node drawing a repeating linear gradient

    *)
  6. | `REPEATING_LINEAR_GRADIENT_NODE
    (*

    A node drawing a radial gradient

    *)
  7. | `RADIAL_GRADIENT_NODE
    (*

    A node drawing a repeating radial gradient

    *)
  8. | `REPEATING_RADIAL_GRADIENT_NODE
    (*

    A node drawing a conic gradient

    *)
  9. | `CONIC_GRADIENT_NODE
    (*

    A node stroking a border around an area

    *)
  10. | `BORDER_NODE
    (*

    A node drawing a `GdkTexture`

    *)
  11. | `TEXTURE_NODE
    (*

    A node drawing an inset shadow

    *)
  12. | `INSET_SHADOW_NODE
    (*

    A node drawing an outset shadow

    *)
  13. | `OUTSET_SHADOW_NODE
    (*

    A node that renders its child after applying a matrix transform

    *)
  14. | `TRANSFORM_NODE
    (*

    A node that changes the opacity of its child

    *)
  15. | `OPACITY_NODE
    (*

    A node that applies a color matrix to every pixel

    *)
  16. | `COLOR_MATRIX_NODE
    (*

    A node that repeats the child's contents

    *)
  17. | `REPEAT_NODE
    (*

    A node that clips its child to a rectangular area

    *)
  18. | `CLIP_NODE
    (*

    A node that clips its child to a rounded rectangle

    *)
  19. | `ROUNDED_CLIP_NODE
    (*

    A node that draws a shadow below its child

    *)
  20. | `SHADOW_NODE
    (*

    A node that blends two children together

    *)
  21. | `BLEND_NODE
    (*

    A node that cross-fades between two children

    *)
  22. | `CROSS_FADE_NODE
    (*

    A node containing a glyph string

    *)
  23. | `TEXT_NODE
    (*

    A node that applies a blur

    *)
  24. | `BLUR_NODE
    (*

    Debug information that does not affect the rendering

    *)
  25. | `DEBUG_NODE
    (*

    A node that uses OpenGL fragment shaders to render

    *)
  26. | `GL_SHADER_NODE
    (*

    A node drawing a `GdkTexture` scaled and filtered.

    *)
  27. | `TEXTURE_SCALE_NODE
    (*

    A node that masks one child with another.

    *)
  28. | `MASK_NODE
    (*

    A node that fills a path.

    *)
  29. | `FILL_NODE
    (*

    A node that strokes a path.

    *)
  30. | `STROKE_NODE
    (*

    A node that possibly redirects part of the scene graph to a subsurface.

    *)
  31. | `SUBSURFACE_NODE
]
val rendernodetype_of_int : int -> rendernodetype
val rendernodetype_to_int : rendernodetype -> int
type scalingfilter = [
  1. | `LINEAR
    (*

    nearest neighbor interpolation filter

    *)
  2. | `NEAREST
    (*

    linear interpolation along each axis, plus mipmap generation, with linear interpolation along the mipmap levels

    *)
  3. | `TRILINEAR
]
val scalingfilter_of_int : int -> scalingfilter
val scalingfilter_to_int : scalingfilter -> int
type serializationerror = [
  1. | `UNSUPPORTED_FORMAT
    (*

    The version of the data is not understood

    *)
  2. | `UNSUPPORTED_VERSION
    (*

    The given data may not exist in a proper serialization

    *)
  3. | `INVALID_DATA
]
val serializationerror_of_int : int -> serializationerror
val serializationerror_to_int : serializationerror -> int
type transformcategory = [
  1. | `UNKNOWN
    (*

    Analyzing the matrix concluded that it does not fit in any other category.

    *)
  2. | `ANY
    (*

    The matrix is a 3D matrix. This means that the w column (the last column) has the values (0, 0, 0, 1).

    *)
  3. | `V3D
    (*

    The matrix is a 2D matrix. This is equivalent to graphene_matrix_is_2d() returning %TRUE. In particular, this means that Cairo can deal with the matrix.

    *)
  4. | `V2D
    (*

    The matrix is a combination of 2D scale and 2D translation operations. In particular, this means that any rectangle can be transformed exactly using this matrix.

    *)
  5. | `V2D_AFFINE
    (*

    The matrix is a 2D translation.

    *)
  6. | `V2D_TRANSLATE
    (*

    The matrix is the identity matrix.

    *)
  7. | `IDENTITY
]
val transformcategory_of_int : int -> transformcategory
val transformcategory_to_int : transformcategory -> int
type pathforeachflags_flag = [
  1. | `ONLY_LINES
    (*

    Allow emission of `GSK_PATH_QUAD` operations

    *)
  2. | `QUAD
    (*

    Allow emission of `GSK_PATH_CUBIC` operations.

    *)
  3. | `CUBIC
    (*

    Allow emission of `GSK_PATH_CONIC` operations.

    *)
  4. | `CONIC
]
type pathforeachflags = pathforeachflags_flag list
val pathforeachflags_of_int : int -> pathforeachflags
val pathforeachflags_to_int : pathforeachflags -> int