package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.About_dialog

type t = [ `about_dialog | `window | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new AboutDialog

val set_wrap_license : t -> bool -> unit

Sets whether the license text in the about dialog should be automatically wrapped.

val set_website_label : t -> string -> unit

Sets the label to be used for the website link.

val set_website : t -> string option -> unit

Sets the URL to use for the website link.

val set_version : t -> string option -> unit

Sets the version string to display in the about dialog.

val set_translator_credits : t -> string option -> unit

Sets the translator credits string which is displayed in the credits page.

The intended use for this string is to display the translator of the language which is currently used in the user interface. Using `gettext()`, a simple way to achieve that is to mark the string for translation:

```c GtkWidget *about = gtk_about_dialog_new (); gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about), _("translator-credits")); ```

It is a good idea to use the customary `msgid` “translator-credits” for this purpose, since translators will already know the purpose of that `msgid`, and since `GtkAboutDialog` will detect if “translator-credits” is untranslated and omit translator credits.

val set_system_information : t -> string option -> unit

Sets the system information to be displayed in the about dialog.

If `system_information` is `NULL`, the system information page is hidden.

See property@Gtk.AboutDialog:system-information.

val set_program_name : t -> string option -> unit

Sets the name to display in the about dialog.

If `name` is not set, the string returned by `g_get_application_name()` is used.

val set_logo_icon_name : t -> string option -> unit

Sets the icon name to be displayed as logo in the about dialog.

Sets the logo in the about dialog.

val set_license : t -> string option -> unit

Sets the license information to be displayed in the about dialog.

If `license` is `NULL`, the license page is hidden.

val set_documenters : t -> string array -> unit

Sets the names of the documenters which are displayed in the "Credits" page.

Sets the copyright string to display in the about dialog.

This should be a short string of one or two lines.

val set_comments : t -> string option -> unit

Sets the comments string to display in the about dialog.

This should be a short string of one or two lines.

val set_authors : t -> string array -> unit

Sets the names of the authors which are displayed in the "Credits" page of the about dialog.

val set_artists : t -> string array -> unit

Sets the names of the artists to be displayed in the "Credits" page.

val get_wrap_license : t -> bool

Returns whether the license text in the about dialog is automatically wrapped.

val get_website_label : t -> string option

Returns the label used for the website link.

val get_website : t -> string option

Returns the website URL.

val get_version : t -> string option

Returns the version string.

val get_translator_credits : t -> string option

Returns the translator credits string which is displayed in the credits page.

val get_system_information : t -> string option

Returns the system information that is shown in the about dialog.

val get_program_name : t -> string option

Returns the program name displayed in the about dialog.

val get_logo_icon_name : t -> string option

Returns the icon name displayed as logo in the about dialog.

Returns the paintable displayed as logo in the about dialog.

val get_license : t -> string option

Returns the license information.

val get_documenters : t -> string array

Returns the name of the documenters which are displayed in the credits page.

Returns the copyright string.

val get_comments : t -> string option

Returns the comments string.

val get_authors : t -> string array

Returns the names of the authors which are displayed in the credits page.

val get_artists : t -> string array

Returns the names of the artists which are displayed in the credits page.

val add_credit_section : t -> string -> string array -> unit

Creates a new section in the "Credits" page.