package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Accessible_list

type t = [ `accessible_list ] Gobject.obj

A boxed type which wraps a list of references to GtkAccessible objects.

val new_from_array : [ `accessible ] Gobject.obj array -> Gsize.t -> t

Create a new AccessibleList

val new_from_list : [ `accessible ] Gobject.obj list -> t

Create a new AccessibleList

val get_objects : t -> [ `accessible ] Gobject.obj list

Gets the list of objects this boxed type holds

val get_type : unit -> Gobject.Type.t