package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Accessible_text

type t = [ `accessible_text ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val update_selection_bound : t -> unit

Updates the boundary of the selection.

Implementations of the `GtkAccessibleText` interface should call this function every time the selection has moved, in order to notify assistive technologies.

val update_contents : t -> Gtk_enums.accessibletextcontentchange -> int -> int -> unit

Notifies assistive technologies of a change in contents.

Implementations of the `GtkAccessibleText` interface should call this function every time their contents change as the result of an operation, like an insertion or a removal.

Note: If the change is a deletion, this function must be called *before* removing the contents, if it is an insertion, it must be called *after* inserting the new contents.

val update_caret_position : t -> unit

Updates the position of the caret.

Implementations of the `GtkAccessibleText` interface should call this function every time the caret has moved, in order to notify assistive technologies.