package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Action_bar

type t = [ `action_bar | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new ActionBar

val set_revealed : t -> bool -> unit

Reveals or conceals the content of the action bar.

Note: this does not show or hide @action_bar in the property@Gtk.Widget:visible sense, so revealing has no effect if the action bar is hidden.

val set_center_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the center widget for the `GtkActionBar`.

val remove : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> unit

Removes a child from @action_bar.

val pack_start : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> unit

Adds @child to @action_bar, packed with reference to the start of the @action_bar.

val pack_end : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> unit

Adds @child to @action_bar, packed with reference to the end of the @action_bar.

val get_revealed : t -> bool

Gets whether the contents of the action bar are revealed.

val get_center_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the center bar widget of the bar.