package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Alternative_trigger

type t = [ `alternative_trigger | `shortcut_trigger | `object_ ] Gobject.obj
val new_ : [ `shortcut_trigger | `object_ ] Gobject.obj -> [ `shortcut_trigger | `object_ ] Gobject.obj -> t

Create a new AlternativeTrigger

val get_second : t -> [ `shortcut_trigger | `object_ ] Gobject.obj

Gets the second of the two alternative triggers that may trigger @self.

method@Gtk.AlternativeTrigger.get_first will return the other one.

val get_first : t -> [ `shortcut_trigger | `object_ ] Gobject.obj

Gets the first of the two alternative triggers that may trigger @self.

method@Gtk.AlternativeTrigger.get_second will return the other one.