package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.App_chooser_dialog

type t = [ `app_chooser_dialog | `dialog | `window | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : [ `window | `widget | `initially_unowned | `object_ ] Gobject.obj option -> Gtk_enums.dialogflags -> Ocgtk_gio.Gio.Wrappers.File.t -> t

Create a new AppChooserDialog

val new_for_content_type : [ `window | `widget | `initially_unowned | `object_ ] Gobject.obj option -> Gtk_enums.dialogflags -> string -> t

Create a new AppChooserDialog

val set_heading : t -> string -> unit

Sets the text to display at the top of the dialog.

If the heading is not set, the dialog displays a default text.

val get_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj

Returns the `GtkAppChooserWidget` of this dialog.

val get_heading : t -> string option

Returns the text to display at the top of the dialog.

val get_gfile : t -> Ocgtk_gio.Gio.Wrappers.File.t

Get property: gfile