package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Aspect_frame

type t = [ `aspect_frame | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : float -> float -> float -> bool -> t

Create a new AspectFrame

val set_yalign : t -> float -> unit

Sets the vertical alignment of the child within the allocation of the `GtkAspectFrame`.

val set_xalign : t -> float -> unit

Sets the horizontal alignment of the child within the allocation of the `GtkAspectFrame`.

val set_ratio : t -> float -> unit

Sets the desired aspect ratio of the child.

val set_obey_child : t -> bool -> unit

Sets whether the aspect ratio of the child's size request should override the set aspect ratio of the `GtkAspectFrame`.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child widget of @self.

val get_yalign : t -> float

Returns the vertical alignment of the child within the allocation of the `GtkAspectFrame`.

val get_xalign : t -> float

Returns the horizontal alignment of the child within the allocation of the `GtkAspectFrame`.

val get_ratio : t -> float

Returns the desired aspect ratio of the child.

val get_obey_child : t -> bool

Returns whether the child's size request should override the set aspect ratio of the `GtkAspectFrame`.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget of @self.