package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Bookmark_list

type t = [ `bookmark_list | `object_ ] Gobject.obj
val new_ : string option -> string option -> t

Create a new BookmarkList

val set_io_priority : t -> int -> unit

Sets the IO priority to use while loading files.

The default IO priority is %G_PRIORITY_DEFAULT.

val set_attributes : t -> string option -> unit

Sets the @attributes to be enumerated and starts the enumeration.

If @attributes is %NULL, no attributes will be queried, but a list of `GFileInfo`s will still be created.

val is_loading : t -> bool

Returns %TRUE if the files are currently being loaded.

Files will be added to @self from time to time while loading is going on. The order in which are added is undefined and may change in between runs.

val get_io_priority : t -> int

Gets the IO priority to use while loading file.

val get_filename : t -> string

Returns the filename of the bookmark file that this list is loading.

val get_attributes : t -> string option

Gets the attributes queried on the children.

val get_item_type : t -> Gobject.Type.t

Get property: item-type

val get_loading : t -> bool

Get property: loading

val get_n_items : t -> int

Get property: n-items