package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Box_layout

type t = [ `box_layout | `layout_manager | `object_ ] Gobject.obj
val new_ : Gtk_enums.orientation -> t

Create a new BoxLayout

val set_spacing : t -> int -> unit

Sets how much spacing to put between children.

val set_homogeneous : t -> bool -> unit

Sets whether the box layout will allocate the same size to all children.

val set_baseline_position : t -> Gtk_enums.baselineposition -> unit

Sets the baseline position of a box layout.

The baseline position affects only horizontal boxes with at least one baseline aligned child. If there is more vertical space available than requested, and the baseline is not allocated by the parent then the given @position is used to allocate the baseline within the extra space available.

val set_baseline_child : t -> int -> unit

Sets the index of the child that determines the baseline in vertical layout.

val get_spacing : t -> int

Returns the space that @box_layout puts between children.

val get_homogeneous : t -> bool

Returns whether the layout is set to be homogeneous.

val get_baseline_position : t -> Gtk_enums.baselineposition

Gets the value set by gtk_box_layout_set_baseline_position().

val get_baseline_child : t -> int

Gets the value set by gtk_box_layout_set_baseline_child().