package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Center_box

type t = [ `center_box | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new CenterBox

val set_start_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the start widget.

To remove the existing start widget, pass %NULL.

val set_shrink_center_last : t -> bool -> unit

Sets whether to shrink the center widget after other children.

By default, when there's no space to give all three children their natural widths, the start and end widgets start shrinking and the center child keeps natural width until they reach minimum width.

If set to `FALSE`, start and end widgets keep natural width and the center widget starts shrinking instead.

val set_end_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the end widget.

To remove the existing end widget, pass %NULL.

val set_center_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the center widget.

To remove the existing center widget, pass %NULL.

val set_baseline_position : t -> Gtk_enums.baselineposition -> unit

Sets the baseline position of a center box.

This affects only horizontal boxes with at least one baseline aligned child. If there is more vertical space available than requested, and the baseline is not allocated by the parent then @position is used to allocate the baseline wrt. the extra space available.

val get_start_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the start widget, or %NULL if there is none.

val get_shrink_center_last : t -> bool

Gets whether @self shrinks the center widget after other children.

val get_end_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the end widget, or %NULL if there is none.

val get_center_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the center widget, or %NULL if there is none.

val get_baseline_position : t -> Gtk_enums.baselineposition

Gets the value set by gtk_center_box_set_baseline_position().