package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Center_layout

type t = [ `center_layout | `layout_manager | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new CenterLayout

val set_start_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the new start widget of @self.

To remove the existing start widget, pass %NULL.

val set_shrink_center_last : t -> bool -> unit

Sets whether to shrink the center widget after other children.

By default, when there's no space to give all three children their natural widths, the start and end widgets start shrinking and the center child keeps natural width until they reach minimum width.

If set to `FALSE`, start and end widgets keep natural width and the center widget starts shrinking instead.

val set_orientation : t -> Gtk_enums.orientation -> unit

Sets the orientation of @self.

val set_end_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the new end widget of @self.

To remove the existing center widget, pass %NULL.

val set_center_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the new center widget of @self.

To remove the existing center widget, pass %NULL.

val set_baseline_position : t -> Gtk_enums.baselineposition -> unit

Sets the new baseline position of @self

val get_start_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Returns the start widget of the layout.

val get_shrink_center_last : t -> bool

Gets whether @self shrinks the center widget after other children.

val get_orientation : t -> Gtk_enums.orientation

Gets the current orienration of the layout manager.

val get_end_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Returns the end widget of the layout.

val get_center_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Returns the center widget of the layout.

val get_baseline_position : t -> Gtk_enums.baselineposition

Returns the baseline position of the layout.