package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Column_view_cell

type t = [ `column_view_cell | `list_item | `object_ ] Gobject.obj
val set_focusable : t -> bool -> unit

Sets @self to be focusable.

If an item is focusable, it can be focused using the keyboard. This works similar to method@Gtk.Widget.set_focusable.

Note that if items are not focusable, the keyboard cannot be used to activate them and selecting only works if one of the listitem's children is focusable.

By default, list items are focusable.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child to be used for this listitem.

This function is typically called by applications when setting up a listitem so that the widget can be reused when binding it multiple times.

val get_selected : t -> bool

Checks if the item is displayed as selected.

The selected state is maintained by the liste widget and its model and cannot be set otherwise.

val get_position : t -> int

Gets the position in the model that @self currently displays.

If @self is unbound, %GTK_INVALID_LIST_POSITION is returned.

val get_item : t -> [ `object_ ] Gobject.obj option

Gets the model item that associated with @self.

If @self is unbound, this function returns %NULL.

val get_focusable : t -> bool

Checks if a list item has been set to be focusable via gtk_column_view_cell_set_focusable().

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child previously set via gtk_column_view_cell_set_child() or %NULL if none was set.