package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Column_view_column

type t = [ `column_view_column | `object_ ] Gobject.obj
val new_ : string option -> [ `list_item_factory | `object_ ] Gobject.obj option -> t

Create a new ColumnViewColumn

val set_visible : t -> bool -> unit

Sets whether this column should be visible in views.

val set_title : t -> string option -> unit

Sets the title of this column.

The title is displayed in the header of a `GtkColumnView` for this column and is therefore user-facing text that should be translated.

val set_sorter : t -> [ `sorter | `object_ ] Gobject.obj option -> unit

Associates a sorter with the column.

If @sorter is %NULL, the column will not let users change the sorting by clicking on its header.

This sorter can be made active by clicking on the column header, or by calling method@Gtk.ColumnView.sort_by_column.

See method@Gtk.ColumnView.get_sorter for the necessary steps for setting up customizable sorting for class@Gtk.ColumnView.

val set_resizable : t -> bool -> unit

Sets whether this column should be resizable by dragging.

val set_id : t -> string option -> unit

Sets the id of this column.

GTK makes no use of this, but applications can use it when storing column view configuration.

It is up to callers to ensure uniqueness of IDs.

val set_header_menu : t -> Ocgtk_gio.Gio.Wrappers.Menu_model.t option -> unit

Sets the menu model that is used to create the context menu for the column header.

val set_fixed_width : t -> int -> unit

If @fixed_width is not -1, sets the fixed width of @column; otherwise unsets it.

Setting a fixed width overrides the automatically calculated width. Interactive resizing also sets the “fixed-width” property.

val set_factory : t -> [ `list_item_factory | `object_ ] Gobject.obj option -> unit

Sets the `GtkListItemFactory` to use for populating list items for this column.

val set_expand : t -> bool -> unit

Sets the column to take available extra space.

The extra space is shared equally amongst all columns that have the expand set to %TRUE.

val get_visible : t -> bool

Returns whether this column is visible.

val get_title : t -> string option

Returns the title set with gtk_column_view_column_set_title().

val get_sorter : t -> [ `sorter | `object_ ] Gobject.obj option

Returns the sorter that is associated with the column.

val get_resizable : t -> bool

Returns whether this column is resizable.

val get_id : t -> string option

Returns the ID set with gtk_column_view_column_set_id().

val get_header_menu : t -> Ocgtk_gio.Gio.Wrappers.Menu_model.t option

Gets the menu model that is used to create the context menu for the column header.

val get_fixed_width : t -> int

Gets the fixed width of the column.

val get_factory : t -> [ `list_item_factory | `object_ ] Gobject.obj option

Gets the factory that's currently used to populate list items for this column.

val get_expand : t -> bool

Returns whether this column should expand.

val get_column_view : t -> [ `column_view | `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the column view that's currently displaying this column.

If @self has not been added to a column view yet, %NULL is returned.