package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Combo_box_text

type t = [ `combo_box_text | `combo_box | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new ComboBoxText

val new_with_entry : unit -> t

Create a new ComboBoxText

val remove_all : t -> unit

Removes all the text entries from the combo box.

val remove : t -> int -> unit

Removes the string at @position from @combo_box.

val prepend_text : t -> string -> unit

Prepends @text to the list of strings stored in @combo_box.

This is the same as calling method@Gtk.ComboBoxText.insert_text with a position of 0.

val prepend : t -> string option -> string -> unit

Prepends @text to the list of strings stored in @combo_box.

If @id is non-%NULL then it is used as the ID of the row.

This is the same as calling method@Gtk.ComboBoxText.insert with a position of 0.

val insert_text : t -> int -> string -> unit

Inserts @text at @position in the list of strings stored in @combo_box.

If @position is negative then @text is appended.

This is the same as calling method@Gtk.ComboBoxText.insert with a %NULL ID string.

val insert : t -> int -> string option -> string -> unit

Inserts @text at @position in the list of strings stored in @combo_box.

If @id is non-%NULL then it is used as the ID of the row. See property@Gtk.ComboBox:id-column.

If @position is negative then @text is appended.

val get_active_text : t -> string option

Returns the currently active string in @combo_box.

If no row is currently selected, %NULL is returned. If @combo_box contains an entry, this function will return its contents (which will not necessarily be an item from the list).

val append_text : t -> string -> unit

Appends @text to the list of strings stored in @combo_box.

This is the same as calling method@Gtk.ComboBoxText.insert_text with a position of -1.

val append : t -> string option -> string -> unit

Appends @text to the list of strings stored in @combo_box.

If @id is non-%NULL then it is used as the ID of the row.

This is the same as calling method@Gtk.ComboBoxText.insert with a position of -1.