package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Constraint

type t = [ `constraint_ | `object_ ] Gobject.obj
val new_ : [ `constraint_target ] Gobject.obj option -> Gtk_enums.constraintattribute -> Gtk_enums.constraintrelation -> [ `constraint_target ] Gobject.obj option -> Gtk_enums.constraintattribute -> float -> float -> int -> t

Create a new Constraint

val new_constant : [ `constraint_target ] Gobject.obj option -> Gtk_enums.constraintattribute -> Gtk_enums.constraintrelation -> float -> int -> t

Create a new Constraint

val is_required : t -> bool

Checks whether the constraint is a required relation for solving the constraint layout.

val is_constant : t -> bool

Checks whether the constraint describes a relation between an attribute on the property@Gtk.Constraint:target and a constant value.

val is_attached : t -> bool

Checks whether the constraint is attached to a class@Gtk.ConstraintLayout, and it is contributing to the layout.

val get_target_attribute : t -> Gtk_enums.constraintattribute

Retrieves the attribute of the target to be set by the constraint.

val get_target : t -> [ `constraint_target ] Gobject.obj option

Retrieves the iface@Gtk.ConstraintTarget used as the target for the constraint.

If the targe is set to `NULL` at creation, the constraint will use the widget using the class@Gtk.ConstraintLayout as the target.

val get_strength : t -> int

Retrieves the strength of the constraint.

val get_source_attribute : t -> Gtk_enums.constraintattribute

Retrieves the attribute of the source to be read by the constraint.

val get_source : t -> [ `constraint_target ] Gobject.obj option

Retrieves the iface@Gtk.ConstraintTarget used as the source for the constraint.

If the source is set to `NULL` at creation, the constraint will use the widget using the class@Gtk.ConstraintLayout as the source.

val get_relation : t -> Gtk_enums.constraintrelation

The order relation between the terms of the constraint.

val get_multiplier : t -> float

Retrieves the multiplication factor applied to the source attribute's value.

val get_constant : t -> float

Retrieves the constant factor added to the source attributes' value.