package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Constraint_guide

type t = [ `constraint_guide | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new ConstraintGuide

val set_strength : t -> Gtk_enums.constraintstrength -> unit

Sets the strength of the constraint on the natural size of the given `GtkConstraintGuide`.

val set_nat_size : t -> int -> int -> unit

Sets the natural size of @guide.

If @guide is attached to a `GtkConstraintLayout`, the constraints will be updated to reflect the new size.

val set_name : t -> string option -> unit

Sets a name for the given `GtkConstraintGuide`.

The name is useful for debugging purposes.

val set_min_size : t -> int -> int -> unit

Sets the minimum size of @guide.

If @guide is attached to a `GtkConstraintLayout`, the constraints will be updated to reflect the new size.

val set_max_size : t -> int -> int -> unit

Sets the maximum size of @guide.

If @guide is attached to a `GtkConstraintLayout`, the constraints will be updated to reflect the new size.

val get_strength : t -> Gtk_enums.constraintstrength

Retrieves the strength set using gtk_constraint_guide_set_strength().

val get_nat_size : t -> int * int

Gets the natural size of @guide.

val get_name : t -> string option

Retrieves the name set using gtk_constraint_guide_set_name().

val get_min_size : t -> int * int

Gets the minimum size of @guide.

val get_max_size : t -> int * int

Gets the maximum size of @guide.

val get_max_height : t -> int

Get property: max-height

val set_max_height : t -> int -> unit

Set property: max-height

val get_max_width : t -> int

Get property: max-width

val set_max_width : t -> int -> unit

Set property: max-width

val get_min_height : t -> int

Get property: min-height

val set_min_height : t -> int -> unit

Set property: min-height

val get_min_width : t -> int

Get property: min-width

val set_min_width : t -> int -> unit

Set property: min-width

val get_nat_height : t -> int

Get property: nat-height

val set_nat_height : t -> int -> unit

Set property: nat-height

val get_nat_width : t -> int

Get property: nat-width

val set_nat_width : t -> int -> unit

Set property: nat-width