package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Constraint_layout

type t = [ `constraint_layout | `layout_manager | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new ConstraintLayout

val remove_guide : t -> [ `constraint_guide | `object_ ] Gobject.obj -> unit

Removes `guide` from the layout manager, so that it no longer influences the layout.

val remove_constraint : t -> [ `constraint_ | `object_ ] Gobject.obj -> unit

Removes `constraint` from the layout manager, so that it no longer influences the layout.

val remove_all_constraints : t -> unit

Removes all constraints from the layout manager.

val observe_guides : t -> Ocgtk_gio.Gio.Wrappers.List_model.t

Returns a `GListModel` to track the guides that are part of the layout.

Calling this function will enable extra internal bookkeeping to track guides and emit signals on the returned listmodel. It may slow down operations a lot.

Applications should try hard to avoid calling this function because of the slowdowns.

val observe_constraints : t -> Ocgtk_gio.Gio.Wrappers.List_model.t

Returns a `GListModel` to track the constraints that are part of the layout.

Calling this function will enable extra internal bookkeeping to track constraints and emit signals on the returned listmodel. It may slow down operations a lot.

Applications should try hard to avoid calling this function because of the slowdowns.

val add_guide : t -> [ `constraint_guide | `object_ ] Gobject.obj -> unit

Adds a guide to `layout`.

A guide can be used as the source or target of constraints, like a widget, but it is not visible.

The `layout` acquires the ownership of `guide` after calling this function.

val add_constraint : t -> [ `constraint_ | `object_ ] Gobject.obj -> unit

Adds a constraint to the layout manager.

The property@Gtk.Constraint:source and property@Gtk.Constraint:target properties of `constraint` can be:

  • set to `NULL` to indicate that the constraint refers to the widget using `layout`
  • set to the class@Gtk.Widget using `layout`
  • set to a child of the class@Gtk.Widget using `layout`
  • set to a class@Gtk.ConstraintGuide that is part of `layout`

The @layout acquires the ownership of @constraint after calling this function.