package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Drop_target_async

type t = [ `drop_target_async | `event_controller | `object_ ] Gobject.obj

Create a new DropTargetAsync

val set_formats : t -> Ocgtk_gdk.Gdk.Wrappers.Content_formats.t option -> unit

Sets the data formats that this drop target will accept.

val set_actions : t -> Ocgtk_gdk.Gdk.dragaction -> unit

Sets the actions that this drop target supports.

val reject_drop : t -> Ocgtk_gdk.Gdk.Wrappers.Drop.t -> unit

Sets the @drop as not accepted on this drag site.

This function should be used when delaying the decision on whether to accept a drag or not until after reading the data.

val get_formats : t -> Ocgtk_gdk.Gdk.Wrappers.Content_formats.t option

Gets the data formats that this drop target accepts.

If the result is %NULL, all formats are expected to be supported.

val get_actions : t -> Ocgtk_gdk.Gdk.dragaction

Gets the actions that this drop target supports.

val on_accept : ?after:bool -> t -> callback:(drop:Ocgtk_gdk.Gdk.Wrappers.Drop.t -> bool) -> Gobject.Signal.handler_id
val on_drag_enter : ?after:bool -> t -> callback: (drop:Ocgtk_gdk.Gdk.Wrappers.Drop.t -> x:float -> y:float -> Ocgtk_gdk.Gdk_enums.dragaction) -> Gobject.Signal.handler_id
val on_drag_leave : ?after:bool -> t -> callback:(drop:Ocgtk_gdk.Gdk.Wrappers.Drop.t -> unit) -> Gobject.Signal.handler_id
val on_drag_motion : ?after:bool -> t -> callback: (drop:Ocgtk_gdk.Gdk.Wrappers.Drop.t -> x:float -> y:float -> Ocgtk_gdk.Gdk_enums.dragaction) -> Gobject.Signal.handler_id
val on_drop : ?after:bool -> t -> callback:(drop:Ocgtk_gdk.Gdk.Wrappers.Drop.t -> x:float -> y:float -> bool) -> Gobject.Signal.handler_id