package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Editable_label

type t = [ `editable_label | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : string -> t

Create a new EditableLabel

val stop_editing : t -> bool -> unit

Switches the label out of “editing mode”.

If @commit is %TRUE, the resulting text is kept as the property@Gtk.Editable:text property value, otherwise the resulting text is discarded and the label will keep its previous property@Gtk.Editable:text property value.

val start_editing : t -> unit

Switches the label into “editing mode”.

val get_editing : t -> bool

Returns whether the label is currently in “editing mode”.