package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Event_controller_key

type t = [ `event_controller_key | `event_controller | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new EventControllerKey

val set_im_context : t -> [ `im_context | `object_ ] Gobject.obj option -> unit

Sets the input method context of the key @controller.

val get_im_context : t -> [ `im_context | `object_ ] Gobject.obj option

Gets the input method context of the key @controller.

val get_group : t -> int

Gets the key group of the current event of this @controller.

See method@Gdk.KeyEvent.get_layout.

val forward : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> bool

Forwards the current event of this @controller to a @widget.

This function can only be used in handlers for the signal@Gtk.EventControllerKey::key-pressed, signal@Gtk.EventControllerKey::key-released or signal@Gtk.EventControllerKey::modifiers signals.

val on_im_update : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_key_pressed : ?after:bool -> t -> callback: (keyval:int -> keycode:int -> state:Ocgtk_gdk.Gdk_enums.modifiertype -> bool) -> Gobject.Signal.handler_id
val on_key_released : ?after:bool -> t -> callback: (keyval:int -> keycode:int -> state:Ocgtk_gdk.Gdk_enums.modifiertype -> unit) -> Gobject.Signal.handler_id
val on_modifiers : ?after:bool -> t -> callback:(state:Ocgtk_gdk.Gdk_enums.modifiertype -> bool) -> Gobject.Signal.handler_id