package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Expander

type t = [ `expander | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : string option -> t

Create a new Expander

val new_with_mnemonic : string option -> t

Create a new Expander

val set_use_underline : t -> bool -> unit

If true, an underline in the text indicates a mnemonic.

val set_use_markup : t -> bool -> unit

Sets whether the text of the label contains Pango markup.

val set_resize_toplevel : t -> bool -> unit

Sets whether the expander will resize the toplevel widget containing the expander upon resizing and collapsing.

val set_label_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Set the label widget for the expander.

This is the widget that will appear embedded alongside the expander arrow.

val set_label : t -> string option -> unit

Sets the text of the label of the expander to @label.

This will also clear any previously set labels.

val set_expanded : t -> bool -> unit

Sets the state of the expander.

Set to %TRUE, if you want the child widget to be revealed, and %FALSE if you want the child widget to be hidden.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child widget of @expander.

val get_use_underline : t -> bool

Returns whether an underline in the text indicates a mnemonic.

val get_use_markup : t -> bool

Returns whether the label’s text is interpreted as Pango markup.

val get_resize_toplevel : t -> bool

Returns whether the expander will resize the toplevel widget containing the expander upon resizing and collapsing.

val get_label_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the label widget for the frame.

val get_label : t -> string option

Fetches the text from a label widget.

This is including any embedded underlines indicating mnemonics and Pango markup, as set by method@Gtk.Expander.set_label. If the label text has not been set the return value will be %NULL. This will be the case if you create an empty button with gtk_button_new() to use as a container.

val get_expanded : t -> bool

Queries a `GtkExpander` and returns its current state.

Returns %TRUE if the child widget is revealed.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget of @expander.

val on_activate : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id