package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Expression_watch

type t = [ `expression_watch ] Gobject.obj

An opaque structure representing a watched `GtkExpression`.

The contents of `GtkExpressionWatch` should only be accessed through the provided API.

val unwatch : t -> unit

Stops watching an expression.

See method@Gtk.Expression.watch for how the watch was established.

val ref : t -> t

Acquires a reference on the given `GtkExpressionWatch`.

val evaluate : t -> Gobject.Value.t -> bool

Evaluates the watched expression and on success stores the result in `value`.

This is equivalent to calling method@Gtk.Expression.evaluate with the expression and this pointer originally used to create `watch`.

val get_type : unit -> Gobject.Type.t