package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.File_chooser_native

type t = [ `file_chooser_native | `native_dialog | `object_ ] Gobject.obj
val new_ : string option -> [ `window | `widget | `initially_unowned | `object_ ] Gobject.obj option -> Gtk_enums.filechooseraction -> string option -> string option -> t

Create a new FileChooserNative

val set_cancel_label : t -> string option -> unit

Sets the custom label text for the cancel button.

If characters in @label are preceded by an underscore, they are underlined. If you need a literal underscore character in a label, use “__” (two underscores). The first underlined character represents a keyboard accelerator called a mnemonic.

Pressing Alt and that key should activate the button.

val set_accept_label : t -> string option -> unit

Sets the custom label text for the accept button.

If characters in @label are preceded by an underscore, they are underlined. If you need a literal underscore character in a label, use “__” (two underscores). The first underlined character represents a keyboard accelerator called a mnemonic.

Pressing Alt and that key should activate the button.

val get_cancel_label : t -> string option

Retrieves the custom label text for the cancel button.

val get_accept_label : t -> string option

Retrieves the custom label text for the accept button.