package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.File_launcher

type t = [ `file_launcher | `object_ ] Gobject.obj
val new_ : Ocgtk_gio.Gio.Wrappers.File.t option -> t

Create a new FileLauncher

val set_writable : t -> bool -> unit

Sets whether to make the file writable for the handler.

val set_file : t -> Ocgtk_gio.Gio.Wrappers.File.t option -> unit

Sets the file that will be opened.

val set_always_ask : t -> bool -> unit

Sets whether to awlays ask the user to choose an app for opening the file. If `FALSE`, the file might be opened with a default app or the previous choice.

val open_containing_folder_finish : t -> Ocgtk_gio.Gio.Wrappers.Async_result.t -> (bool, GError.t) result

Finishes the method@Gtk.FileLauncher.open_containing_folder call and returns the result.

val launch_finish : t -> Ocgtk_gio.Gio.Wrappers.Async_result.t -> (bool, GError.t) result

Finishes the method@Gtk.FileLauncher.launch call and returns the result.

val get_writable : t -> bool

Returns whether to make the file writable for the handler.

val get_file : t -> Ocgtk_gio.Gio.Wrappers.File.t option

Gets the file that will be opened.

val get_always_ask : t -> bool

Returns whether to ask the user to choose an app for opening the file.