package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Fixed

type t = [ `fixed | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new Fixed

val set_child_transform : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> Ocgtk_gsk.Gsk.Wrappers.Transform.t option -> unit

Sets the transformation for @widget.

This is a convenience function that retrieves the class@Gtk.FixedLayoutChild instance associated to @widget and calls method@Gtk.FixedLayoutChild.set_transform.

val remove : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> unit

Removes a child from @fixed.

val put : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> float -> float -> unit

Adds a widget to a `GtkFixed` at the given position.

val move : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> float -> float -> unit

Sets a translation transformation to the given @x and @y coordinates to the child @widget of the `GtkFixed`.

val get_child_transform : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> Ocgtk_gsk.Gsk.Wrappers.Transform.t option

Retrieves the transformation for @widget set using gtk_fixed_set_child_transform().

val get_child_position : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> float * float

Retrieves the translation transformation of the given child `GtkWidget` in the `GtkFixed`.

See also: method@Gtk.Fixed.get_child_transform.