package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Flow_box_child

type t = [ `flow_box_child | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new FlowBoxChild

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child widget of @self.

val is_selected : t -> bool

Returns whether the @child is currently selected in its `GtkFlowBox` container.

val get_index : t -> int

Gets the current index of the @child in its `GtkFlowBox` container.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget of @self.

val changed : t -> unit

Marks @child as changed, causing any state that depends on this to be updated.

This affects sorting and filtering.

Note that calls to this method must be in sync with the data used for the sorting and filtering functions. For instance, if the list is mirroring some external data set, and *two* children changed in the external data set when you call gtk_flow_box_child_changed() on the first child, the sort function must only read the new data for the first of the two changed children, otherwise the resorting of the children will be wrong.

This generally means that if you don’t fully control the data model, you have to duplicate the data that affects the sorting and filtering functions into the widgets themselves.

Another alternative is to call method@Gtk.FlowBox.invalidate_sort on any model change, but that is more expensive.

val on_activate : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id