package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Font_dialog

type t = [ `font_dialog | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new FontDialog

val set_title : t -> string -> unit

Sets the title that will be shown on the font chooser dialog.

val set_modal : t -> bool -> unit

Sets whether the font chooser dialog blocks interaction with the parent window while it is presented.

val set_language : t -> Ocgtk_pango.Pango.Wrappers.Language.t -> unit

Sets the language for which font features are applied.

val set_font_map : t -> Ocgtk_pango.Pango.Wrappers.Font_map.t option -> unit

Sets the fontmap from which fonts are selected.

If @fontmap is `NULL`, the default fontmap is used.

val set_filter : t -> [ `filter | `object_ ] Gobject.obj option -> unit

Adds a filter that decides which fonts to display in the font chooser dialog.

The `GtkFilter` must be able to handle both `PangoFontFamily` and `PangoFontFace` objects.

val get_title : t -> string

Returns the title that will be shown on the font chooser dialog.

val get_modal : t -> bool

Returns whether the font chooser dialog blocks interaction with the parent window while it is presented.

val get_language : t -> Ocgtk_pango.Pango.Wrappers.Language.t option

Returns the language for which font features are applied.

val get_font_map : t -> Ocgtk_pango.Pango.Wrappers.Font_map.t option

Returns the fontmap from which fonts are selected, or `NULL` for the default fontmap.

val get_filter : t -> [ `filter | `object_ ] Gobject.obj option

Returns the filter that decides which fonts to display in the font chooser dialog.

Finishes the method@Gtk.FontDialog.choose_font call and returns the resulting font description.

Finishes the method@Gtk.FontDialog.choose_family call and returns the resulting family.

This function never returns an error. If the operation is not finished successfully, the value passed as @initial_value to method@Gtk.FontDialog.choose_family is returned.

Finishes the method@Gtk.FontDialog.choose_face call and returns the resulting font face.