package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Font_dialog_button

type t = [ `font_dialog_button | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : [ `font_dialog | `object_ ] Gobject.obj option -> t

Create a new FontDialogButton

val set_use_size : t -> bool -> unit

If @use_size is `TRUE`, the font name will be written using the selected font size.

val set_use_font : t -> bool -> unit

If @use_font is `TRUE`, the font name will be written using the selected font.

val set_level : t -> Gtk_enums.fontlevel -> unit

Sets the level of detail at which this dialog lets the user select fonts.

val set_language : t -> Ocgtk_pango.Pango.Wrappers.Language.t option -> unit

Sets the language to use for font features.

val set_font_features : t -> string option -> unit

Sets the font features of the button.

val set_font_desc : t -> Ocgtk_pango.Pango.Wrappers.Font_description.t -> unit

Sets the font of the button.

val set_dialog : t -> [ `font_dialog | `object_ ] Gobject.obj -> unit

Sets a `GtkFontDialog` object to use for creating the font chooser dialog that is presented when the user clicks the button.

val get_use_size : t -> bool

Returns whether the selected font size is used in the label.

val get_use_font : t -> bool

Returns whether the selected font is used in the label.

val get_level : t -> Gtk_enums.fontlevel

Returns the level of detail at which this dialog lets the user select fonts.

val get_language : t -> Ocgtk_pango.Pango.Wrappers.Language.t option

Returns the language that is used for font features.

val get_font_features : t -> string option

Returns the font features of the button.

This function is what should be used to obtain the font features that were chosen by the user. To get informed about changes, listen to "notify::font-features".

Note that the button will only let users choose font features if property@Gtk.FontDialogButton:level is set to `GTK_FONT_LEVEL_FEATURES`.

val get_font_desc : t -> Ocgtk_pango.Pango.Wrappers.Font_description.t option

Returns the font of the button.

This function is what should be used to obtain the font that was chosen by the user. To get informed about changes, listen to "notify::font-desc".

val get_dialog : t -> [ `font_dialog | `object_ ] Gobject.obj option

Returns the `GtkFontDialog` of @self.

val on_activate : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id