package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Frame

type t = [ `frame | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : string option -> t

Create a new Frame

val set_label_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the label widget for the frame.

This is the widget that will appear embedded in the top edge of the frame as a title.

val set_label_align : t -> float -> unit

Sets the X alignment of the frame widget’s label.

The default value for a newly created frame is 0.0.

val set_label : t -> string option -> unit

Creates a new `GtkLabel` with the @label and sets it as the frame's label widget.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child widget of @frame.

val get_label_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the label widget for the frame.

val get_label_align : t -> float

Retrieves the X alignment of the frame’s label.

val get_label : t -> string option

Returns the frame labels text.

If the frame's label widget is not a `GtkLabel`, %NULL is returned.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget of @frame.

val get_label_xalign : t -> float

Get property: label-xalign

val set_label_xalign : t -> float -> unit

Set property: label-xalign