package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Gesture_pan

type t = [ `gesture_pan | `gesture_drag | `gesture_single | `gesture | `event_controller | `object_ ] Gobject.obj
val new_ : Gtk_enums.orientation -> t

Create a new GesturePan

val set_orientation : t -> Gtk_enums.orientation -> unit

Sets the orientation to be expected on pan gestures.

val get_orientation : t -> Gtk_enums.orientation

Returns the orientation of the pan gestures that this @gesture expects.

val on_pan : ?after:bool -> t -> callback:(direction:Gtk_enums.pandirection -> offset:float -> unit) -> Gobject.Signal.handler_id