package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Gesture_swipe

type t = [ `gesture_swipe | `gesture_single | `gesture | `event_controller | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new GestureSwipe

val get_velocity : t -> bool * float * float

Gets the current velocity.

If the gesture is recognized, this function returns %TRUE and fills in @velocity_x and @velocity_y with the recorded velocity, as per the last events processed.

val on_swipe : ?after:bool -> t -> callback:(velocity_x:float -> velocity_y:float -> unit) -> Gobject.Signal.handler_id