package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Im_context

type t = [ `im_context | `object_ ] Gobject.obj
val set_use_preedit : t -> bool -> unit

Sets whether the IM context should use the preedit string to display feedback.

If @use_preedit is %FALSE (default is %TRUE), then the IM context may use some other method to display feedback, such as displaying it in a child of the root window.

val set_surrounding_with_selection : t -> string -> int -> int -> int -> unit

Sets surrounding context around the insertion point and preedit string. This function is expected to be called in response to the signal@Gtk.IMContext::retrieve_surrounding signal, and will likely have no effect if called at other times.

val set_surrounding : t -> string -> int -> int -> unit

Sets surrounding context around the insertion point and preedit string.

This function is expected to be called in response to the signal@Gtk.IMContext::retrieve-surrounding signal, and will likely have no effect if called at other times.

val set_cursor_location : t -> Ocgtk_gdk.Gdk.Wrappers.Rectangle.t -> unit

Notify the input method that a change in cursor position has been made.

The location is relative to the client widget.

val set_client_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Set the client widget for the input context.

This is the `GtkWidget` holding the input focus. This widget is used in order to correctly position status windows, and may also be used for purposes internal to the input method.

val reset : t -> unit

Notify the input method that a change such as a change in cursor position has been made.

This will typically cause the input method to clear the preedit state.

val focus_out : t -> unit

Notify the input method that the widget to which this input context corresponds has lost focus.

The input method may, for example, change the displayed feedback or reset the contexts state to reflect this change.

val focus_in : t -> unit

Notify the input method that the widget to which this input context corresponds has gained focus.

The input method may, for example, change the displayed feedback to reflect this change.

val filter_keypress : t -> Ocgtk_gdk.Gdk.Wrappers.Event.t -> bool

Allow an input method to internally handle key press and release events.

If this function returns %TRUE, then no further processing should be done for this key event.

Allow an input method to forward key press and release events to another input method without necessarily having a `GdkEvent` available.

val delete_surrounding : t -> int -> int -> bool

Asks the widget that the input context is attached to delete characters around the cursor position by emitting the `::delete_surrounding` signal.

Note that @offset and @n_chars are in characters not in bytes which differs from the usage other places in `GtkIMContext`.

In order to use this function, you should first call method@Gtk.IMContext.get_surrounding to get the current context, and call this function immediately afterwards to make sure that you know what you are deleting. You should also account for the fact that even if the signal was handled, the input context might not have deleted all the characters that were requested to be deleted.

This function is used by an input method that wants to make substitutions in the existing text in response to new input. It is not useful for applications.

val activate_osk : t -> Ocgtk_gdk.Gdk.Wrappers.Event.t option -> bool

Requests the platform to show an on-screen keyboard for user input.

This method will return %TRUE if this request was actually performed to the platform, other environmental factors may result in an on-screen keyboard effectively not showing up.

val get_input_hints : t -> Gtk_enums.inputhints

Get property: input-hints

val set_input_hints : t -> Gtk_enums.inputhints -> unit

Set property: input-hints

val get_input_purpose : t -> Gtk_enums.inputpurpose

Get property: input-purpose

val set_input_purpose : t -> Gtk_enums.inputpurpose -> unit

Set property: input-purpose

val on_commit : ?after:bool -> t -> callback:(str:string -> unit) -> Gobject.Signal.handler_id
val on_delete_surrounding : ?after:bool -> t -> callback:(offset:int -> n_chars:int -> bool) -> Gobject.Signal.handler_id
val on_preedit_changed : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_preedit_end : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_preedit_start : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_retrieve_surrounding : ?after:bool -> t -> callback:(unit -> bool) -> Gobject.Signal.handler_id