package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Im_multicontext

type t = [ `im_multicontext | `im_context | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new IMMulticontext

val set_context_id : t -> string option -> unit

Sets the context id for @context.

This causes the currently active delegate of @context to be replaced by the delegate corresponding to the new context id.

Setting this to a non-%NULL value overrides the system-wide IM module setting. See the property@Gtk.Settings:gtk-im-module property.

val get_context_id : t -> string

Gets the id of the currently active delegate of the @context.