package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Inscription

type t = [ `inscription | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : string option -> t

Create a new Inscription

val set_yalign : t -> float -> unit

Sets the `yalign` of the inscription.

See the property@Gtk.Inscription:yalign property.

val set_xalign : t -> float -> unit

Sets the `xalign` of the inscription.

See the property@Gtk.Inscription:xalign property.

val set_wrap_mode : t -> Ocgtk_pango.Pango.wrapmode -> unit

Controls how line wrapping is done.

val set_text_overflow : t -> Gtk_enums.inscriptionoverflow -> unit

Sets what to do when the text doesn't fit.

val set_text : t -> string option -> unit

Sets the text to be displayed.

val set_nat_lines : t -> int -> unit

Sets the `nat-lines` of the inscription.

See the property@Gtk.Inscription:nat-lines property.

val set_nat_chars : t -> int -> unit

Sets the `nat-chars` of the inscription.

See the property@Gtk.Inscription:nat-chars property.

val set_min_lines : t -> int -> unit

Sets the `min-lines` of the inscription.

See the property@Gtk.Inscription:min-lines property.

val set_min_chars : t -> int -> unit

Sets the `min-chars` of the inscription.

See the property@Gtk.Inscription:min-chars property.

val set_markup : t -> string option -> unit

Utility function to set the text and attributes to be displayed.

See the property@Gtk.Inscription:markup property.

val set_attributes : t -> Ocgtk_pango.Pango.Wrappers.Attr_list.t option -> unit

Apply attributes to the inscription text.

These attributes will not be evaluated for sizing the inscription.

val get_yalign : t -> float

Gets the `yalign` of the inscription.

See the property@Gtk.Inscription:yalign property.

val get_xalign : t -> float

Gets the `xalign` of the inscription.

See the property@Gtk.Inscription:xalign property.

val get_wrap_mode : t -> Ocgtk_pango.Pango.wrapmode

Returns line wrap mode used by the inscription.

See method@Gtk.Inscription.set_wrap_mode.

val get_text_overflow : t -> Gtk_enums.inscriptionoverflow

Gets the inscription's overflow method.

val get_text : t -> string option

Gets the text that is displayed.

val get_nat_lines : t -> int

Gets the `nat-lines` of the inscription.

See the property@Gtk.Inscription:nat-lines property.

val get_nat_chars : t -> int

Gets the `nat-chars` of the inscription.

See the property@Gtk.Inscription:nat-chars property.

val get_min_lines : t -> int

Gets the `min-lines` of the inscription.

See the property@Gtk.Inscription:min-lines property.

val get_min_chars : t -> int

Gets the `min-chars` of the inscription.

See the property@Gtk.Inscription:min-chars property.

val get_attributes : t -> Ocgtk_pango.Pango.Wrappers.Attr_list.t option

Gets the inscription's attribute list.