package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Layout_manager

type t = [ `layout_manager | `object_ ] Gobject.obj
val measure : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> Gtk_enums.orientation -> int -> int * int * int * int

Measures the size of the @widget using @manager, for the given @orientation and size.

See the class@Gtk.Widget documentation on layout management for more details.

val layout_changed : t -> unit

Queues a resize on the `GtkWidget` using @manager, if any.

This function should be called by subclasses of `GtkLayoutManager` in response to changes to their layout management policies.

val get_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the `GtkWidget` using the given `GtkLayoutManager`.

val get_request_mode : t -> Gtk_enums.sizerequestmode

Retrieves the request mode of @manager.

val get_layout_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> [ `layout_child | `object_ ] Gobject.obj

Retrieves a `GtkLayoutChild` instance for the `GtkLayoutManager`, creating one if necessary.

The @child widget must be a child of the widget using @manager.

The `GtkLayoutChild` instance is owned by the `GtkLayoutManager`, and is guaranteed to exist as long as @child is a child of the `GtkWidget` using the given `GtkLayoutManager`.

val allocate : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> int -> int -> int -> unit

Assigns the given @width, @height, and @baseline to a @widget, and computes the position and sizes of the children of the @widget using the layout management policy of @manager.