package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Level_bar

type t = [ `level_bar | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new LevelBar

val new_for_interval : float -> float -> t

Create a new LevelBar

val set_value : t -> float -> unit

Sets the value of the `GtkLevelBar`.

val set_mode : t -> Gtk_enums.levelbarmode -> unit

Sets the `mode` of the `GtkLevelBar`.

val set_min_value : t -> float -> unit

Sets the `min-value` of the `GtkLevelBar`.

You probably want to update preexisting level offsets after calling this function.

val set_max_value : t -> float -> unit

Sets the `max-value` of the `GtkLevelBar`.

You probably want to update preexisting level offsets after calling this function.

val set_inverted : t -> bool -> unit

Sets whether the `GtkLevelBar` is inverted.

val remove_offset_value : t -> string option -> unit

Removes an offset marker from a `GtkLevelBar`.

The marker must have been previously added with method@Gtk.LevelBar.add_offset_value.

val get_value : t -> float

Returns the `value` of the `GtkLevelBar`.

val get_offset_value : t -> string option -> bool * float

Fetches the value specified for the offset marker @name in @self.

val get_mode : t -> Gtk_enums.levelbarmode

Returns the `mode` of the `GtkLevelBar`.

val get_min_value : t -> float

Returns the `min-value` of the `GtkLevelBar`.

val get_max_value : t -> float

Returns the `max-value` of the `GtkLevelBar`.

val get_inverted : t -> bool

Returns whether the levelbar is inverted.

val add_offset_value : t -> string -> float -> unit

Adds a new offset marker on @self at the position specified by @value.

When the bar value is in the interval topped by @value (or between @value and property@Gtk.LevelBar:max-value in case the offset is the last one on the bar) a style class named `level-`@name will be applied when rendering the level bar fill.

If another offset marker named @name exists, its value will be replaced by @value.

val on_offset_changed : ?after:bool -> t -> callback:(name:string -> unit) -> Gobject.Signal.handler_id