package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Mount_operation

type t = [ `mount_operation | `object_ ] Gobject.obj
val new_ : [ `window | `widget | `initially_unowned | `object_ ] Gobject.obj option -> t

Create a new MountOperation

val set_parent : t -> [ `window | `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the transient parent for windows shown by the `GtkMountOperation`.

val set_display : t -> Ocgtk_gdk.Gdk.Wrappers.Display.t -> unit

Sets the display to show windows of the `GtkMountOperation` on.

val is_showing : t -> bool

Returns whether the `GtkMountOperation` is currently displaying a window.

val get_parent : t -> [ `window | `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the transient parent used by the `GtkMountOperation`.

val get_display : t -> Ocgtk_gdk.Gdk.Wrappers.Display.t

Gets the display on which windows of the `GtkMountOperation` will be shown.