package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Overlay

type t = [ `overlay | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new Overlay

val set_measure_overlay : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> bool -> unit

Sets whether @widget is included in the measured size of @overlay.

The overlay will request the size of the largest child that has this property set to %TRUE. Children who are not included may be drawn outside of @overlay's allocation if they are too large.

val set_clip_overlay : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> bool -> unit

Sets whether @widget should be clipped within the parent.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child widget of @overlay.

val remove_overlay : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> unit

Removes an overlay that was added with gtk_overlay_add_overlay().

val get_measure_overlay : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> bool

Gets whether @widget's size is included in the measurement of @overlay.

val get_clip_overlay : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> bool

Gets whether @widget should be clipped within the parent.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget of @overlay.

val add_overlay : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> unit

Adds @widget to @overlay.

The widget will be stacked on top of the main widget added with method@Gtk.Overlay.set_child.

The position at which @widget is placed is determined from its property@Gtk.Widget:halign and property@Gtk.Widget:valign properties.