package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Pad_controller

type t = [ `pad_controller | `event_controller | `object_ ] Gobject.obj

Create a new PadController

val set_action_entries : t -> [ `pad_action_entry ] Gobject.obj array -> int -> unit

A convenience function to add a group of action entries on @controller.

See struct@Gtk.PadActionEntry and method@Gtk.PadController.set_action.

val set_action : t -> Gtk_enums.padactiontype -> int -> int -> string -> string -> unit

Adds an individual action to @controller.

This action will only be activated if the given button/ring/strip number in @index is interacted while the current mode is @mode. -1 may be used for simple cases, so the action is triggered on all modes.

The given @label should be considered user-visible, so internationalization rules apply. Some windowing systems may be able to use those for user feedback.

val get_action_group : t -> Ocgtk_gio.Gio.Wrappers.Action_group.t

Get property: action-group

Get property: pad