package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Paned

type t = [ `paned | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : Gtk_enums.orientation -> t

Create a new Paned

val set_wide_handle : t -> bool -> unit

Sets whether the separator should be wide.

val set_start_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the start child of @paned to @child.

If @child is `NULL`, the existing child will be removed.

val set_shrink_start_child : t -> bool -> unit

Sets whether the property@Gtk.Paned:start-child can shrink.

val set_shrink_end_child : t -> bool -> unit

Sets whether the property@Gtk.Paned:end-child can shrink.

val set_resize_start_child : t -> bool -> unit

Sets whether the property@Gtk.Paned:start-child can be resized.

val set_resize_end_child : t -> bool -> unit

Sets whether the property@Gtk.Paned:end-child can be resized.

val set_position : t -> int -> unit

Sets the position of the divider between the two panes.

val set_end_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the end child of @paned to @child.

If @child is `NULL`, the existing child will be removed.

val get_wide_handle : t -> bool

Gets whether the separator should be wide.

val get_start_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the start child of the given `GtkPaned`.

val get_shrink_start_child : t -> bool

Returns whether the property@Gtk.Paned:start-child can shrink.

val get_shrink_end_child : t -> bool

Returns whether the property@Gtk.Paned:end-child can shrink.

val get_resize_start_child : t -> bool

Returns whether the property@Gtk.Paned:start-child can be resized.

val get_resize_end_child : t -> bool

Returns whether the property@Gtk.Paned:end-child can be resized.

val get_position : t -> int

Obtains the position of the divider between the two panes.

val get_end_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the end child of the given `GtkPaned`.

val get_max_position : t -> int

Get property: max-position

val get_min_position : t -> int

Get property: min-position

val get_position_set : t -> bool

Get property: position-set

val set_position_set : t -> bool -> unit

Set property: position-set

val on_accept_position : ?after:bool -> t -> callback:(unit -> bool) -> Gobject.Signal.handler_id
val on_cancel_position : ?after:bool -> t -> callback:(unit -> bool) -> Gobject.Signal.handler_id
val on_cycle_child_focus : ?after:bool -> t -> callback:(reversed:bool -> bool) -> Gobject.Signal.handler_id
val on_cycle_handle_focus : ?after:bool -> t -> callback:(reversed:bool -> bool) -> Gobject.Signal.handler_id
val on_move_handle : ?after:bool -> t -> callback:(scroll_type:Gtk_enums.scrolltype -> bool) -> Gobject.Signal.handler_id
val on_toggle_handle_focus : ?after:bool -> t -> callback:(unit -> bool) -> Gobject.Signal.handler_id