package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Password_entry

type t = [ `password_entry | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new PasswordEntry

val set_show_peek_icon : t -> bool -> unit

Sets whether the entry should have a clickable icon to reveal the contents.

Setting this to %FALSE also hides the text again.

val set_extra_menu : t -> Ocgtk_gio.Gio.Wrappers.Menu_model.t option -> unit

Sets a menu model to add when constructing the context menu for @entry.

val get_show_peek_icon : t -> bool

Returns whether the entry is showing an icon to reveal the contents.

val get_extra_menu : t -> Ocgtk_gio.Gio.Wrappers.Menu_model.t option

Gets the menu model set with gtk_password_entry_set_extra_menu().

val get_activates_default : t -> bool

Get property: activates-default

val set_activates_default : t -> bool -> unit

Set property: activates-default

val get_placeholder_text : t -> string

Get property: placeholder-text

val set_placeholder_text : t -> string -> unit

Set property: placeholder-text

val on_activate : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id