package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Popover_menu_bar

type t = [ `popover_menu_bar | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_from_model : Ocgtk_gio.Gio.Wrappers.Menu_model.t option -> t

Create a new PopoverMenuBar

val set_menu_model : t -> Ocgtk_gio.Gio.Wrappers.Menu_model.t option -> unit

Sets a menu model from which @bar should take its contents.

val remove_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> bool

Removes a widget that has previously been added with gtk_popover_menu_bar_add_child().

val get_menu_model : t -> Ocgtk_gio.Gio.Wrappers.Menu_model.t option

Returns the model from which the contents of @bar are taken.

val add_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> string -> bool

Adds a custom widget to a generated menubar.

For this to work, the menu model of @bar must have an item with a `custom` attribute that matches @id.