package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Print_setup

type t = [ `print_setup ] Gobject.obj

A `GtkPrintSetup` is an auxiliary object for printing that allows decoupling the setup from the printing.

A print setup is obtained by calling method@Gtk.PrintDialog.setup, and can later be passed to print functions such as method@Gtk.PrintDialog.print.

Print setups can be reused for multiple print calls.

Applications may wish to store the page_setup and print_settings from the print setup and copy them to the PrintDialog if they want to keep using them.

val ref : t -> t

Increase the reference count of @setup.

val get_print_settings : t -> [ `print_settings | `object_ ] Gobject.obj option

Returns the print settings of @setup.

They may be different from the `GtkPrintDialog`'s settings if the user changed them during the setup process.

val get_page_setup : t -> [ `page_setup | `object_ ] Gobject.obj option

Returns the page setup of @setup.

It may be different from the `GtkPrintDialog`'s page setup if the user changed it during the setup process.

val get_type : unit -> Gobject.Type.t