package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Recent_manager

type t = [ `recent_manager | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new RecentManager

val remove_item : t -> string -> (bool, GError.t) result

Removes a resource pointed by @uri from the recently used resources list handled by a recent manager.

val purge_items : t -> (int, GError.t) result

Purges every item from the recently used resources list.

val move_item : t -> string -> string option -> (bool, GError.t) result

Changes the location of a recently used resource from @uri to @new_uri.

Please note that this function will not affect the resource pointed by the URIs, but only the URI used in the recently used resources list.

val lookup_item : t -> string -> ([ `recent_info ] Gobject.obj option, GError.t) result

Searches for a URI inside the recently used resources list, and returns a `GtkRecentInfo` containing information about the resource like its MIME type, or its display name.

val has_item : t -> string -> bool

Checks whether there is a recently used resource registered with @uri inside the recent manager.

val get_items : t -> [ `recent_info ] Gobject.obj list

Gets the list of recently used resources.

val add_item : t -> string -> bool

Adds a new resource, pointed by @uri, into the recently used resources list.

This function automatically retrieves some of the needed metadata and setting other metadata to common default values; it then feeds the data to method@Gtk.RecentManager.add_full.

See method@Gtk.RecentManager.add_full if you want to explicitly define the metadata for the resource pointed by @uri.

val add_full : t -> string -> [ `recent_data ] Gobject.obj -> bool

Adds a new resource, pointed by @uri, into the recently used resources list, using the metadata specified inside the `GtkRecentData` passed in @recent_data.

The passed URI will be used to identify this resource inside the list.

In order to register the new recently used resource, metadata about the resource must be passed as well as the URI; the metadata is stored in a `GtkRecentData`, which must contain the MIME type of the resource pointed by the URI; the name of the application that is registering the item, and a command line to be used when launching the item.

Optionally, a `GtkRecentData` might contain a UTF-8 string to be used when viewing the item instead of the last component of the URI; a short description of the item; whether the item should be considered private - that is, should be displayed only by the applications that have registered it.

val get_filename : t -> string

Get property: filename

val get_size : t -> int

Get property: size

val on_changed : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id