package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Requested_size

type t = [ `requested_size ] Gobject.obj

Represents a request of a screen object in a given orientation. These are primarily used in container implementations when allocating a natural size for children calling. See func@distribute_natural_allocation.