package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Revealer

type t = [ `revealer | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new Revealer

val set_transition_type : t -> Gtk_enums.revealertransitiontype -> unit

Sets the type of animation that will be used for transitions in @revealer.

Available types include various kinds of fades and slides.

val set_transition_duration : t -> int -> unit

Sets the duration that transitions will take.

val set_reveal_child : t -> bool -> unit

Tells the `GtkRevealer` to reveal or conceal its child.

The transition will be animated with the current transition type of @revealer.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the child widget of @revealer.

val get_transition_type : t -> Gtk_enums.revealertransitiontype

Gets the type of animation that will be used for transitions in @revealer.

val get_transition_duration : t -> int

Returns the amount of time (in milliseconds) that transitions will take.

val get_reveal_child : t -> bool

Returns whether the child is currently revealed.

This function returns %TRUE as soon as the transition is to the revealed state is started. To learn whether the child is fully revealed (ie the transition is completed), use method@Gtk.Revealer.get_child_revealed.

val get_child_revealed : t -> bool

Returns whether the child is fully revealed.

In other words, this returns whether the transition to the revealed state is completed.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget of @revealer.