package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Scale_button

type t = [ `scale_button | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : float -> float -> float -> string array option -> t

Create a new ScaleButton

val set_value : t -> float -> unit

Sets the current value of the scale.

If the value is outside the minimum or maximum range values, it will be clamped to fit inside them.

The scale button emits the signal@Gtk.ScaleButton::value-changed signal if the value changes.

val set_icons : t -> string array -> unit

Sets the icons to be used by the scale button.

val set_has_frame : t -> bool -> unit

Sets the style of the button.

val set_adjustment : t -> [ `adjustment | `initially_unowned | `object_ ] Gobject.obj -> unit

Sets the `GtkAdjustment` to be used as a model for the `GtkScaleButton`’s scale.

See method@Gtk.Range.set_adjustment for details.

val get_value : t -> float

Gets the current value of the scale button.

val get_popup : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj

Retrieves the popup of the `GtkScaleButton`.

val get_plus_button : t -> [ `button | `widget | `initially_unowned | `object_ ] Gobject.obj

Retrieves the plus button of the `GtkScaleButton.`

val get_minus_button : t -> [ `button | `widget | `initially_unowned | `object_ ] Gobject.obj

Retrieves the minus button of the `GtkScaleButton`.

val get_has_frame : t -> bool

Returns whether the button has a frame.

val get_adjustment : t -> [ `adjustment | `initially_unowned | `object_ ] Gobject.obj

Gets the `GtkAdjustment` associated with the `GtkScaleButton`’s scale.

See method@Gtk.Range.get_adjustment for details.

val get_active : t -> bool

Queries a `GtkScaleButton` and returns its current state.

Returns %TRUE if the scale button is pressed in and %FALSE if it is raised.

val on_popdown : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_popup : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_value_changed : ?after:bool -> t -> callback:(value:float -> unit) -> Gobject.Signal.handler_id