package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Scroll_info

type t = [ `scroll_info ] Gobject.obj

The `GtkScrollInfo` can be used to provide more accurate data on how a scroll operation should be performed.

Scrolling functions usually allow passing a %NULL scroll info which will cause the default values to be used and just scroll the element into view.

val new_ : unit -> t

Create a new ScrollInfo

val set_enable_vertical : t -> bool -> unit

Turns vertical scrolling on or off.

val set_enable_horizontal : t -> bool -> unit

Turns horizontal scrolling on or off.

val ref : t -> t

Increases the reference count of a `GtkScrollInfo` by one.

val get_enable_vertical : t -> bool

Checks if vertical scrolling is enabled.

val get_enable_horizontal : t -> bool

Checks if horizontal scrolling is enabled.

val get_type : unit -> Gobject.Type.t