package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Scrollable

type t = [ `scrollable ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val set_vscroll_policy : t -> Gtk_enums.scrollablepolicy -> unit

Sets the `GtkScrollablePolicy`.

The policy determines whether vertical scrolling should start below the minimum height or below the natural height.

val set_vadjustment : t -> [ `adjustment | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the vertical adjustment of the `GtkScrollable`.

val set_hscroll_policy : t -> Gtk_enums.scrollablepolicy -> unit

Sets the `GtkScrollablePolicy`.

The policy determines whether horizontal scrolling should start below the minimum width or below the natural width.

val set_hadjustment : t -> [ `adjustment | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the horizontal adjustment of the `GtkScrollable`.

val get_vscroll_policy : t -> Gtk_enums.scrollablepolicy

Gets the vertical `GtkScrollablePolicy`.

val get_vadjustment : t -> [ `adjustment | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the `GtkAdjustment` used for vertical scrolling.

val get_hscroll_policy : t -> Gtk_enums.scrollablepolicy

Gets the horizontal `GtkScrollablePolicy`.

val get_hadjustment : t -> [ `adjustment | `initially_unowned | `object_ ] Gobject.obj option

Retrieves the `GtkAdjustment` used for horizontal scrolling.

val get_border : t -> bool * [ `border ] Gobject.obj

Returns the size of a non-scrolling border around the outside of the scrollable.

An example for this would be treeview headers. GTK can use this information to display overlaid graphics, like the overshoot indication, at the right position.