package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Search_entry

type t = [ `search_entry | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new SearchEntry

val set_search_delay : t -> int -> unit

Set the delay to be used between the last keypress and the signal@Gtk.SearchEntry::search-changed signal being emitted.

val set_placeholder_text : t -> string option -> unit

Sets the placeholder text associated with @entry.

val set_key_capture_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets @widget as the widget that @entry will capture key events from.

Key events are consumed by the search entry to start or continue a search.

If the entry is part of a `GtkSearchBar`, it is preferable to call method@Gtk.SearchBar.set_key_capture_widget instead, which will reveal the entry in addition to triggering the search entry.

Note that despite the name of this function, the events are only 'captured' in the bubble phase, which means that editable child widgets of @widget will receive text input before it gets captured. If that is not desired, you can capture and forward the events yourself with method@Gtk.EventControllerKey.forward.

val set_input_purpose : t -> Gtk_enums.inputpurpose -> unit

Sets the input purpose of @entry.

val set_input_hints : t -> Gtk_enums.inputhints -> unit

Sets the input hints for @entry.

val get_search_delay : t -> int

Get the delay to be used between the last keypress and the signal@Gtk.SearchEntry::search-changed signal being emitted.

val get_placeholder_text : t -> string option

Gets the placeholder text associated with @entry.

val get_key_capture_widget : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the widget that @entry is capturing key events from.

val get_input_purpose : t -> Gtk_enums.inputpurpose

Gets the input purpose of @entry.

val get_input_hints : t -> Gtk_enums.inputhints

Gets the input purpose for @entry.

val get_activates_default : t -> bool

Get property: activates-default

val set_activates_default : t -> bool -> unit

Set property: activates-default

val on_activate : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_next_match : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_previous_match : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_search_changed : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id
val on_search_started : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id