package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Section_model

type t = [ `section_model ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val sections_changed : t -> int -> int -> unit
val get_section : t -> int -> int * int

Query the section that covers the given position. The number of items in the section can be computed by `out_end - out_start`.

If the position is larger than the number of items, a single range from n_items to G_MAXUINT will be returned.

val on_sections_changed : ?after:bool -> t -> callback:(position:int -> n_items:int -> unit) -> Gobject.Signal.handler_id