package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Shortcut

type t = [ `shortcut | `object_ ] Gobject.obj
val new_ : [ `shortcut_trigger | `object_ ] Gobject.obj option -> [ `shortcut_action | `object_ ] Gobject.obj option -> t

Create a new Shortcut

val set_trigger : t -> [ `shortcut_trigger | `object_ ] Gobject.obj option -> unit

Sets the new trigger for @self to be @trigger.

val set_arguments : t -> Gvariant.t option -> unit

Sets the arguments to pass when activating the shortcut.

val set_action : t -> [ `shortcut_action | `object_ ] Gobject.obj option -> unit

Sets the new action for @self to be @action.

val get_trigger : t -> [ `shortcut_trigger | `object_ ] Gobject.obj option

Gets the trigger used to trigger @self.

val get_arguments : t -> Gvariant.t option

Gets the arguments that are passed when activating the shortcut.

val get_action : t -> [ `shortcut_action | `object_ ] Gobject.obj option

Gets the action that is activated by this shortcut.