package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Shortcut_action

type t = [ `shortcut_action | `object_ ] Gobject.obj
val parse_string : string -> t

Create a new ShortcutAction

val to_string : t -> string

Prints the given action into a human-readable string.

This is a small wrapper around method@Gtk.ShortcutAction.print to help when debugging.

val activate : t -> Gtk_enums.shortcutactionflags -> [ `widget | `initially_unowned | `object_ ] Gobject.obj -> Gvariant.t option -> bool

Activates the action on the @widget with the given @args.

Note that some actions ignore the passed in @flags, @widget or @args.

Activation of an action can fail for various reasons. If the action is not supported by the @widget, if the @args don't match the action or if the activation otherwise had no effect, %FALSE will be returned.