package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Stack_page

type t = [ `stack_page | `object_ ] Gobject.obj
val set_visible : t -> bool -> unit

Sets whether @page is visible in its `GtkStack`.

val set_use_underline : t -> bool -> unit

Sets whether underlines in the page title indicate mnemonics.

val set_title : t -> string -> unit

Sets the page title.

val set_needs_attention : t -> bool -> unit

Sets whether the page is marked as “needs attention”.

val set_name : t -> string -> unit

Sets the name of the page.

val set_icon_name : t -> string -> unit

Sets the icon name of the page.

val get_visible : t -> bool

Returns whether @page is visible in its `GtkStack`.

This is independent from the property@Gtk.Widget:visible property of its widget.

val get_use_underline : t -> bool

Gets whether underlines in the page title indicate mnemonics.

val get_title : t -> string option

Gets the page title.

val get_needs_attention : t -> bool

Returns whether the page is marked as “needs attention”.

val get_name : t -> string option

Returns the name of the page.

val get_icon_name : t -> string option

Returns the icon name of the page.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj

Returns the stack child to which @self belongs.