package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Statusbar

type t = [ `statusbar | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new Statusbar

val remove_all : t -> int -> unit

Forces the removal of all messages from a statusbar's stack with the exact @context_id.

val remove : t -> int -> int -> unit

Forces the removal of a message from a statusbar’s stack. The exact @context_id and @message_id must be specified.

val push : t -> int -> string -> int

Pushes a new message onto a statusbar’s stack.

val pop : t -> int -> unit

Removes the first message in the `GtkStatusbar`’s stack with the given context id.

Note that this may not change the displayed message, if the message at the top of the stack has a different context id.

val get_context_id : t -> string -> int

Returns a new context identifier, given a description of the actual context.

Note that the description is not shown in the UI.

val on_text_popped : ?after:bool -> t -> callback:(context_id:int -> text:string -> unit) -> Gobject.Signal.handler_id
val on_text_pushed : ?after:bool -> t -> callback:(context_id:int -> text:string -> unit) -> Gobject.Signal.handler_id