package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Text_child_anchor

type t = [ `text_child_anchor | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new TextChildAnchor

val new_with_replacement : string -> t

Create a new TextChildAnchor

val get_widgets : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj array * int

Gets a list of all widgets anchored at this child anchor.

The order in which the widgets are returned is not defined.

val get_deleted : t -> bool

Determines whether a child anchor has been deleted from the buffer.

Keep in mind that the child anchor will be unreferenced when removed from the buffer, so you need to hold your own reference (with g_object_ref()) if you plan to use this function — otherwise all deleted child anchors will also be finalized.