package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Text_mark

type t = [ `text_mark | `object_ ] Gobject.obj
val new_ : string option -> bool -> t

Create a new TextMark

val set_visible : t -> bool -> unit
val get_visible : t -> bool

Returns %TRUE if the mark is visible.

A cursor is displayed for visible marks.

val get_name : t -> string option

Returns the mark name.

Returns %NULL for anonymous marks.

val get_left_gravity : t -> bool

Determines whether the mark has left gravity.

val get_deleted : t -> bool

Returns %TRUE if the mark has been removed from its buffer.

See method@Gtk.TextBuffer.add_mark for a way to add it to a buffer again.

val get_buffer : t -> [ `text_buffer | `object_ ] Gobject.obj option

Gets the buffer this mark is located inside.

Returns %NULL if the mark is deleted.