package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Tree_drag_dest

type t = [ `tree_drag_dest ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val row_drop_possible : t -> [ `tree_path ] Gobject.obj -> Gobject.Value.t -> bool

Determines whether a drop is possible before the given @dest_path, at the same depth as @dest_path. i.e., can we drop the data in @value at that location. @dest_path does not have to exist; the return value will almost certainly be %FALSE if the parent of @dest_path doesn’t exist, though.

val drag_data_received : t -> [ `tree_path ] Gobject.obj -> Gobject.Value.t -> bool

Asks the `GtkTreeDragDest` to insert a row before the path @dest, deriving the contents of the row from @value. If @dest is outside the tree so that inserting before it is impossible, %FALSE will be returned. Also, %FALSE may be returned if the new row is not created for some model-specific reason. Should robustly handle a @dest no longer found in the model!