package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Tree_drag_source

type t = [ `tree_drag_source ] Gobject.obj
val from_gobject : 'a Gobject.obj -> t
val row_draggable : t -> [ `tree_path ] Gobject.obj -> bool

Asks the `GtkTreeDragSource` whether a particular row can be used as the source of a DND operation. If the source doesn’t implement this interface, the row is assumed draggable.

val drag_data_get : t -> [ `tree_path ] Gobject.obj -> Ocgtk_gdk.Gdk.Wrappers.Content_provider.t option

Asks the `GtkTreeDragSource` to return a `GdkContentProvider` representing the row at @path. Should robustly handle a @path no longer found in the model!

val drag_data_delete : t -> [ `tree_path ] Gobject.obj -> bool

Asks the `GtkTreeDragSource` to delete the row at @path, because it was moved somewhere else via drag-and-drop. Returns %FALSE if the deletion fails because @path no longer exists, or for some model-specific reason. Should robustly handle a @path no longer found in the model!