package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Tree_expander

type t = [ `tree_expander | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new TreeExpander

val set_list_row : t -> [ `tree_list_row | `object_ ] Gobject.obj option -> unit

Sets the tree list row that this expander should manage.

val set_indent_for_icon : t -> bool -> unit

Sets if the TreeExpander should indent the child by the width of an expander-icon when it is not expandable.

val set_indent_for_depth : t -> bool -> unit

Sets if the TreeExpander should indent the child according to its depth.

val set_hide_expander : t -> bool -> unit

Sets whether the expander icon should be visible in a GtkTreeListRow.

val set_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option -> unit

Sets the content widget to display.

val get_list_row : t -> [ `tree_list_row | `object_ ] Gobject.obj option

Gets the list row managed by @self.

val get_item : t -> [ `object_ ] Gobject.obj option

Forwards the item set on the `GtkTreeListRow` that @self is managing.

This call is essentially equivalent to calling:

```c gtk_tree_list_row_get_item (gtk_tree_expander_get_list_row (@self)); ```

val get_indent_for_icon : t -> bool

TreeExpander indents the child by the width of an expander-icon if it is not expandable.

val get_indent_for_depth : t -> bool

TreeExpander indents each level of depth with an additional indent.

val get_hide_expander : t -> bool

Gets whether the TreeExpander should be hidden in a GtkTreeListRow.

val get_child : t -> [ `widget | `initially_unowned | `object_ ] Gobject.obj option

Gets the child widget displayed by @self.