package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Tree_row_reference

type t = [ `tree_row_reference ] Gobject.obj

A GtkTreeRowReference tracks model changes so that it always refers to the same row (a `GtkTreePath` refers to a position, not a fixed row). Create a new GtkTreeRowReference with gtk_tree_row_reference_new().

val new_ : [ `tree_model ] Gobject.obj -> [ `tree_path ] Gobject.obj -> t

Create a new TreeRowReference

val new_proxy : [ `object_ ] Gobject.obj -> [ `tree_model ] Gobject.obj -> [ `tree_path ] Gobject.obj -> t

Create a new TreeRowReference

val valid : t -> bool

Returns %TRUE if the @reference is non-%NULL and refers to a current valid path.

val get_path : t -> [ `tree_path ] Gobject.obj option

Returns a path that the row reference currently points to, or %NULL if the path pointed to is no longer valid.

val get_model : t -> [ `tree_model ] Gobject.obj

Returns the model that the row reference is monitoring.

val get_type : unit -> Gobject.Type.t