package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Tree_selection

type t = [ `tree_selection | `object_ ] Gobject.obj
val unselect_range : t -> [ `tree_path ] Gobject.obj -> [ `tree_path ] Gobject.obj -> unit

Unselects a range of nodes, determined by @start_path and @end_path inclusive.

val unselect_path : t -> [ `tree_path ] Gobject.obj -> unit

Unselects the row at @path.

val unselect_iter : t -> [ `tree_iter ] Gobject.obj -> unit

Unselects the specified iterator.

val unselect_all : t -> unit

Unselects all the nodes.

val set_mode : t -> Gtk_enums.selectionmode -> unit

Sets the selection mode of the @selection. If the previous type was %GTK_SELECTION_MULTIPLE, then the anchor is kept selected, if it was previously selected.

val select_range : t -> [ `tree_path ] Gobject.obj -> [ `tree_path ] Gobject.obj -> unit

Selects a range of nodes, determined by @start_path and @end_path inclusive. @selection must be set to %GTK_SELECTION_MULTIPLE mode.

val select_path : t -> [ `tree_path ] Gobject.obj -> unit

Select the row at @path.

val select_iter : t -> [ `tree_iter ] Gobject.obj -> unit

Selects the specified iterator.

val select_all : t -> unit

Selects all the nodes. @selection must be set to %GTK_SELECTION_MULTIPLE mode.

val path_is_selected : t -> [ `tree_path ] Gobject.obj -> bool

Returns %TRUE if the row pointed to by @path is currently selected. If @path does not point to a valid location, %FALSE is returned

val iter_is_selected : t -> [ `tree_iter ] Gobject.obj -> bool

Returns %TRUE if the row at @iter is currently selected.

val get_tree_view : t -> [ `tree_view | `widget | `initially_unowned | `object_ ] Gobject.obj

Returns the tree view associated with @selection.

val get_mode : t -> Gtk_enums.selectionmode

Gets the selection mode for @selection. See gtk_tree_selection_set_mode().

val count_selected_rows : t -> int

Returns the number of rows that have been selected in @tree.

val on_changed : ?after:bool -> t -> callback:(unit -> unit) -> Gobject.Signal.handler_id