package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Window_controls

type t = [ `window_controls | `widget | `initially_unowned | `object_ ] Gobject.obj
val new_ : Gtk_enums.packtype -> t

Create a new WindowControls

val set_side : t -> Gtk_enums.packtype -> unit

Determines which part of decoration layout the `GtkWindowControls` uses.

See property@Gtk.WindowControls:decoration-layout.

val set_decoration_layout : t -> string option -> unit

Sets the decoration layout for the title buttons.

This overrides the property@Gtk.Settings:gtk-decoration-layout setting.

The format of the string is button names, separated by commas. A colon separates the buttons that should appear on the left from those on the right. Recognized button names are minimize, maximize, close and icon (the window icon).

For example, “icon:minimize,maximize,close” specifies a icon on the left, and minimize, maximize and close buttons on the right.

If property@Gtk.WindowControls:side value is @GTK_PACK_START, @self will display the part before the colon, otherwise after that.

val get_side : t -> Gtk_enums.packtype

Gets the side to which this `GtkWindowControls` instance belongs.

val get_empty : t -> bool

Gets whether the widget has any window buttons.

val get_decoration_layout : t -> string option

Gets the decoration layout of this `GtkWindowControls`.