package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Attr_font_desc

type t = [ `attr_font_desc ] Gobject.obj

The `PangoAttrFontDesc` structure is used to store an attribute that sets all aspects of the font description at once.