package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Attribute

type t = [ `attribute ] Gobject.obj

The `PangoAttribute` structure represents the common portions of all attributes.

Particular types of attributes include this structure as their initial portion. The common portion of the attribute holds the range to which the value in the type-specific part of the attribute applies and should be initialized using method@Pango.Attribute.init. By default, an attribute will have an all-inclusive range of 0,%G_MAXUINT.

val init : t -> [ `attr_class ] Gobject.obj -> unit

Initializes @attr's klass to @klass, it's start_index to %PANGO_ATTR_INDEX_FROM_TEXT_BEGINNING and end_index to %PANGO_ATTR_INDEX_TO_TEXT_END such that the attribute applies to the entire text by default.

val equal : t -> t -> bool

Compare two attributes for equality.

This compares only the actual value of the two attributes and not the ranges that the attributes apply to.

val destroy : t -> unit

Destroy a `PangoAttribute` and free all associated memory.

val as_string : t -> [ `attr_string ] Gobject.obj option

Returns the attribute cast to `PangoAttrString`.

This is mainly useful for language bindings.

val as_size : t -> [ `attr_size ] Gobject.obj option

Returns the attribute cast to `PangoAttrSize`.

This is mainly useful for language bindings.

val as_shape : t -> [ `attr_shape ] Gobject.obj option

Returns the attribute cast to `PangoAttrShape`.

This is mainly useful for language bindings.

val as_language : t -> [ `attr_language ] Gobject.obj option

Returns the attribute cast to `PangoAttrLanguage`.

This is mainly useful for language bindings.

val as_int : t -> [ `attr_int ] Gobject.obj option

Returns the attribute cast to `PangoAttrInt`.

This is mainly useful for language bindings.

val as_font_features : t -> [ `attr_font_features ] Gobject.obj option

Returns the attribute cast to `PangoAttrFontFeatures`.

This is mainly useful for language bindings.

val as_font_desc : t -> [ `attr_font_desc ] Gobject.obj option

Returns the attribute cast to `PangoAttrFontDesc`.

This is mainly useful for language bindings.

val as_float : t -> [ `attr_float ] Gobject.obj option

Returns the attribute cast to `PangoAttrFloat`.

This is mainly useful for language bindings.

val as_color : t -> [ `attr_color ] Gobject.obj option

Returns the attribute cast to `PangoAttrColor`.

This is mainly useful for language bindings.

val get_type : unit -> Gobject.Type.t