package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Coverage

type t = [ `coverage | `object_ ] Gobject.obj
val new_ : unit -> t

Create a new Coverage

val unref : t -> unit

Decrease the reference count on the `PangoCoverage` by one.

If the result is zero, free the coverage and all associated memory.

val set : t -> int -> Pango_enums.coveragelevel -> unit

Modify a particular index within @coverage

val ref : t -> t

Increase the reference count on the `PangoCoverage` by one.

val max : t -> t -> unit

Set the coverage for each index in @coverage to be the max (better) value of the current coverage for the index and the coverage for the corresponding index in @other.

val get : t -> int -> Pango_enums.coveragelevel

Determine whether a particular index is covered by @coverage.

val copy : t -> t

Copy an existing `PangoCoverage`.