package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Font_face

type t = [ `font_face | `object_ ] Gobject.obj
val list_sizes : t -> int array option * int

List the available sizes for a font.

This is only applicable to bitmap fonts. For scalable fonts, stores %NULL at the location pointed to by @sizes and 0 at the location pointed to by @n_sizes. The sizes returned are in Pango units and are sorted in ascending order.

val is_synthesized : t -> bool

Returns whether a `PangoFontFace` is synthesized.

This will be the case if the underlying font rendering engine creates this face from another face, by shearing, emboldening, lightening or modifying it in some other way.

val get_family : t -> [ `font_family | `object_ ] Gobject.obj

Gets the `PangoFontFamily` that @face belongs to.

val get_face_name : t -> string

Gets a name representing the style of this face.

Note that a font family may contain multiple faces with the same name (e.g. a variable and a non-variable face for the same style).

val describe : t -> [ `font_description ] Gobject.obj

Returns a font description that matches the face.

The resulting font description will have the family, style, variant, weight and stretch of the face, but its size field will be unset.