package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Fontset

type t = [ `fontset | `object_ ] Gobject.obj
val get_metrics : t -> [ `font_metrics ] Gobject.obj

Get overall metric information for the fonts in the fontset.

val get_font : t -> int -> [ `font | `object_ ] Gobject.obj

Returns the font in the fontset that contains the best glyph for a Unicode character.