package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Layout

type t = [ `layout | `object_ ] Gobject.obj
val new_ : [ `context | `object_ ] Gobject.obj -> t

Create a new Layout

val xy_to_index : t -> int -> int -> bool * int * int

Converts from X and Y position within a layout to the byte index to the character at that logical position.

If the Y position is not inside the layout, the closest position is chosen (the position will be clamped inside the layout). If the X position is not within the layout, then the start or the end of the line is chosen as described for method@Pango.LayoutLine.x_to_index. If either the X or Y positions were not inside the layout, then the function returns %FALSE; on an exact hit, it returns %TRUE.

val write_to_file : t -> Pango_enums.layoutserializeflags -> string -> (bool, GError.t) result

A convenience method to serialize a layout to a file.

It is equivalent to calling method@Pango.Layout.serialize followed by func@GLib.file_set_contents.

See those two functions for details on the arguments.

It is mostly intended for use inside a debugger to quickly dump a layout to a file for later inspection.

val set_wrap : t -> Pango_enums.wrapmode -> unit

Sets the wrap mode.

The wrap mode only has effect if a width is set on the layout with method@Pango.Layout.set_width. To turn off wrapping, set the width to -1.

The default value is %PANGO_WRAP_WORD.

val set_width : t -> int -> unit

Sets the width to which the lines of the `PangoLayout` should wrap or ellipsized.

The default value is -1: no width set.

val set_text : t -> string -> int -> unit

Sets the text of the layout.

This function validates @text and renders invalid UTF-8 with a placeholder glyph.

Note that if you have used method@Pango.Layout.set_markup or method@Pango.Layout.set_markup_with_accel on @layout before, you may want to call method@Pango.Layout.set_attributes to clear the attributes set on the layout from the markup as this function does not clear attributes.

val set_tabs : t -> [ `tab_array ] Gobject.obj option -> unit

Sets the tabs to use for @layout, overriding the default tabs.

`PangoLayout` will place content at the next tab position whenever it meets a Tab character (U+0009).

By default, tabs are every 8 spaces. If @tabs is %NULL, the default tabs are reinstated. @tabs is copied into the layout; you must free your copy of @tabs yourself.

Note that tabs and justification conflict with each other: Justification will move content away from its tab-aligned positions. The same is true for alignments other than %PANGO_ALIGN_LEFT.

val set_spacing : t -> int -> unit

Sets the amount of spacing in Pango units between the lines of the layout.

When placing lines with spacing, Pango arranges things so that

line2.top = line1.bottom + spacing

The default value is 0.

Note: Since 1.44, Pango is using the line height (as determined by the font) for placing lines when the line spacing factor is set to a non-zero value with method@Pango.Layout.set_line_spacing. In that case, the @spacing set with this function is ignored.

Note: for semantics that are closer to the CSS line-height property, see func@Pango.attr_line_height_new.

val set_single_paragraph_mode : t -> bool -> unit

Sets the single paragraph mode of @layout.

If @setting is %TRUE, do not treat newlines and similar characters as paragraph separators; instead, keep all text in a single paragraph, and display a glyph for paragraph separator characters. Used when you want to allow editing of newlines on a single text line.

The default value is %FALSE.

val set_markup_with_accel : t -> string -> int -> int -> int

Sets the layout text and attribute list from marked-up text.

See Pango Markup(pango_markup.html)).

Replaces the current text and attribute list.

If @accel_marker is nonzero, the given character will mark the character following it as an accelerator. For example, @accel_marker might be an ampersand or underscore. All characters marked as an accelerator will receive a %PANGO_UNDERLINE_LOW attribute, and the first character so marked will be returned in @accel_char. Two @accel_marker characters following each other produce a single literal @accel_marker character.

val set_markup : t -> string -> int -> unit

Sets the layout text and attribute list from marked-up text.

See Pango Markup(pango_markup.html)).

Replaces the current text and attribute list.

This is the same as method@Pango.Layout.set_markup_with_accel, but the markup text isn't scanned for accelerators.

val set_line_spacing : t -> float -> unit

Sets a factor for line spacing.

Typical values are: 0, 1, 1.5, 2. The default values is 0.

If @factor is non-zero, lines are placed so that

baseline2 = baseline1 + factor * height2

where height2 is the line height of the second line (as determined by the font(s)). In this case, the spacing set with method@Pango.Layout.set_spacing is ignored.

If @factor is zero (the default), spacing is applied as before.

Note: for semantics that are closer to the CSS line-height property, see func@Pango.attr_line_height_new.

val set_justify_last_line : t -> bool -> unit

Sets whether the last line should be stretched to fill the entire width of the layout.

This only has an effect if method@Pango.Layout.set_justify has been called as well.

The default value is %FALSE.

val set_justify : t -> bool -> unit

Sets whether each complete line should be stretched to fill the entire width of the layout.

Stretching is typically done by adding whitespace, but for some scripts (such as Arabic), the justification may be done in more complex ways, like extending the characters.

Note that this setting is not implemented and so is ignored in Pango older than 1.18.

Note that tabs and justification conflict with each other: Justification will move content away from its tab-aligned positions.

The default value is %FALSE.

Also see method@Pango.Layout.set_justify_last_line.

val set_indent : t -> int -> unit

Sets the width in Pango units to indent each paragraph.

A negative value of @indent will produce a hanging indentation. That is, the first line will have the full width, and subsequent lines will be indented by the absolute value of @indent.

The indent setting is ignored if layout alignment is set to %PANGO_ALIGN_CENTER.

The default value is 0.

val set_height : t -> int -> unit

Sets the height to which the `PangoLayout` should be ellipsized at.

There are two different behaviors, based on whether @height is positive or negative.

If @height is positive, it will be the maximum height of the layout. Only lines would be shown that would fit, and if there is any text omitted, an ellipsis added. At least one line is included in each paragraph regardless of how small the height value is. A value of zero will render exactly one line for the entire layout.

If @height is negative, it will be the (negative of) maximum number of lines per paragraph. That is, the total number of lines shown may well be more than this value if the layout contains multiple paragraphs of text. The default value of -1 means that the first line of each paragraph is ellipsized. This behavior may be changed in the future to act per layout instead of per paragraph. File a bug against pango at https://gitlab.gnome.org/gnome/pango(https://gitlab.gnome.org/gnome/pango) if your code relies on this behavior.

Height setting only has effect if a positive width is set on @layout and ellipsization mode of @layout is not %PANGO_ELLIPSIZE_NONE. The behavior is undefined if a height other than -1 is set and ellipsization mode is set to %PANGO_ELLIPSIZE_NONE, and may change in the future.

val set_font_description : t -> [ `font_description ] Gobject.obj option -> unit

Sets the default font description for the layout.

If no font description is set on the layout, the font description from the layout's context is used.

val set_ellipsize : t -> Pango_enums.ellipsizemode -> unit

Sets the type of ellipsization being performed for @layout.

Depending on the ellipsization mode @ellipsize text is removed from the start, middle, or end of text so they fit within the width and height of layout set with method@Pango.Layout.set_width and method@Pango.Layout.set_height.

If the layout contains characters such as newlines that force it to be layed out in multiple paragraphs, then whether each paragraph is ellipsized separately or the entire layout is ellipsized as a whole depends on the set height of the layout.

The default value is %PANGO_ELLIPSIZE_NONE.

See method@Pango.Layout.set_height for details.

val set_auto_dir : t -> bool -> unit

Sets whether to calculate the base direction for the layout according to its contents.

When this flag is on (the default), then paragraphs in @layout that begin with strong right-to-left characters (Arabic and Hebrew principally), will have right-to-left layout, paragraphs with letters from other scripts will have left-to-right layout. Paragraphs with only neutral characters get their direction from the surrounding paragraphs.

When %FALSE, the choice between left-to-right and right-to-left layout is done according to the base direction of the layout's `PangoContext`. (See method@Pango.Context.set_base_dir).

When the auto-computed direction of a paragraph differs from the base direction of the context, the interpretation of %PANGO_ALIGN_LEFT and %PANGO_ALIGN_RIGHT are swapped.

val set_attributes : t -> [ `attr_list ] Gobject.obj option -> unit

Sets the text attributes for a layout object.

References @attrs, so the caller can unref its reference.

val set_alignment : t -> Pango_enums.alignment -> unit

Sets the alignment for the layout: how partial lines are positioned within the horizontal space available.

The default alignment is %PANGO_ALIGN_LEFT.

Serializes the @layout for later deserialization via func@Pango.Layout.deserialize.

There are no guarantees about the format of the output across different versions of Pango and func@Pango.Layout.deserialize will reject data that it cannot parse.

The intended use of this function is testing, benchmarking and debugging. The format is not meant as a permanent storage format.

val move_cursor_visually : t -> bool -> int -> int -> int -> int * int

Computes a new cursor position from an old position and a direction.

If @direction is positive, then the new position will cause the strong or weak cursor to be displayed one position to right of where it was with the old cursor position. If @direction is negative, it will be moved to the left.

In the presence of bidirectional text, the correspondence between logical and visual order will depend on the direction of the current run, and there may be jumps when the cursor is moved off of the end of a run.

Motion here is in cursor positions, not in characters, so a single call to this function may move the cursor over multiple characters when multiple characters combine to form a single grapheme.

val is_wrapped : t -> bool

Queries whether the layout had to wrap any paragraphs.

This returns %TRUE if a positive width is set on @layout, ellipsization mode of @layout is set to %PANGO_ELLIPSIZE_NONE, and there are paragraphs exceeding the layout width that have to be wrapped.

val is_ellipsized : t -> bool

Queries whether the layout had to ellipsize any paragraphs.

This returns %TRUE if the ellipsization mode for @layout is not %PANGO_ELLIPSIZE_NONE, a positive width is set on @layout, and there are paragraphs exceeding that width that have to be ellipsized.

val index_to_pos : t -> int -> [ `rectangle ] Gobject.obj

Converts from an index within a `PangoLayout` to the onscreen position corresponding to the grapheme at that index.

The returns is represented as rectangle. Note that `pos->x` is always the leading edge of the grapheme and `pos->x + pos->width` the trailing edge of the grapheme. If the directionality of the grapheme is right-to-left, then `pos->width` will be negative.

val index_to_line_x : t -> int -> bool -> int * int

Converts from byte @index_ within the @layout to line and X position.

The X position is measured from the left edge of the line.

val get_wrap : t -> Pango_enums.wrapmode

Gets the wrap mode for the layout.

Use method@Pango.Layout.is_wrapped to query whether any paragraphs were actually wrapped.

val get_width : t -> int

Gets the width to which the lines of the `PangoLayout` should wrap.

val get_unknown_glyphs_count : t -> int

Counts the number of unknown glyphs in @layout.

This function can be used to determine if there are any fonts available to render all characters in a certain string, or when used in combination with %PANGO_ATTR_FALLBACK, to check if a certain font supports all the characters in the string.

val get_text : t -> string

Gets the text in the layout.

The returned text should not be freed or modified.

val get_tabs : t -> [ `tab_array ] Gobject.obj option

Gets the current `PangoTabArray` used by this layout.

If no `PangoTabArray` has been set, then the default tabs are in use and %NULL is returned. Default tabs are every 8 spaces.

The return value should be freed with method@Pango.TabArray.free.

val get_spacing : t -> int

Gets the amount of spacing between the lines of the layout.

val get_size : t -> int * int

Determines the logical width and height of a `PangoLayout` in Pango units.

This is simply a convenience function around method@Pango.Layout.get_extents.

val get_single_paragraph_mode : t -> bool

Obtains whether @layout is in single paragraph mode.

See method@Pango.Layout.set_single_paragraph_mode.

val get_serial : t -> int

Returns the current serial number of @layout.

The serial number is initialized to an small number larger than zero when a new layout is created and is increased whenever the layout is changed using any of the setter functions, or the `PangoContext` it uses has changed. The serial may wrap, but will never have the value 0. Since it can wrap, never compare it with "less than", always use "not equals".

This can be used to automatically detect changes to a `PangoLayout`, and is useful for example to decide whether a layout needs redrawing. To force the serial to be increased, use method@Pango.Layout.context_changed.

val get_pixel_size : t -> int * int

Determines the logical width and height of a `PangoLayout` in device units.

method@Pango.Layout.get_size returns the width and height scaled by %PANGO_SCALE. This is simply a convenience function around method@Pango.Layout.get_pixel_extents.

val get_pixel_extents : t -> [ `rectangle ] Gobject.obj * [ `rectangle ] Gobject.obj

Computes the logical and ink extents of @layout in device units.

This function just calls method@Pango.Layout.get_extents followed by two func@extents_to_pixels calls, rounding @ink_rect and @logical_rect such that the rounded rectangles fully contain the unrounded one (that is, passes them as first argument to func@Pango.extents_to_pixels).

val get_log_attrs_readonly : t -> [ `log_attr ] Gobject.obj array * int

Retrieves an array of logical attributes for each character in the @layout.

This is a faster alternative to method@Pango.Layout.get_log_attrs. The returned array is part of @layout and must not be modified. Modifying the layout will invalidate the returned array.

The number of attributes returned in @n_attrs will be one more than the total number of characters in the layout, since there need to be attributes corresponding to both the position before the first character and the position after the last character.

val get_log_attrs : t -> [ `log_attr ] Gobject.obj array * int

Retrieves an array of logical attributes for each character in the @layout.

val get_lines_readonly : t -> [ `layout_line ] Gobject.obj list

Returns the lines of the @layout as a list.

This is a faster alternative to method@Pango.Layout.get_lines, but the user is not expected to modify the contents of the lines (glyphs, glyph widths, etc.).

val get_lines : t -> [ `layout_line ] Gobject.obj list

Returns the lines of the @layout as a list.

Use the faster method@Pango.Layout.get_lines_readonly if you do not plan to modify the contents of the lines (glyphs, glyph widths, etc.).

val get_line_spacing : t -> float

Gets the line spacing factor of @layout.

See method@Pango.Layout.set_line_spacing.

val get_line_readonly : t -> int -> [ `layout_line ] Gobject.obj option

Retrieves a particular line from a `PangoLayout`.

This is a faster alternative to method@Pango.Layout.get_line, but the user is not expected to modify the contents of the line (glyphs, glyph widths, etc.).

val get_line_count : t -> int

Retrieves the count of lines for the @layout.

val get_line : t -> int -> [ `layout_line ] Gobject.obj option

Retrieves a particular line from a `PangoLayout`.

Use the faster method@Pango.Layout.get_line_readonly if you do not plan to modify the contents of the line (glyphs, glyph widths, etc.).

val get_justify_last_line : t -> bool

Gets whether the last line should be stretched to fill the entire width of the layout.

val get_justify : t -> bool

Gets whether each complete line should be stretched to fill the entire width of the layout.

val get_iter : t -> [ `layout_iter ] Gobject.obj

Returns an iterator to iterate over the visual extents of the layout.

val get_indent : t -> int

Gets the paragraph indent width in Pango units.

A negative value indicates a hanging indentation.

val get_height : t -> int

Gets the height of layout used for ellipsization.

See method@Pango.Layout.set_height for details.

val get_font_description : t -> [ `font_description ] Gobject.obj option

Gets the font description for the layout, if any.

val get_extents : t -> [ `rectangle ] Gobject.obj * [ `rectangle ] Gobject.obj

Computes the logical and ink extents of @layout.

Logical extents are usually what you want for positioning things. Note that both extents may have non-zero x and y. You may want to use those to offset where you render the layout. Not doing that is a very typical bug that shows up as right-to-left layouts not being correctly positioned in a layout with a set width.

The extents are given in layout coordinates and in Pango units; layout coordinates begin at the top left corner of the layout.

val get_ellipsize : t -> Pango_enums.ellipsizemode

Gets the type of ellipsization being performed for @layout.

See method@Pango.Layout.set_ellipsize.

Use method@Pango.Layout.is_ellipsized to query whether any paragraphs were actually ellipsized.

val get_direction : t -> int -> Pango_enums.direction

Gets the text direction at the given character position in @layout.

val get_cursor_pos : t -> int -> [ `rectangle ] Gobject.obj * [ `rectangle ] Gobject.obj

Given an index within a layout, determines the positions that of the strong and weak cursors if the insertion point is at that index.

The position of each cursor is stored as a zero-width rectangle with the height of the run extents.

<picture> <source srcset="cursor-positions-dark.png" media="(prefers-color-scheme: dark)"> <img alt="Cursor positions" src="cursor-positions-light.png"> </picture>

The strong cursor location is the location where characters of the directionality equal to the base direction of the layout are inserted. The weak cursor location is the location where characters of the directionality opposite to the base direction of the layout are inserted.

The following example shows text with both a strong and a weak cursor.

<picture> <source srcset="split-cursor-dark.png" media="(prefers-color-scheme: dark)"> <img alt="Strong and weak cursors" src="split-cursor-light.png"> </picture>

The strong cursor has a little arrow pointing to the right, the weak cursor to the left. Typing a 'c' in this situation will insert the character after the 'b', and typing another Hebrew character, like 'ג', will insert it at the end.

val get_context : t -> [ `context | `object_ ] Gobject.obj

Retrieves the `PangoContext` used for this layout.

val get_character_count : t -> int

Returns the number of Unicode characters in the the text of @layout.

val get_caret_pos : t -> int -> [ `rectangle ] Gobject.obj * [ `rectangle ] Gobject.obj

Given an index within a layout, determines the positions that of the strong and weak cursors if the insertion point is at that index.

This is a variant of method@Pango.Layout.get_cursor_pos that applies font metric information about caret slope and offset to the positions it returns.

<picture> <source srcset="caret-metrics-dark.png" media="(prefers-color-scheme: dark)"> <img alt="Caret metrics" src="caret-metrics-light.png"> </picture>

val get_baseline : t -> int

Gets the Y position of baseline of the first line in @layout.

val get_auto_dir : t -> bool

Gets whether to calculate the base direction for the layout according to its contents.

See method@Pango.Layout.set_auto_dir.

val get_attributes : t -> [ `attr_list ] Gobject.obj option

Gets the attribute list for the layout, if any.

val get_alignment : t -> Pango_enums.alignment

Gets the alignment for the layout: how partial lines are positioned within the horizontal space available.

val copy : t -> t

Creates a deep copy-by-value of the layout.

The attribute list, tab array, and text from the original layout are all copied by value.

val context_changed : t -> unit

Forces recomputation of any state in the `PangoLayout` that might depend on the layout's context.

This function should be called if you make changes to the context subsequent to creating the layout.