package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Rectangle

type t = [ `rectangle ] Gobject.obj

The `PangoRectangle` structure represents a rectangle.

`PangoRectangle` is frequently used to represent the logical or ink extents of a single glyph or section of text. (See, for instance, method@Pango.Font.get_glyph_extents.)