package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wrappers.Script_iter

type t = [ `script_iter ] Gobject.obj

A `PangoScriptIter` is used to iterate through a string and identify ranges in different scripts.

val new_ : string -> int -> t

Create a new ScriptIter

val next : t -> bool

Advances a `PangoScriptIter` to the next range.

If @iter is already at the end, it is left unchanged and %FALSE is returned.

val get_type : unit -> Gobject.Type.t