package ocgtk

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ocgtk_pango.Pango_enums

type alignment = [
  1. | `LEFT
    (*

    Center the line within the available space

    *)
  2. | `CENTER
    (*

    Put all available space on the left

    *)
  3. | `RIGHT
]
val alignment_of_int : int -> alignment
val alignment_to_int : alignment -> int
type attrtype = [
  1. | `INVALID
    (*

    language (struct@Pango.AttrLanguage)

    *)
  2. | `LANGUAGE
    (*

    font family name list (struct@Pango.AttrString)

    *)
  3. | `FAMILY
    (*

    font slant style (struct@Pango.AttrInt)

    *)
  4. | `STYLE
    (*

    font weight (struct@Pango.AttrInt)

    *)
  5. | `WEIGHT
    (*

    font variant (normal or small caps) (struct@Pango.AttrInt)

    *)
  6. | `VARIANT
    (*

    font stretch (struct@Pango.AttrInt)

    *)
  7. | `STRETCH
    (*

    font size in points scaled by %PANGO_SCALE (struct@Pango.AttrInt)

    *)
  8. | `SIZE
    (*

    font description (struct@Pango.AttrFontDesc)

    *)
  9. | `FONT_DESC
    (*

    foreground color (struct@Pango.AttrColor)

    *)
  10. | `FOREGROUND
    (*

    background color (struct@Pango.AttrColor)

    *)
  11. | `BACKGROUND
    (*

    whether the text has an underline (struct@Pango.AttrInt)

    *)
  12. | `UNDERLINE
    (*

    whether the text is struck-through (struct@Pango.AttrInt)

    *)
  13. | `STRIKETHROUGH
    (*

    baseline displacement (struct@Pango.AttrInt)

    *)
  14. | `RISE
    (*

    shape (struct@Pango.AttrShape)

    *)
  15. | `SHAPE
    (*

    font size scale factor (struct@Pango.AttrFloat)

    *)
  16. | `SCALE
    (*

    whether fallback is enabled (struct@Pango.AttrInt)

    *)
  17. | `FALLBACK
    (*

    letter spacing (struct@PangoAttrInt)

    *)
  18. | `LETTER_SPACING
    (*

    underline color (struct@Pango.AttrColor)

    *)
  19. | `UNDERLINE_COLOR
    (*

    strikethrough color (struct@Pango.AttrColor)

    *)
  20. | `STRIKETHROUGH_COLOR
    (*

    font size in pixels scaled by %PANGO_SCALE (struct@Pango.AttrInt)

    *)
  21. | `ABSOLUTE_SIZE
    (*

    base text gravity (struct@Pango.AttrInt)

    *)
  22. | `GRAVITY
    (*

    gravity hint (struct@Pango.AttrInt)

    *)
  23. | `GRAVITY_HINT
    (*

    OpenType font features (struct@Pango.AttrFontFeatures). Since 1.38

    *)
  24. | `FONT_FEATURES
    (*

    foreground alpha (struct@Pango.AttrInt). Since 1.38

    *)
  25. | `FOREGROUND_ALPHA
    (*

    background alpha (struct@Pango.AttrInt). Since 1.38

    *)
  26. | `BACKGROUND_ALPHA
    (*

    whether breaks are allowed (struct@Pango.AttrInt). Since 1.44

    *)
  27. | `ALLOW_BREAKS
    (*

    how to render invisible characters (struct@Pango.AttrInt). Since 1.44

    *)
  28. | `SHOW
    (*

    whether to insert hyphens at intra-word line breaks (struct@Pango.AttrInt). Since 1.44

    *)
  29. | `INSERT_HYPHENS
    (*

    whether the text has an overline (struct@Pango.AttrInt). Since 1.46

    *)
  30. | `OVERLINE
    (*

    overline color (struct@Pango.AttrColor). Since 1.46

    *)
  31. | `OVERLINE_COLOR
    (*

    line height factor (struct@Pango.AttrFloat). Since: 1.50

    *)
  32. | `LINE_HEIGHT
    (*

    line height (struct@Pango.AttrInt). Since: 1.50

    *)
  33. | `ABSOLUTE_LINE_HEIGHT
  34. | `TEXT_TRANSFORM
    (*

    override segmentation to classify the range of the attribute as a single word (struct@Pango.AttrInt). Since 1.50

    *)
  35. | `WORD
    (*

    override segmentation to classify the range of the attribute as a single sentence (struct@Pango.AttrInt). Since 1.50

    *)
  36. | `SENTENCE
    (*

    baseline displacement (struct@Pango.AttrInt). Since 1.50

    *)
  37. | `BASELINE_SHIFT
    (*

    font-relative size change (struct@Pango.AttrInt). Since 1.50

    *)
  38. | `FONT_SCALE
]
val attrtype_of_int : int -> attrtype
val attrtype_to_int : attrtype -> int
type baselineshift = [
  1. | `NONE
    (*

    Shift the baseline to the superscript position, relative to the previous run

    *)
  2. | `SUPERSCRIPT
    (*

    Shift the baseline to the subscript position, relative to the previous run

    *)
  3. | `SUBSCRIPT
]
val baselineshift_of_int : int -> baselineshift
val baselineshift_to_int : baselineshift -> int
type biditype = [
  1. | `L
    (*

    Left-to-Right Embedding

    *)
  2. | `LRE
    (*

    Left-to-Right Override

    *)
  3. | `LRO
    (*

    Right-to-Left

    *)
  4. | `R
    (*

    Right-to-Left Arabic

    *)
  5. | `AL
    (*

    Right-to-Left Embedding

    *)
  6. | `RLE
    (*

    Right-to-Left Override

    *)
  7. | `RLO
    (*

    Pop Directional Format

    *)
  8. | `PDF
    (*

    European Number

    *)
  9. | `EN
    (*

    European Number Separator

    *)
  10. | `ES
    (*

    European Number Terminator

    *)
  11. | `ET
    (*

    Arabic Number

    *)
  12. | `AN
    (*

    Common Number Separator

    *)
  13. | `CS
    (*

    Nonspacing Mark

    *)
  14. | `NSM
    (*

    Boundary Neutral

    *)
  15. | `BN
    (*

    Paragraph Separator

    *)
  16. | `B
    (*

    Segment Separator

    *)
  17. | `S
    (*

    Whitespace

    *)
  18. | `WS
    (*

    Other Neutrals

    *)
  19. | `ON
    (*

    Left-to-Right isolate. Since 1.48.6

    *)
  20. | `LRI
    (*

    Right-to-Left isolate. Since 1.48.6

    *)
  21. | `RLI
    (*

    First strong isolate. Since 1.48.6

    *)
  22. | `FSI
    (*

    Pop directional isolate. Since 1.48.6

    *)
  23. | `PDI
]
val biditype_of_int : int -> biditype
val biditype_to_int : biditype -> int
type coveragelevel = [
  1. | `NONE
    (*

    The character is represented in a way that may be comprehensible but is not the correct graphical form. For instance, a Hangul character represented as a a sequence of Jamos, or a Latin transliteration of a Cyrillic word.

    *)
  2. | `FALLBACK
    (*

    The character is represented as basically the correct graphical form, but with a stylistic variant inappropriate for the current script.

    *)
  3. | `APPROXIMATE
    (*

    The character is represented as the correct graphical form.

    *)
  4. | `EXACT
]
val coveragelevel_of_int : int -> coveragelevel
val coveragelevel_to_int : coveragelevel -> int
type direction = [
  1. | `LTR
    (*

    A strong right-to-left direction

    *)
  2. | `RTL
    (*

    Deprecated value; treated the same as `PANGO_DIRECTION_RTL`.

    *)
  3. | `TTB_LTR
    (*

    Deprecated value; treated the same as `PANGO_DIRECTION_LTR`

    *)
  4. | `TTB_RTL
    (*

    A weak left-to-right direction

    *)
  5. | `WEAK_LTR
    (*

    A weak right-to-left direction

    *)
  6. | `WEAK_RTL
    (*

    No direction specified

    *)
  7. | `NEUTRAL
]
val direction_of_int : int -> direction
val direction_to_int : direction -> int
type ellipsizemode = [
  1. | `NONE
    (*

    Omit characters at the start of the text

    *)
  2. | `START
    (*

    Omit characters in the middle of the text

    *)
  3. | `MIDDLE
    (*

    Omit characters at the end of the text

    *)
  4. | `END
]
val ellipsizemode_of_int : int -> ellipsizemode
val ellipsizemode_to_int : ellipsizemode -> int
type fontscale = [
  1. | `NONE
    (*

    Change the font to a size suitable for superscripts

    *)
  2. | `SUPERSCRIPT
    (*

    Change the font to a size suitable for subscripts

    *)
  3. | `SUBSCRIPT
    (*

    Change the font to a size suitable for Small Caps

    *)
  4. | `SMALL_CAPS
]
val fontscale_of_int : int -> fontscale
val fontscale_to_int : fontscale -> int
type gravity = [
  1. | `SOUTH
    (*

    Glyphs are rotated 90 degrees counter-clockwise. <img align="right" valign="center" src="m-east.png">

    *)
  2. | `EAST
    (*

    Glyphs are upside-down. <img align="right" valign="cener" src="m-north.png">

    *)
  3. | `NORTH
    (*

    Glyphs are rotated 90 degrees clockwise. <img align="right" valign="center" src="m-west.png">

    *)
  4. | `WEST
    (*

    Gravity is resolved from the context matrix

    *)
  5. | `AUTO
]
val gravity_of_int : int -> gravity
val gravity_to_int : gravity -> int
type gravityhint = [
  1. | `NATURAL
    (*

    always use the base gravity set, regardless of the script.

    *)
  2. | `STRONG
    (*

    for scripts not in their natural direction (eg. Latin in East gravity), choose per-script gravity such that every script respects the line progression. This means, Latin and Arabic will take opposite gravities and both flow top-to-bottom for example.

    *)
  3. | `LINE
]
val gravityhint_of_int : int -> gravityhint
val gravityhint_to_int : gravityhint -> int
type layoutdeserializeerror = [
  1. | `INVALID
    (*

    A JSon value could not be interpreted

    *)
  2. | `INVALID_VALUE
    (*

    A required JSon member was not found

    *)
  3. | `MISSING_VALUE
]
val layoutdeserializeerror_of_int : int -> layoutdeserializeerror
val layoutdeserializeerror_to_int : layoutdeserializeerror -> int
type overline = [
  1. | `NONE
    (*

    Draw a single line above the ink extents of the text being underlined.

    *)
  2. | `SINGLE
]
val overline_of_int : int -> overline
val overline_to_int : overline -> int
type renderpart = [
  1. | `FOREGROUND
    (*

    the area behind the text

    *)
  2. | `BACKGROUND
    (*

    underlines

    *)
  3. | `UNDERLINE
    (*

    strikethrough lines

    *)
  4. | `STRIKETHROUGH
    (*

    overlines

    *)
  5. | `OVERLINE
]
val renderpart_of_int : int -> renderpart
val renderpart_to_int : renderpart -> int
type script = [
  1. | `INVALID_CODE
    (*

    a character used by multiple different scripts

    *)
  2. | `COMMON
    (*

    a mark glyph that takes its script from the base glyph to which it is attached

    *)
  3. | `INHERITED
    (*

    Arabic

    *)
  4. | `ARABIC
    (*

    Armenian

    *)
  5. | `ARMENIAN
    (*

    Bengali

    *)
  6. | `BENGALI
    (*

    Bopomofo

    *)
  7. | `BOPOMOFO
    (*

    Cherokee

    *)
  8. | `CHEROKEE
    (*

    Coptic

    *)
  9. | `COPTIC
    (*

    Cyrillic

    *)
  10. | `CYRILLIC
    (*

    Deseret

    *)
  11. | `DESERET
    (*

    Devanagari

    *)
  12. | `DEVANAGARI
    (*

    Ethiopic

    *)
  13. | `ETHIOPIC
    (*

    Georgian

    *)
  14. | `GEORGIAN
    (*

    Gothic

    *)
  15. | `GOTHIC
    (*

    Greek

    *)
  16. | `GREEK
    (*

    Gujarati

    *)
  17. | `GUJARATI
    (*

    Gurmukhi

    *)
  18. | `GURMUKHI
    (*

    Han

    *)
  19. | `HAN
    (*

    Hangul

    *)
  20. | `HANGUL
    (*

    Hebrew

    *)
  21. | `HEBREW
    (*

    Hiragana

    *)
  22. | `HIRAGANA
    (*

    Kannada

    *)
  23. | `KANNADA
    (*

    Katakana

    *)
  24. | `KATAKANA
    (*

    Khmer

    *)
  25. | `KHMER
    (*

    Lao

    *)
  26. | `LAO
    (*

    Latin

    *)
  27. | `LATIN
    (*

    Malayalam

    *)
  28. | `MALAYALAM
    (*

    Mongolian

    *)
  29. | `MONGOLIAN
    (*

    Myanmar

    *)
  30. | `MYANMAR
    (*

    Ogham

    *)
  31. | `OGHAM
    (*

    Old Italic

    *)
  32. | `OLD_ITALIC
    (*

    Oriya

    *)
  33. | `ORIYA
    (*

    Runic

    *)
  34. | `RUNIC
    (*

    Sinhala

    *)
  35. | `SINHALA
    (*

    Syriac

    *)
  36. | `SYRIAC
    (*

    Tamil

    *)
  37. | `TAMIL
    (*

    Telugu

    *)
  38. | `TELUGU
    (*

    Thaana

    *)
  39. | `THAANA
    (*

    Thai

    *)
  40. | `THAI
    (*

    Tibetan

    *)
  41. | `TIBETAN
    (*

    Canadian Aboriginal

    *)
  42. | `CANADIAN_ABORIGINAL
    (*

    Yi

    *)
  43. | `YI
    (*

    Tagalog

    *)
  44. | `TAGALOG
    (*

    Hanunoo

    *)
  45. | `HANUNOO
    (*

    Buhid

    *)
  46. | `BUHID
    (*

    Tagbanwa

    *)
  47. | `TAGBANWA
    (*

    Braille

    *)
  48. | `BRAILLE
    (*

    Cypriot

    *)
  49. | `CYPRIOT
    (*

    Limbu

    *)
  50. | `LIMBU
    (*

    Osmanya

    *)
  51. | `OSMANYA
    (*

    Shavian

    *)
  52. | `SHAVIAN
    (*

    Linear B

    *)
  53. | `LINEAR_B
    (*

    Tai Le

    *)
  54. | `TAI_LE
    (*

    Ugaritic

    *)
  55. | `UGARITIC
    (*

    New Tai Lue. Since 1.10

    *)
  56. | `NEW_TAI_LUE
    (*

    Buginese. Since 1.10

    *)
  57. | `BUGINESE
    (*

    Glagolitic. Since 1.10

    *)
  58. | `GLAGOLITIC
    (*

    Tifinagh. Since 1.10

    *)
  59. | `TIFINAGH
    (*

    Syloti Nagri. Since 1.10

    *)
  60. | `SYLOTI_NAGRI
    (*

    Old Persian. Since 1.10

    *)
  61. | `OLD_PERSIAN
    (*

    Kharoshthi. Since 1.10

    *)
  62. | `KHAROSHTHI
    (*

    an unassigned code point. Since 1.14

    *)
  63. | `UNKNOWN
    (*

    Balinese. Since 1.14

    *)
  64. | `BALINESE
    (*

    Cuneiform. Since 1.14

    *)
  65. | `CUNEIFORM
    (*

    Phoenician. Since 1.14

    *)
  66. | `PHOENICIAN
    (*

    Phags-pa. Since 1.14

    *)
  67. | `PHAGS_PA
    (*

    N'Ko. Since 1.14

    *)
  68. | `NKO
    (*

    Kayah Li. Since 1.20.1

    *)
  69. | `KAYAH_LI
    (*

    Lepcha. Since 1.20.1

    *)
  70. | `LEPCHA
    (*

    Rejang. Since 1.20.1

    *)
  71. | `REJANG
    (*

    Sundanese. Since 1.20.1

    *)
  72. | `SUNDANESE
    (*

    Saurashtra. Since 1.20.1

    *)
  73. | `SAURASHTRA
    (*

    Cham. Since 1.20.1

    *)
  74. | `CHAM
    (*

    Ol Chiki. Since 1.20.1

    *)
  75. | `OL_CHIKI
    (*

    Vai. Since 1.20.1

    *)
  76. | `VAI
    (*

    Carian. Since 1.20.1

    *)
  77. | `CARIAN
    (*

    Lycian. Since 1.20.1

    *)
  78. | `LYCIAN
    (*

    Lydian. Since 1.20.1

    *)
  79. | `LYDIAN
    (*

    Batak. Since 1.32

    *)
  80. | `BATAK
    (*

    Brahmi. Since 1.32

    *)
  81. | `BRAHMI
    (*

    Mandaic. Since 1.32

    *)
  82. | `MANDAIC
    (*

    Chakma. Since: 1.32

    *)
  83. | `CHAKMA
    (*

    Meroitic Cursive. Since: 1.32

    *)
  84. | `MEROITIC_CURSIVE
    (*

    Meroitic Hieroglyphs. Since: 1.32

    *)
  85. | `MEROITIC_HIEROGLYPHS
    (*

    Miao. Since: 1.32

    *)
  86. | `MIAO
    (*

    Sharada. Since: 1.32

    *)
  87. | `SHARADA
    (*

    Sora Sompeng. Since: 1.32

    *)
  88. | `SORA_SOMPENG
    (*

    Takri. Since: 1.32

    *)
  89. | `TAKRI
    (*

    Bassa. Since: 1.40

    *)
  90. | `BASSA_VAH
    (*

    Caucasian Albanian. Since: 1.40

    *)
  91. | `CAUCASIAN_ALBANIAN
    (*

    Duployan. Since: 1.40

    *)
  92. | `DUPLOYAN
    (*

    Elbasan. Since: 1.40

    *)
  93. | `ELBASAN
    (*

    Grantha. Since: 1.40

    *)
  94. | `GRANTHA
    (*

    Kjohki. Since: 1.40

    *)
  95. | `KHOJKI
    (*

    Khudawadi, Sindhi. Since: 1.40

    *)
  96. | `KHUDAWADI
    (*

    Linear A. Since: 1.40

    *)
  97. | `LINEAR_A
    (*

    Mahajani. Since: 1.40

    *)
  98. | `MAHAJANI
    (*

    Manichaean. Since: 1.40

    *)
  99. | `MANICHAEAN
    (*

    Mende Kikakui. Since: 1.40

    *)
  100. | `MENDE_KIKAKUI
    (*

    Modi. Since: 1.40

    *)
  101. | `MODI
    (*

    Mro. Since: 1.40

    *)
  102. | `MRO
    (*

    Nabataean. Since: 1.40

    *)
  103. | `NABATAEAN
    (*

    Old North Arabian. Since: 1.40

    *)
  104. | `OLD_NORTH_ARABIAN
    (*

    Old Permic. Since: 1.40

    *)
  105. | `OLD_PERMIC
    (*

    Pahawh Hmong. Since: 1.40

    *)
  106. | `PAHAWH_HMONG
    (*

    Palmyrene. Since: 1.40

    *)
  107. | `PALMYRENE
    (*

    Pau Cin Hau. Since: 1.40

    *)
  108. | `PAU_CIN_HAU
    (*

    Psalter Pahlavi. Since: 1.40

    *)
  109. | `PSALTER_PAHLAVI
    (*

    Siddham. Since: 1.40

    *)
  110. | `SIDDHAM
    (*

    Tirhuta. Since: 1.40

    *)
  111. | `TIRHUTA
    (*

    Warang Citi. Since: 1.40

    *)
  112. | `WARANG_CITI
    (*

    Ahom. Since: 1.40

    *)
  113. | `AHOM
    (*

    Anatolian Hieroglyphs. Since: 1.40

    *)
  114. | `ANATOLIAN_HIEROGLYPHS
    (*

    Hatran. Since: 1.40

    *)
  115. | `HATRAN
    (*

    Multani. Since: 1.40

    *)
  116. | `MULTANI
    (*

    Old Hungarian. Since: 1.40

    *)
  117. | `OLD_HUNGARIAN
    (*

    Signwriting. Since: 1.40

    *)
  118. | `SIGNWRITING
]
val script_of_int : int -> script
val script_to_int : script -> int
type stretch = [
  1. | `ULTRA_CONDENSED
    (*

    extra condensed width

    *)
  2. | `EXTRA_CONDENSED
    (*

    condensed width

    *)
  3. | `CONDENSED
    (*

    semi condensed width

    *)
  4. | `SEMI_CONDENSED
    (*

    the normal width

    *)
  5. | `NORMAL
    (*

    semi expanded width

    *)
  6. | `SEMI_EXPANDED
    (*

    expanded width

    *)
  7. | `EXPANDED
    (*

    extra expanded width

    *)
  8. | `EXTRA_EXPANDED
    (*

    ultra expanded width

    *)
  9. | `ULTRA_EXPANDED
]
val stretch_of_int : int -> stretch
val stretch_to_int : stretch -> int
type style = [
  1. | `NORMAL
    (*

    the font is slanted, but in a roman style.

    *)
  2. | `OBLIQUE
    (*

    the font is slanted in an italic style.

    *)
  3. | `ITALIC
]
val style_of_int : int -> style
val style_to_int : style -> int
type tabalign = [
  1. | `LEFT
    (*

    the text appears to the left of the tab stop position until the available space is filled. Since: 1.50

    *)
  2. | `RIGHT
    (*

    the text is centered at the tab stop position until the available space is filled. Since: 1.50

    *)
  3. | `CENTER
    (*

    text before the first occurrence of the decimal point character appears to the left of the tab stop position (until the available space is filled), the rest to the right. Since: 1.50

    *)
  4. | `DECIMAL
]
val tabalign_of_int : int -> tabalign
val tabalign_to_int : tabalign -> int
type texttransform = [
  1. | `NONE
    (*

    Display letters and numbers as lowercase

    *)
  2. | `LOWERCASE
    (*

    Display letters and numbers as uppercase

    *)
  3. | `UPPERCASE
    (*

    Display the first character of a word in titlecase

    *)
  4. | `CAPITALIZE
]
val texttransform_of_int : int -> texttransform
val texttransform_to_int : texttransform -> int
type underline = [
  1. | `NONE
    (*

    a single underline should be drawn

    *)
  2. | `SINGLE
    (*

    a double underline should be drawn

    *)
  3. | `DOUBLE
    (*

    a single underline should be drawn at a position beneath the ink extents of the text being underlined. This should be used only for underlining single characters, such as for keyboard accelerators. %PANGO_UNDERLINE_SINGLE should be used for extended portions of text.

    *)
  4. | `LOW
    (*

    an underline indicating an error should be drawn below. The exact style of rendering is up to the `PangoRenderer` in use, but typical styles include wavy or dotted lines. This underline is typically used to indicate an error such as a possible mispelling; in some cases a contrasting color may automatically be used. This type of underlining is available since Pango 1.4.

    *)
  5. | `ERROR
    (*

    Like @PANGO_UNDERLINE_SINGLE, but drawn continuously across multiple runs. This type of underlining is available since Pango 1.46.

    *)
  6. | `SINGLE_LINE
    (*

    Like @PANGO_UNDERLINE_DOUBLE, but drawn continuously across multiple runs. This type of underlining is available since Pango 1.46.

    *)
  7. | `DOUBLE_LINE
    (*

    Like @PANGO_UNDERLINE_ERROR, but drawn continuously across multiple runs. This type of underlining is available since Pango 1.46.

    *)
  8. | `ERROR_LINE
]
val underline_of_int : int -> underline
val underline_to_int : underline -> int
type variant = [
  1. | `NORMAL
    (*

    A font with the lower case characters replaced by smaller variants of the capital characters.

    *)
  2. | `SMALL_CAPS
    (*

    A font with all characters replaced by smaller variants of the capital characters. Since: 1.50

    *)
  3. | `ALL_SMALL_CAPS
    (*

    A font with the lower case characters replaced by smaller variants of the capital characters. Petite Caps can be even smaller than Small Caps. Since: 1.50

    *)
  4. | `PETITE_CAPS
    (*

    A font with all characters replaced by smaller variants of the capital characters. Petite Caps can be even smaller than Small Caps. Since: 1.50

    *)
  5. | `ALL_PETITE_CAPS
    (*

    A font with the upper case characters replaced by smaller variants of the capital letters. Since: 1.50

    *)
  6. | `UNICASE
    (*

    A font with capital letters that are more suitable for all-uppercase titles. Since: 1.50

    *)
  7. | `TITLE_CAPS
]
val variant_of_int : int -> variant
val variant_to_int : variant -> int
type weight = [
  1. | `THIN
    (*

    the ultralight weight (= 200)

    *)
  2. | `ULTRALIGHT
    (*

    the light weight (= 300)

    *)
  3. | `LIGHT
    (*

    the semilight weight (= 350) Since: 1.36.7

    *)
  4. | `SEMILIGHT
    (*

    the book weight (= 380) Since: 1.24)

    *)
  5. | `BOOK
    (*

    the default weight (= 400)

    *)
  6. | `NORMAL
    (*

    the medium weight (= 500) Since: 1.24

    *)
  7. | `MEDIUM
    (*

    the semibold weight (= 600)

    *)
  8. | `SEMIBOLD
    (*

    the bold weight (= 700)

    *)
  9. | `BOLD
    (*

    the ultrabold weight (= 800)

    *)
  10. | `ULTRABOLD
    (*

    the heavy weight (= 900)

    *)
  11. | `HEAVY
    (*

    the ultraheavy weight (= 1000) Since: 1.24

    *)
  12. | `ULTRAHEAVY
]
val weight_of_int : int -> weight
val weight_to_int : weight -> int
type wrapmode = [
  1. | `WORD
    (*

    wrap lines at character boundaries.

    *)
  2. | `CHAR
    (*

    wrap lines at word boundaries, but fall back to character boundaries if there is not enough space for a full word.

    *)
  3. | `WORD_CHAR
]
val wrapmode_of_int : int -> wrapmode
val wrapmode_to_int : wrapmode -> int
type fontmask_flag = [
  1. | `FAMILY
    (*

    the font style is specified.

    *)
  2. | `STYLE
    (*

    the font variant is specified.

    *)
  3. | `VARIANT
    (*

    the font weight is specified.

    *)
  4. | `WEIGHT
    (*

    the font stretch is specified.

    *)
  5. | `STRETCH
    (*

    the font size is specified.

    *)
  6. | `SIZE
    (*

    the font gravity is specified (Since: 1.16.)

    *)
  7. | `GRAVITY
    (*

    OpenType font variations are specified (Since: 1.42)

    *)
  8. | `VARIATIONS
]
type fontmask = fontmask_flag list
val fontmask_of_int : int -> fontmask
val fontmask_to_int : fontmask -> int
type layoutdeserializeflags_flag = [
  1. | `DEFAULT
    (*

    Apply context information from the serialization to the `PangoContext`

    *)
  2. | `CONTEXT
]
type layoutdeserializeflags = layoutdeserializeflags_flag list
val layoutdeserializeflags_of_int : int -> layoutdeserializeflags
val layoutdeserializeflags_to_int : layoutdeserializeflags -> int
type layoutserializeflags_flag = [
  1. | `DEFAULT
    (*

    Include context information

    *)
  2. | `CONTEXT
    (*

    Include information about the formatted output

    *)
  3. | `OUTPUT
]
type layoutserializeflags = layoutserializeflags_flag list
val layoutserializeflags_of_int : int -> layoutserializeflags
val layoutserializeflags_to_int : layoutserializeflags -> int
type shapeflags_flag = [
  1. | `NONE
    (*

    Round glyph positions and widths to whole device units This option should be set if the target renderer can't do subpixel positioning of glyphs

    *)
  2. | `ROUND_POSITIONS
]
type shapeflags = shapeflags_flag list
val shapeflags_of_int : int -> shapeflags
val shapeflags_to_int : shapeflags -> int
type showflags_flag = [
  1. | `NONE
    (*

    Render spaces, tabs and newlines visibly

    *)
  2. | `SPACES
    (*

    Render line breaks visibly

    *)
  3. | `LINE_BREAKS
    (*

    Render default-ignorable Unicode characters visibly

    *)
  4. | `IGNORABLES
]
type showflags = showflags_flag list
val showflags_of_int : int -> showflags
val showflags_to_int : showflags -> int